@@ -271,7 +271,6 @@ caps_add_channel_configuration (GstCaps * caps,
           channel_mask = CHANNEL_MASK_7_1;
           break;
         default:
-          channel_mask = 0;
           g_assert_not_reached ();
           break;
       }
@@ -399,7 +398,7 @@ max_chan_error:
 }
 
 snd_pcm_t *
-gst_alsa_open_iec958_pcm (GstObject * obj, gchar * device)
+gst_alsa_open_iec958_pcm (GstObject * obj)
 {
   char *iec958_pcm_name = NULL;
   snd_pcm_t *pcm = NULL;
@@ -418,8 +417,7 @@ gst_alsa_open_iec958_pcm (GstObject * obj, gchar * device)
    *    spdif:{AES0 0x2 AES1 0x82 AES2 0x0 AES3 0x2}
    */
   sprintf (devstr,
-      "%s:{AES0 0x%02x AES1 0x%02x AES2 0x%02x AES3 0x%02x}",
-      device,
+      "iec958:{AES0 0x%02x AES1 0x%02x AES2 0x%02x AES3 0x%02x}",
       IEC958_AES0_CON_EMPHASIS_NONE | IEC958_AES0_NONAUDIO,
       IEC958_AES1_CON_ORIGINAL | IEC958_AES1_CON_PCM_CODER,
       0, IEC958_AES3_CON_FS_48000);
@@ -447,8 +445,8 @@ gst_alsa_open_iec958_pcm (GstObject * obj, gchar * device)
  */
 
 GstCaps *
-gst_alsa_probe_supported_formats (GstObject * obj, gchar * device,
-    snd_pcm_t * handle, const GstCaps * template_caps)
+gst_alsa_probe_supported_formats (GstObject * obj, snd_pcm_t * handle,
+    const GstCaps * template_caps)
 {
   snd_pcm_hw_params_t *hw_params;
   snd_pcm_stream_t stream_type;
@@ -475,7 +473,7 @@ gst_alsa_probe_supported_formats (GstObject * obj, gchar * device,
   /* Try opening IEC958 device to see if we can support that format (playback
    * only for now but we could add SPDIF capture later) */
   if (stream_type == SND_PCM_STREAM_PLAYBACK) {
-    snd_pcm_t *pcm = gst_alsa_open_iec958_pcm (obj, device);
+    snd_pcm_t *pcm = gst_alsa_open_iec958_pcm (obj);
 
     if (G_LIKELY (pcm)) {
       gst_caps_append (caps, gst_caps_from_string (PASSTHROUGH_CAPS));
