@@ -51,10 +51,9 @@
 GST_DEBUG_CATEGORY_EXTERN (alsa_debug);
 #define GST_CAT_DEFAULT alsa_debug
 
-snd_pcm_t * gst_alsa_open_iec958_pcm (GstObject * obj, gchar *device);
+snd_pcm_t * gst_alsa_open_iec958_pcm (GstObject * obj);
 
 GstCaps * gst_alsa_probe_supported_formats (GstObject      * obj,
-                                            gchar          * device,
                                             snd_pcm_t      * handle,
                                             const GstCaps  * template_caps);
 
