@@ -53,6 +53,7 @@
 
 #include <gst/audio/gstaudioiec61937.h>
 #include <gst/gst-i18n-plugin.h>
+#include "gst/glib-compat-private.h"
 
 #define DEFAULT_DEVICE		"default"
 #define DEFAULT_DEVICE_NAME	""
@@ -117,7 +118,7 @@ gst_alsasink_finalise (GObject * object)
   GstAlsaSink *sink = GST_ALSA_SINK (object);
 
   g_free (sink->device);
-  g_mutex_clear (&sink->alsa_lock);
+  g_mutex_free (sink->alsa_lock);
 
   g_mutex_lock (&output_mutex);
   --output_ref;
@@ -254,7 +255,7 @@ gst_alsasink_init (GstAlsaSink * alsasink)
   alsasink->device = g_strdup (DEFAULT_DEVICE);
   alsasink->handle = NULL;
   alsasink->cached_caps = NULL;
-  g_mutex_init (&alsasink->alsa_lock);
+  alsasink->alsa_lock = g_mutex_new ();
 
   g_mutex_lock (&output_mutex);
   if (output_ref == 0) {
@@ -299,8 +300,8 @@ gst_alsasink_getcaps (GstBaseSink * bsink, GstCaps * filter)
   g_return_val_if_fail (pad_template != NULL, NULL);
 
   templ_caps = gst_pad_template_get_caps (pad_template);
-  caps = gst_alsa_probe_supported_formats (GST_OBJECT (sink), sink->device,
-      sink->handle, templ_caps);
+  caps = gst_alsa_probe_supported_formats (GST_OBJECT (sink), sink->handle,
+      templ_caps);
   gst_caps_unref (templ_caps);
 
   if (caps) {
@@ -851,9 +852,9 @@ gst_alsasink_prepare (GstAudioSink * asink, GstAudioRingBufferSpec * spec)
 
   alsa = GST_ALSA_SINK (asink);
 
-  if (alsa->iec958) {
+  if (spec->type == GST_AUDIO_RING_BUFFER_FORMAT_TYPE_IEC958) {
     snd_pcm_close (alsa->handle);
-    alsa->handle = gst_alsa_open_iec958_pcm (GST_OBJECT (alsa), alsa->device);
+    alsa->handle = gst_alsa_open_iec958_pcm (GST_OBJECT (alsa));
     if (G_UNLIKELY (!alsa->handle)) {
       goto no_iec958;
     }
