@@ -205,6 +205,20 @@ gst_ogg_mux_class_init (GstOggMuxClass * klass)
 
 }
 
+#if 0
+static const GstEventMask *
+gst_ogg_mux_get_sink_event_masks (GstPad * pad)
+{
+  static const GstEventMask gst_ogg_mux_sink_event_masks[] = {
+    {GST_EVENT_EOS, 0},
+    {GST_EVENT_DISCONTINUOUS, 0},
+    {0,}
+  };
+
+  return gst_ogg_mux_sink_event_masks;
+}
+#endif
+
 static void
 gst_ogg_mux_clear (GstOggMux * ogg_mux)
 {
@@ -281,14 +295,16 @@ gst_ogg_mux_ogg_pad_destroy_notify (GstCollectData * data)
 }
 
 static GstPadLinkReturn
-gst_ogg_mux_sinkconnect (GstPad * pad, GstObject * parent, GstPad * peer)
+gst_ogg_mux_sinkconnect (GstPad * pad, GstPad * peer)
 {
   GstOggMux *ogg_mux;
 
-  ogg_mux = GST_OGG_MUX (parent);
+  ogg_mux = GST_OGG_MUX (gst_pad_get_parent (pad));
 
   GST_DEBUG_OBJECT (ogg_mux, "sinkconnect triggered on %s", GST_PAD_NAME (pad));
 
+  gst_object_unref (ogg_mux);
+
   return GST_PAD_LINK_OK;
 }
 
@@ -328,7 +344,7 @@ gst_ogg_mux_sink_event (GstCollectPads * pads, GstCollectData * pad,
       gst_event_parse_tag (event, &tags);
       tags = gst_tag_list_merge (ogg_pad->tags, tags, GST_TAG_MERGE_APPEND);
       if (ogg_pad->tags)
-        gst_tag_list_unref (ogg_pad->tags);
+        gst_tag_list_free (ogg_pad->tags);
       ogg_pad->tags = tags;
 
       GST_DEBUG_OBJECT (ogg_mux, "Got tags %" GST_PTR_FORMAT, ogg_pad->tags);
@@ -436,7 +452,7 @@ gst_ogg_mux_request_new_pad (GstElement * element,
       GstOggPadData *oggpad;
 
       oggpad = (GstOggPadData *)
-          gst_collect_pads_add_pad (ogg_mux->collect, newpad,
+          gst_collect_pads_add_pad_full (ogg_mux->collect, newpad,
           sizeof (GstOggPadData), gst_ogg_mux_ogg_pad_destroy_notify, FALSE);
       ogg_mux->active_pads++;
 
@@ -505,29 +521,19 @@ static gboolean
 gst_ogg_mux_handle_src_event (GstPad * pad, GstObject * parent,
     GstEvent * event)
 {
-  gboolean res = FALSE;
-  GstOggMux *ogg_mux = GST_OGG_MUX (parent);
+  GstEventType type;
 
-  switch (GST_EVENT_TYPE (event)) {
-    case GST_EVENT_SEEK:{
-      GstSeekFlags flags;
+  type = event ? GST_EVENT_TYPE (event) : GST_EVENT_UNKNOWN;
 
-      gst_event_parse_seek (event, NULL, NULL, &flags, NULL, NULL, NULL, NULL);
-      if (!ogg_mux->need_headers && (flags & GST_SEEK_FLAG_FLUSH) != 0) {
-        /* don't allow flushing seeks once we started */
-        gst_event_unref (event);
-        event = NULL;
-      }
-      break;
-    }
+  switch (type) {
+    case GST_EVENT_SEEK:
+      /* disable seeking for now */
+      return FALSE;
     default:
       break;
   }
 
-  if (event != NULL)
-    res = gst_pad_event_default (pad, parent, event);
-
-  return res;
+  return gst_pad_event_default (pad, parent, event);
 }
 
 static GstBuffer *
@@ -976,11 +982,6 @@ gst_ogg_mux_queue_pads (GstOggMux * ogg_mux, gboolean * popped)
                 gst_collect_pads_set_waiting (ogg_mux->collect,
                     (GstCollectData *) pad, FALSE);
               }
-
-              if (pad->map.is_video && ogg_mux->delta_pad == NULL) {
-                ogg_mux->delta_pad = pad;
-                GST_INFO_OBJECT (pad, "selected delta pad");
-              }
             }
             if (caps)
               gst_caps_unref (caps);
@@ -1199,8 +1200,7 @@ gst_ogg_mux_make_fishead (GstOggMux * mux, ogg_stream_state * os)
 static void
 gst_ogg_mux_byte_writer_put_string_utf8 (GstByteWriter * bw, const char *s)
 {
-  if (!gst_byte_writer_put_data (bw, (const guint8 *) s, strlen (s)))
-    GST_ERROR ("put_data failed");
+  g_assert (gst_byte_writer_put_data (bw, (const guint8 *) s, strlen (s)));
 }
 
 static void
@@ -2059,7 +2059,7 @@ gst_ogg_mux_clear_collectpads (GstCollectPads * collect)
     }
 
     if (oggpad->tags) {
-      gst_tag_list_unref (oggpad->tags);
+      gst_tag_list_free (oggpad->tags);
       oggpad->tags = NULL;
     }
 
