@@ -536,11 +536,11 @@ setup_dirac_mapper (GstOggStream * pad, ogg_packet * packet)
   pad->caps = gst_caps_new_simple ("video/x-dirac",
       "width", G_TYPE_INT, header.width,
       "height", G_TYPE_INT, header.height,
-      "interlace-mode", G_TYPE_STRING,
-      (header.interlaced ? "mixed" : "progressive"), "pixel-aspect-ratio",
-      GST_TYPE_FRACTION, header.aspect_ratio_numerator,
-      header.aspect_ratio_denominator, "framerate", GST_TYPE_FRACTION,
-      header.frame_rate_numerator, header.frame_rate_denominator, NULL);
+      "interlaced", G_TYPE_BOOLEAN, header.interlaced,
+      "pixel-aspect-ratio", GST_TYPE_FRACTION,
+      header.aspect_ratio_numerator, header.aspect_ratio_denominator,
+      "framerate", GST_TYPE_FRACTION, header.frame_rate_numerator,
+      header.frame_rate_denominator, NULL);
 
   return TRUE;
 }
@@ -1575,8 +1575,7 @@ setup_ogmtext_mapper (GstOggStream * pad, ogg_packet * packet)
   if (pad->granulerate_d <= 0)
     return FALSE;
 
-  pad->caps = gst_caps_new_simple ("text/x-raw", "format", G_TYPE_STRING,
-      "utf8", NULL);
+  pad->caps = gst_caps_new_empty_simple ("text/plain");
 
   pad->n_header_packets = 1;
   pad->is_ogm = TRUE;
@@ -1718,7 +1717,6 @@ setup_cmml_mapper (GstOggStream * pad, ogg_packet * packet)
   pad->caps = gst_caps_new_empty_simple ("text/x-cmml");
   pad->always_flush_page = TRUE;
   pad->is_sparse = TRUE;
-  pad->is_cmml = TRUE;
 
   return TRUE;
 }
@@ -1874,8 +1872,6 @@ setup_opus_mapper (GstOggStream * pad, ogg_packet * packet)
   pad->granulerate_d = 1;
   pad->granuleshift = 0;
   pad->n_header_packets = 2;
-  pad->first_granpos = -1;
-  pad->forbid_start_clamping = TRUE;
 
   /* pre-skip is in samples at 48000 Hz, which matches granule one for one */
   pad->granule_offset = -GST_READ_UINT16_LE (packet->packet + 10);
@@ -1893,29 +1889,6 @@ is_header_opus (GstOggStream * pad, ogg_packet * packet)
   return packet->bytes >= 8 && !memcmp (packet->packet, "Opus", 4);
 }
 
-static gint64
-granulepos_to_granule_opus (GstOggStream * pad, gint64 granulepos)
-{
-  if (granulepos == -1)
-    return -1;
-
-  /* We must reject some particular cases for the first granpos */
-
-  if (pad->first_granpos < 0 || granulepos < pad->first_granpos)
-    pad->first_granpos = granulepos;
-
-  if (pad->first_granpos == granulepos) {
-    if (granulepos < -pad->granule_offset) {
-      GST_ERROR ("Invalid Opus stream: first granulepos (%" G_GINT64_FORMAT
-          ") less than preskip (%" G_GINT64_FORMAT ")", granulepos,
-          -pad->granule_offset);
-      return -1;
-    }
-  }
-
-  return granulepos;
-}
-
 static gint64
 packet_duration_opus (GstOggStream * pad, ogg_packet * packet)
 {
@@ -2173,7 +2146,7 @@ const GstOggMap mappers[] = {
     "OpusHead", 8, 0,
     "audio/x-opus",
     setup_opus_mapper,
-    granulepos_to_granule_opus,
+    granulepos_to_granule_default,
     granule_to_granulepos_default,
     NULL,
     NULL,
