@@ -59,11 +59,6 @@ GST_DEBUG_CATEGORY_EXTERN (GST_CAT_PERFORMANCE);
 #define THEORA_DEF_TELEMETRY_QI 0
 #define THEORA_DEF_TELEMETRY_BITS 0
 
-/* This was removed from the base class, this is used as a
-   temporary return to signal the need to call _drop_frame,
-   and does not leave theoraenc. */
-#define GST_CUSTOM_FLOW_DROP GST_FLOW_CUSTOM_SUCCESS_1
-
 enum
 {
   PROP_0,
@@ -206,7 +201,6 @@ gst_theora_dec_init (GstTheoraDec * dec)
 
   /* input is packetized,
    * but is not marked that way so data gets parsed and keyframes marked */
-  gst_video_decoder_set_packetized (GST_VIDEO_DECODER (dec), FALSE);
 }
 
 static void
@@ -248,10 +242,6 @@ theora_dec_stop (GstVideoDecoder * decoder)
     gst_tag_list_free (dec->tags);
     dec->tags = NULL;
   }
-  if (dec->input_state)
-    gst_video_codec_state_unref (dec->input_state);
-  if (dec->output_state)
-    gst_video_codec_state_unref (dec->output_state);
 
   return TRUE;
 }
@@ -388,7 +378,7 @@ theora_handle_comment_packet (GstTheoraDec * dec, ogg_packet * packet)
 }
 
 static GstFlowReturn
-theora_handle_type_packet (GstTheoraDec * dec)
+theora_handle_type_packet (GstTheoraDec * dec, ogg_packet * packet)
 {
   gint par_num, par_den;
   GstFlowReturn ret = GST_FLOW_OK;
@@ -504,8 +494,6 @@ theora_handle_type_packet (GstTheoraDec * dec)
       break;
   }
 
-  gst_video_decoder_negotiate (GST_VIDEO_DECODER (dec));
-
   dec->have_header = TRUE;
 
   /* FIXME : Put this on the next outgoing frame */
@@ -543,7 +531,7 @@ theora_handle_header_packet (GstTheoraDec * dec, ogg_packet * packet)
       res = theora_handle_comment_packet (dec, packet);
       break;
     case 0x82:
-      res = theora_handle_type_packet (dec);
+      res = theora_handle_type_packet (dec, packet);
       break;
     default:
       /* ignore */
@@ -578,7 +566,7 @@ theora_handle_image (GstTheoraDec * dec, th_ycbcr_buffer buf,
   gint pic_width, pic_height;
   gint offset_x, offset_y;
 
-  result = gst_video_decoder_allocate_output_frame (decoder, frame);
+  result = gst_video_decoder_alloc_output_frame (decoder, frame);
 
   if (G_UNLIKELY (result != GST_FLOW_OK)) {
     GST_DEBUG_OBJECT (dec, "could not get buffer, reason: %s",
@@ -722,6 +710,8 @@ theora_handle_data_packet (GstTheoraDec * dec, ogg_packet * packet,
     goto wrong_dimensions;
 
   result = theora_handle_image (dec, buf, frame);
+  if (result != GST_FLOW_OK)
+    return result;
 
   return result;
 
@@ -735,12 +725,12 @@ not_initialized:
 dropping:
   {
     GST_WARNING_OBJECT (dec, "dropping frame because we need a keyframe");
-    return GST_CUSTOM_FLOW_DROP;
+    return GST_VIDEO_DECODER_FLOW_NEED_DATA;
   }
 dropping_qos:
   {
     GST_WARNING_OBJECT (dec, "dropping frame because of QoS");
-    return GST_CUSTOM_FLOW_DROP;
+    return GST_VIDEO_DECODER_FLOW_NEED_DATA;
   }
 decode_error:
   {
@@ -789,7 +779,6 @@ theora_dec_decode_buffer (GstTheoraDec * dec, GstBuffer * buf,
   if (packet.bytes && packet.packet[0] & 0x80) {
     if (dec->have_header) {
       GST_WARNING_OBJECT (GST_OBJECT (dec), "Ignoring header");
-      result = GST_CUSTOM_FLOW_DROP;
       goto done;
     }
     result = theora_handle_header_packet (dec, &packet);
@@ -817,17 +806,8 @@ theora_dec_handle_frame (GstVideoDecoder * bdec, GstVideoCodecFrame * frame)
   dec = GST_THEORA_DEC (bdec);
 
   res = theora_dec_decode_buffer (dec, frame->input_buffer, frame);
-  switch (res) {
-    case GST_FLOW_OK:
-      res = gst_video_decoder_finish_frame (bdec, frame);
-      break;
-    case GST_CUSTOM_FLOW_DROP:
-      res = gst_video_decoder_drop_frame (bdec, frame);
-      break;
-    default:
-      gst_video_codec_frame_unref (frame);
-      break;
-  }
+  if (res == GST_FLOW_OK)
+    res = gst_video_decoder_finish_frame (bdec, frame);
 
   return res;
 }
@@ -851,12 +831,11 @@ theora_dec_decide_allocation (GstVideoDecoder * decoder, GstQuery * query)
 
   dec->can_crop = FALSE;
   config = gst_buffer_pool_get_config (pool);
-  if (gst_query_find_allocation_meta (query, GST_VIDEO_META_API_TYPE, NULL)) {
+  if (gst_query_has_allocation_meta (query, GST_VIDEO_META_API_TYPE)) {
     gst_buffer_pool_config_add_option (config,
         GST_BUFFER_POOL_OPTION_VIDEO_META);
     dec->can_crop =
-        gst_query_find_allocation_meta (query, GST_VIDEO_CROP_META_API_TYPE,
-        NULL);
+        gst_query_has_allocation_meta (query, GST_VIDEO_CROP_META_API_TYPE);
   }
 
   if (dec->can_crop) {
