@@ -257,7 +257,14 @@ vorbis_handle_comment_packet (GstVorbisDec * vd, ogg_packet * packet)
 
   gst_audio_decoder_merge_tags (GST_AUDIO_DECODER_CAST (vd), list,
       GST_TAG_MERGE_REPLACE);
-  gst_tag_list_unref (list);
+  if (vd->initialized) {
+    gst_tag_list_free (list);
+  } else {
+    /* Only post them as messages for the time being. *
+     * They will be pushed on the pad once the decoder is initialized */
+    gst_element_post_message (GST_ELEMENT_CAST (vd),
+        gst_message_new_tag (GST_OBJECT (vd), list));
+  }
 
   return GST_FLOW_OK;
 }
@@ -471,7 +478,7 @@ vorbis_handle_data_packet (GstVorbisDec * vd, ogg_packet * packet,
       sample_count, size);
 
   /* alloc buffer for it */
-  out = gst_audio_decoder_allocate_output_buffer (GST_AUDIO_DECODER (vd), size);
+  out = gst_buffer_new_allocate (NULL, size, NULL);
 
   gst_buffer_map (out, &map, GST_MAP_WRITE);
   /* get samples ready for reading now, should be sample_count */
@@ -578,10 +585,8 @@ vorbis_dec_handle_frame (GstAudioDecoder * dec, GstBuffer * buffer)
       goto done;
     }
     result = vorbis_handle_header_packet (vd, packet);
-    if (result != GST_FLOW_OK)
-      goto done;
     /* consumer header packet/frame */
-    result = gst_audio_decoder_finish_frame (GST_AUDIO_DECODER (vd), NULL, 1);
+    gst_audio_decoder_finish_frame (GST_AUDIO_DECODER (vd), NULL, 1);
   } else {
     GstClockTime timestamp, duration;
 
