@@ -50,7 +50,6 @@
 
 #include <gst/gsttagsetter.h>
 #include <gst/tag/tag.h>
-#include <gst/audio/multichannel.h>
 #include <gst/audio/audio.h>
 #include "gstvorbisenc.h"
 
@@ -63,17 +62,18 @@ static GstStaticPadTemplate vorbis_enc_sink_factory =
 GST_STATIC_PAD_TEMPLATE ("sink",
     GST_PAD_SINK,
     GST_PAD_ALWAYS,
-    GST_STATIC_CAPS ("audio/x-raw-float, "
-        "rate = (int) [ 1, 200000 ], "
-        "channels = (int) [ 1, 255 ], " "endianness = (int) BYTE_ORDER, "
-        "width = (int) 32")
+    GST_STATIC_CAPS ("audio/x-raw, "
+        "format = (string) " GST_AUDIO_NE (F32) ", "
+        "layout = (string) interleaved, "
+        "rate = (int) [ 1, 200000 ], " "channels = (int) [ 1, 255 ]")
     );
 
 static GstStaticPadTemplate vorbis_enc_src_factory =
 GST_STATIC_PAD_TEMPLATE ("src",
     GST_PAD_SRC,
     GST_PAD_ALWAYS,
-    GST_STATIC_CAPS ("audio/x-vorbis")
+    GST_STATIC_CAPS ("audio/x-vorbis, "
+        "rate = (int) [ 1, 200000 ], " "channels = (int) [ 1, 255 ]")
     );
 
 enum
@@ -103,11 +103,10 @@ static gboolean gst_vorbis_enc_set_format (GstAudioEncoder * enc,
     GstAudioInfo * info);
 static GstFlowReturn gst_vorbis_enc_handle_frame (GstAudioEncoder * enc,
     GstBuffer * in_buf);
-static GstCaps *gst_vorbis_enc_getcaps (GstAudioEncoder * enc);
+static GstCaps *gst_vorbis_enc_getcaps (GstAudioEncoder * enc,
+    GstCaps * filter);
 static gboolean gst_vorbis_enc_sink_event (GstAudioEncoder * enc,
     GstEvent * event);
-static GstFlowReturn gst_vorbis_enc_pre_push (GstAudioEncoder * enc,
-    GstBuffer ** buffer);
 
 static gboolean gst_vorbis_enc_setup (GstVorbisEnc * vorbisenc);
 
@@ -116,57 +115,26 @@ static void gst_vorbis_enc_get_property (GObject * object, guint prop_id,
     GValue * value, GParamSpec * pspec);
 static void gst_vorbis_enc_set_property (GObject * object, guint prop_id,
     const GValue * value, GParamSpec * pspec);
-static void gst_vorbis_enc_add_interfaces (GType vorbisenc_type);
 
-GST_BOILERPLATE_FULL (GstVorbisEnc, gst_vorbis_enc, GstAudioEncoder,
-    GST_TYPE_AUDIO_ENCODER, gst_vorbis_enc_add_interfaces);
-
-static void
-gst_vorbis_enc_add_interfaces (GType vorbisenc_type)
-{
-  static const GInterfaceInfo tag_setter_info = { NULL, NULL, NULL };
-
-  g_type_add_interface_static (vorbisenc_type, GST_TYPE_TAG_SETTER,
-      &tag_setter_info);
-}
-
-static void
-gst_vorbis_enc_base_init (gpointer g_class)
-{
-  GstElementClass *element_class = GST_ELEMENT_CLASS (g_class);
-
-  gst_element_class_add_static_pad_template (element_class,
-      &vorbis_enc_src_factory);
-  gst_element_class_add_static_pad_template (element_class,
-      &vorbis_enc_sink_factory);
-
-  gst_element_class_set_details_simple (element_class,
-      "Vorbis audio encoder", "Codec/Encoder/Audio",
-      "Encodes audio in Vorbis format",
-      "Monty <monty@xiph.org>, " "Wim Taymans <wim@fluendo.com>");
-}
+#define gst_vorbis_enc_parent_class parent_class
+G_DEFINE_TYPE_WITH_CODE (GstVorbisEnc, gst_vorbis_enc,
+    GST_TYPE_AUDIO_ENCODER, G_IMPLEMENT_INTERFACE (GST_TYPE_TAG_SETTER, NULL));
 
 static void
 gst_vorbis_enc_class_init (GstVorbisEncClass * klass)
 {
   GObjectClass *gobject_class;
+  GstElementClass *gstelement_class;
   GstAudioEncoderClass *base_class;
 
   gobject_class = (GObjectClass *) klass;
+  gstelement_class = (GstElementClass *) klass;
   base_class = (GstAudioEncoderClass *) (klass);
 
   gobject_class->set_property = gst_vorbis_enc_set_property;
   gobject_class->get_property = gst_vorbis_enc_get_property;
   gobject_class->dispose = gst_vorbis_enc_dispose;
 
-  base_class->start = GST_DEBUG_FUNCPTR (gst_vorbis_enc_start);
-  base_class->stop = GST_DEBUG_FUNCPTR (gst_vorbis_enc_stop);
-  base_class->set_format = GST_DEBUG_FUNCPTR (gst_vorbis_enc_set_format);
-  base_class->handle_frame = GST_DEBUG_FUNCPTR (gst_vorbis_enc_handle_frame);
-  base_class->getcaps = GST_DEBUG_FUNCPTR (gst_vorbis_enc_getcaps);
-  base_class->event = GST_DEBUG_FUNCPTR (gst_vorbis_enc_sink_event);
-  base_class->pre_push = GST_DEBUG_FUNCPTR (gst_vorbis_enc_pre_push);
-
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_MAX_BITRATE,
       g_param_spec_int ("max-bitrate", "Maximum Bitrate",
           "Specify a maximum bitrate (in bps). Useful for streaming "
@@ -197,10 +165,27 @@ gst_vorbis_enc_class_init (GstVorbisEncClass * klass)
       g_param_spec_string ("last-message", "last-message",
           "The last status message", NULL,
           G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
+
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&vorbis_enc_src_factory));
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&vorbis_enc_sink_factory));
+
+  gst_element_class_set_static_metadata (gstelement_class,
+      "Vorbis audio encoder", "Codec/Encoder/Audio",
+      "Encodes audio in Vorbis format",
+      "Monty <monty@xiph.org>, " "Wim Taymans <wim@fluendo.com>");
+
+  base_class->start = GST_DEBUG_FUNCPTR (gst_vorbis_enc_start);
+  base_class->stop = GST_DEBUG_FUNCPTR (gst_vorbis_enc_stop);
+  base_class->set_format = GST_DEBUG_FUNCPTR (gst_vorbis_enc_set_format);
+  base_class->handle_frame = GST_DEBUG_FUNCPTR (gst_vorbis_enc_handle_frame);
+  base_class->getcaps = GST_DEBUG_FUNCPTR (gst_vorbis_enc_getcaps);
+  base_class->sink_event = GST_DEBUG_FUNCPTR (gst_vorbis_enc_sink_event);
 }
 
 static void
-gst_vorbis_enc_init (GstVorbisEnc * vorbisenc, GstVorbisEncClass * klass)
+gst_vorbis_enc_init (GstVorbisEnc * vorbisenc)
 {
   GstAudioEncoder *enc = GST_AUDIO_ENCODER (vorbisenc);
 
@@ -239,7 +224,7 @@ gst_vorbis_enc_start (GstAudioEncoder * enc)
   GstVorbisEnc *vorbisenc = GST_VORBISENC (enc);
 
   GST_DEBUG_OBJECT (enc, "start");
-  vorbisenc->tags = gst_tag_list_new ();
+  vorbisenc->tags = gst_tag_list_new_empty ();
   vorbisenc->header_sent = FALSE;
 
   return TRUE;
@@ -258,8 +243,6 @@ gst_vorbis_enc_stop (GstAudioEncoder * enc)
   vorbisenc->last_message = NULL;
   gst_tag_list_free (vorbisenc->tags);
   vorbisenc->tags = NULL;
-  g_slist_foreach (vorbisenc->headers, (GFunc) gst_buffer_unref, NULL);
-  vorbisenc->headers = NULL;
 
   gst_tag_setter_reset_tags (GST_TAG_SETTER (enc));
 
@@ -272,60 +255,59 @@ gst_vorbis_enc_generate_sink_caps (void)
   GstCaps *caps = gst_caps_new_empty ();
   int i, c;
 
-  gst_caps_append_structure (caps, gst_structure_new ("audio/x-raw-float",
+  gst_caps_append_structure (caps, gst_structure_new ("audio/x-raw",
+          "format", G_TYPE_STRING, GST_AUDIO_NE (F32),
+          "layout", G_TYPE_STRING, "interleaved",
           "rate", GST_TYPE_INT_RANGE, 1, 200000,
-          "channels", G_TYPE_INT, 1,
-          "endianness", G_TYPE_INT, G_BYTE_ORDER, "width", G_TYPE_INT, 32,
-          NULL));
+          "channels", G_TYPE_INT, 1, NULL));
 
-  gst_caps_append_structure (caps, gst_structure_new ("audio/x-raw-float",
-          "rate", GST_TYPE_INT_RANGE, 1, 200000,
-          "channels", G_TYPE_INT, 2,
-          "endianness", G_TYPE_INT, G_BYTE_ORDER, "width", G_TYPE_INT, 32,
-          NULL));
-
-  for (i = 3; i <= 8; i++) {
-    GValue chanpos = { 0 };
-    GValue pos = { 0 };
+  for (i = 2; i <= 8; i++) {
     GstStructure *structure;
-
-    g_value_init (&chanpos, GST_TYPE_ARRAY);
-    g_value_init (&pos, GST_TYPE_AUDIO_CHANNEL_POSITION);
+    guint64 channel_mask = 0;
+    const GstAudioChannelPosition *pos = gst_vorbis_channel_positions[i - 1];
 
     for (c = 0; c < i; c++) {
-      g_value_set_enum (&pos, gst_vorbis_channel_positions[i - 1][c]);
-      gst_value_array_append_value (&chanpos, &pos);
+      channel_mask |= G_GUINT64_CONSTANT (1) << pos[c];
     }
-    g_value_unset (&pos);
 
-    structure = gst_structure_new ("audio/x-raw-float",
-        "rate", GST_TYPE_INT_RANGE, 1, 200000,
-        "channels", G_TYPE_INT, i,
-        "endianness", G_TYPE_INT, G_BYTE_ORDER, "width", G_TYPE_INT, 32, NULL);
-    gst_structure_set_value (structure, "channel-positions", &chanpos);
-    g_value_unset (&chanpos);
+    structure = gst_structure_new ("audio/x-raw",
+        "format", G_TYPE_STRING, GST_AUDIO_NE (F32),
+        "layout", G_TYPE_STRING, "interleaved",
+        "rate", GST_TYPE_INT_RANGE, 1, 200000, "channels", G_TYPE_INT, i,
+        "channel-mask", GST_TYPE_BITMASK, channel_mask, NULL);
 
     gst_caps_append_structure (caps, structure);
   }
 
-  gst_caps_append_structure (caps, gst_structure_new ("audio/x-raw-float",
+  gst_caps_append_structure (caps, gst_structure_new ("audio/x-raw",
+          "format", G_TYPE_STRING, GST_AUDIO_NE (F32),
+          "layout", G_TYPE_STRING, "interleaved",
           "rate", GST_TYPE_INT_RANGE, 1, 200000,
           "channels", GST_TYPE_INT_RANGE, 9, 255,
-          "endianness", G_TYPE_INT, G_BYTE_ORDER, "width", G_TYPE_INT, 32,
-          NULL));
+          "channel-mask", GST_TYPE_BITMASK, G_GUINT64_CONSTANT (0), NULL));
 
   return caps;
 }
 
 static GstCaps *
-gst_vorbis_enc_getcaps (GstAudioEncoder * enc)
+gst_vorbis_enc_getcaps (GstAudioEncoder * enc, GstCaps * filter)
 {
   GstVorbisEnc *vorbisenc = GST_VORBISENC (enc);
+  GstCaps *caps;
 
   if (vorbisenc->sinkcaps == NULL)
     vorbisenc->sinkcaps = gst_vorbis_enc_generate_sink_caps ();
 
-  return gst_audio_encoder_proxy_getcaps (enc, vorbisenc->sinkcaps);
+  if (filter) {
+    GstCaps *int_caps = gst_caps_intersect_full (filter, vorbisenc->sinkcaps,
+        GST_CAPS_INTERSECT_FIRST);
+    caps = gst_audio_encoder_proxy_getcaps (enc, int_caps);
+    gst_caps_unref (int_caps);
+  } else {
+    caps = gst_audio_encoder_proxy_getcaps (enc, vorbisenc->sinkcaps);
+  }
+
+  return caps;
 }
 
 static gint64
@@ -580,14 +562,14 @@ gst_vorbis_enc_buffer_from_header_packet (GstVorbisEnc * vorbisenc,
   GstBuffer *outbuf;
 
   outbuf = gst_buffer_new_and_alloc (packet->bytes);
-  memcpy (GST_BUFFER_DATA (outbuf), packet->packet, packet->bytes);
+  gst_buffer_fill (outbuf, 0, packet->packet, packet->bytes);
   GST_BUFFER_OFFSET (outbuf) = vorbisenc->bytes_out;
   GST_BUFFER_OFFSET_END (outbuf) = 0;
   GST_BUFFER_TIMESTAMP (outbuf) = GST_CLOCK_TIME_NONE;
   GST_BUFFER_DURATION (outbuf) = GST_CLOCK_TIME_NONE;
 
-  GST_DEBUG ("created header packet buffer, %d bytes",
-      GST_BUFFER_SIZE (outbuf));
+  GST_DEBUG ("created header packet buffer, %" G_GSIZE_FORMAT " bytes",
+      gst_buffer_get_size (outbuf));
   return outbuf;
 }
 
@@ -616,20 +598,7 @@ gst_vorbis_enc_sink_event (GstAudioEncoder * enc, GstEvent * event)
   }
 
   /* we only peeked, let base class handle it */
-  return FALSE;
-}
-
-/* push out the buffer and do internal bookkeeping */
-static GstFlowReturn
-gst_vorbis_enc_push_header (GstVorbisEnc * vorbisenc, GstBuffer * buffer)
-{
-  GST_DEBUG_OBJECT (vorbisenc,
-      "Pushing buffer with GP %" G_GINT64_FORMAT ", ts %" GST_TIME_FORMAT,
-      GST_BUFFER_OFFSET_END (buffer),
-      GST_TIME_ARGS (GST_BUFFER_TIMESTAMP (buffer)));
-  gst_buffer_set_caps (buffer,
-      GST_PAD_CAPS (GST_AUDIO_ENCODER_SRC_PAD (vorbisenc)));
-  return gst_pad_push (GST_AUDIO_ENCODER_SRC_PAD (vorbisenc), buffer);
+  return GST_AUDIO_ENCODER_CLASS (parent_class)->sink_event (enc, event);
 }
 
 /*
@@ -667,14 +636,14 @@ _gst_caps_set_buffer_array (GstCaps * caps, const gchar * field,
   va_start (va, buf);
   /* put buffers in a fixed list */
   while (buf) {
-    g_assert (gst_buffer_is_metadata_writable (buf));
+    g_assert (gst_buffer_is_writable (buf));
 
     /* mark buffer */
-    GST_BUFFER_FLAG_SET (buf, GST_BUFFER_FLAG_IN_CAPS);
+    GST_BUFFER_FLAG_SET (buf, GST_BUFFER_FLAG_HEADER);
 
     g_value_init (&value, GST_TYPE_BUFFER);
     buf = gst_buffer_copy (buf);
-    GST_BUFFER_FLAG_SET (buf, GST_BUFFER_FLAG_IN_CAPS);
+    GST_BUFFER_FLAG_SET (buf, GST_BUFFER_FLAG_HEADER);
     gst_value_set_buffer (&value, buf);
     gst_buffer_unref (buf);
     gst_value_array_append_value (&array, &value);
@@ -694,7 +663,8 @@ gst_vorbis_enc_handle_frame (GstAudioEncoder * enc, GstBuffer * buffer)
 {
   GstVorbisEnc *vorbisenc;
   GstFlowReturn ret = GST_FLOW_OK;
-  gfloat *data;
+  GstMapInfo map;
+  gfloat *ptr;
   gulong size;
   gulong i, j;
   float **vorbis_buffer;
@@ -726,6 +696,7 @@ gst_vorbis_enc_handle_frame (GstAudioEncoder * enc, GstBuffer * buffer)
     ogg_packet header_comm;
     ogg_packet header_code;
     GstCaps *caps;
+    GList *headers;
 
     GST_DEBUG_OBJECT (vorbisenc, "creating and sending header packets");
     gst_vorbis_enc_set_metadata (vorbisenc);
@@ -739,26 +710,24 @@ gst_vorbis_enc_handle_frame (GstAudioEncoder * enc, GstBuffer * buffer)
     buf3 = gst_vorbis_enc_buffer_from_header_packet (vorbisenc, &header_code);
 
     /* mark and put on caps */
-    caps = gst_caps_new_simple ("audio/x-vorbis", NULL);
+    caps = gst_caps_new_simple ("audio/x-vorbis",
+        "rate", G_TYPE_INT, vorbisenc->frequency,
+        "channels", G_TYPE_INT, vorbisenc->channels, NULL);
     caps = _gst_caps_set_buffer_array (caps, "streamheader",
         buf1, buf2, buf3, NULL);
 
     /* negotiate with these caps */
     GST_DEBUG_OBJECT (vorbisenc, "here are the caps: %" GST_PTR_FORMAT, caps);
-
-    gst_buffer_set_caps (buf1, caps);
-    gst_buffer_set_caps (buf2, caps);
-    gst_buffer_set_caps (buf3, caps);
-    gst_pad_set_caps (GST_AUDIO_ENCODER_SRC_PAD (vorbisenc), caps);
+    gst_audio_encoder_set_output_format (GST_AUDIO_ENCODER (vorbisenc), caps);
     gst_caps_unref (caps);
 
     /* store buffers for later pre_push sending */
-    g_slist_foreach (vorbisenc->headers, (GFunc) gst_buffer_unref, NULL);
-    vorbisenc->headers = NULL;
+    headers = NULL;
     GST_DEBUG_OBJECT (vorbisenc, "storing header buffers");
-    vorbisenc->headers = g_slist_prepend (vorbisenc->headers, buf3);
-    vorbisenc->headers = g_slist_prepend (vorbisenc->headers, buf2);
-    vorbisenc->headers = g_slist_prepend (vorbisenc->headers, buf1);
+    headers = g_list_prepend (headers, buf3);
+    headers = g_list_prepend (headers, buf2);
+    headers = g_list_prepend (headers, buf1);
+    gst_audio_encoder_set_headers (enc, headers);
 
     vorbisenc->header_sent = TRUE;
   }
@@ -766,22 +735,38 @@ gst_vorbis_enc_handle_frame (GstAudioEncoder * enc, GstBuffer * buffer)
   if (!buffer)
     return gst_vorbis_enc_clear (vorbisenc);
 
+  gst_buffer_map (buffer, &map, GST_MAP_WRITE);
+
   /* data to encode */
-  data = (gfloat *) GST_BUFFER_DATA (buffer);
-  size = GST_BUFFER_SIZE (buffer) / (vorbisenc->channels * sizeof (float));
+  size = map.size / (vorbisenc->channels * sizeof (float));
+  ptr = (gfloat *) map.data;
 
   /* expose the buffer to submit data */
   vorbis_buffer = vorbis_analysis_buffer (&vorbisenc->vd, size);
 
   /* deinterleave samples, write the buffer data */
-  for (i = 0; i < size; i++) {
-    for (j = 0; j < vorbisenc->channels; j++) {
-      vorbis_buffer[j][i] = *data++;
+  if (vorbisenc->channels < 2 || vorbisenc->channels > 8) {
+    for (i = 0; i < size; i++) {
+      for (j = 0; j < vorbisenc->channels; j++) {
+        vorbis_buffer[j][i] = *ptr++;
+      }
+    }
+  } else {
+    gint i, j;
+
+    /* Reorder */
+    for (i = 0; i < size; i++) {
+      for (j = 0; j < vorbisenc->channels; j++) {
+        vorbis_buffer[gst_vorbis_reorder_map[vorbisenc->channels - 1][j]][i] =
+            ptr[j];
+      }
+      ptr += vorbisenc->channels;
     }
   }
 
   /* tell the library how much we actually submitted */
   vorbis_analysis_wrote (&vorbisenc->vd, size);
+  gst_buffer_unmap (buffer, &map);
 
   GST_LOG_OBJECT (vorbisenc, "wrote %lu samples to vorbis", size);
 
@@ -814,7 +799,7 @@ gst_vorbis_enc_output_buffers (GstVorbisEnc * vorbisenc)
 
       GST_LOG_OBJECT (vorbisenc, "pushing out a data packet");
       buf = gst_buffer_new_and_alloc (op.bytes);
-      memcpy (GST_BUFFER_DATA (buf), op.packet, op.bytes);
+      gst_buffer_fill (buf, 0, op.packet, op.bytes);
       /* tracking granulepos should tell us samples accounted for */
       ret =
           gst_audio_encoder_finish_frame (GST_AUDIO_ENCODER
@@ -829,36 +814,6 @@ gst_vorbis_enc_output_buffers (GstVorbisEnc * vorbisenc)
   return GST_FLOW_OK;
 }
 
-static GstFlowReturn
-gst_vorbis_enc_pre_push (GstAudioEncoder * enc, GstBuffer ** buffer)
-{
-  GstVorbisEnc *vorbisenc;
-  GstFlowReturn ret = GST_FLOW_OK;
-
-  vorbisenc = GST_VORBISENC (enc);
-
-  /* FIXME 0.11 ? get rid of this special ogg stuff and have it
-   * put and use 'codec data' in caps like anything else,
-   * with all the usual out-of-band advantage etc */
-  if (G_UNLIKELY (vorbisenc->headers)) {
-    GSList *header = vorbisenc->headers;
-
-    /* try to push all of these, if we lose one, might as well lose all */
-    while (header) {
-      if (ret == GST_FLOW_OK)
-        ret = gst_vorbis_enc_push_header (vorbisenc, header->data);
-      else
-        gst_vorbis_enc_push_header (vorbisenc, header->data);
-      header = g_slist_next (header);
-    }
-
-    g_slist_free (vorbisenc->headers);
-    vorbisenc->headers = NULL;
-  }
-
-  return ret;
-}
-
 static void
 gst_vorbis_enc_get_property (GObject * object, guint prop_id, GValue * value,
     GParamSpec * pspec)
