@@ -86,6 +86,8 @@
  * happened or the state of the appsrc has gone through READY.
  *
  * Last reviewed on 2008-12-17 (0.10.10)
+ *
+ * Since: 0.10.22
  */
 
 #ifdef HAVE_CONFIG_H
@@ -100,10 +102,12 @@
 #include "gstapp-marshal.h"
 #include "gstappsrc.h"
 
+#include "gst/glib-compat-private.h"
+
 struct _GstAppSrcPrivate
 {
-  GCond cond;
-  GMutex mutex;
+  GCond *cond;
+  GMutex *mutex;
   GQueue *queue;
 
   GstCaps *caps;
@@ -112,8 +116,6 @@ struct _GstAppSrcPrivate
   guint64 max_bytes;
   GstFormat format;
   gboolean block;
-  gchar *uri;
-  gboolean new_caps;
 
   gboolean flushing;
   gboolean started;
@@ -256,7 +258,7 @@ gst_app_src_class_init (GstAppSrcClass * klass)
   gobject_class->get_property = gst_app_src_get_property;
 
   /**
-   * GstAppSrc::caps:
+   * GstAppSrc::caps
    *
    * The GstCaps that will negotiated downstream and will be put
    * on outgoing buffers.
@@ -266,7 +268,7 @@ gst_app_src_class_init (GstAppSrcClass * klass)
           "The allowed caps for the src pad", GST_TYPE_CAPS,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   /**
-   * GstAppSrc::format:
+   * GstAppSrc::format
    *
    * The format to use for segment events. When the source is producing
    * timestamped buffers this property should be set to GST_FORMAT_TIME.
@@ -276,7 +278,7 @@ gst_app_src_class_init (GstAppSrcClass * klass)
           "The format of the segment events and seek", GST_TYPE_FORMAT,
           DEFAULT_PROP_FORMAT, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   /**
-   * GstAppSrc::size:
+   * GstAppSrc::size
    *
    * The total size in bytes of the data stream. If the total size is known, it
    * is recommended to configure it with this property.
@@ -287,7 +289,7 @@ gst_app_src_class_init (GstAppSrcClass * klass)
           -1, G_MAXINT64, DEFAULT_PROP_SIZE,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   /**
-   * GstAppSrc::stream-type:
+   * GstAppSrc::stream-type
    *
    * The type of stream that this source is producing.  For seekable streams the
    * application should connect to the seek-data signal.
@@ -298,7 +300,7 @@ gst_app_src_class_init (GstAppSrcClass * klass)
           DEFAULT_PROP_STREAM_TYPE,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   /**
-   * GstAppSrc::max-bytes:
+   * GstAppSrc::max-bytes
    *
    * The maximum amount of bytes that can be queued internally.
    * After the maximum amount of bytes are queued, appsrc will emit the
@@ -310,7 +312,7 @@ gst_app_src_class_init (GstAppSrcClass * klass)
           0, G_MAXUINT64, DEFAULT_PROP_MAX_BYTES,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   /**
-   * GstAppSrc::block:
+   * GstAppSrc::block
    *
    * When max-bytes are queued and after the enough-data signal has been emitted,
    * block any further push-buffer calls until the amount of queued bytes drops
@@ -322,7 +324,7 @@ gst_app_src_class_init (GstAppSrcClass * klass)
           DEFAULT_PROP_BLOCK, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
   /**
-   * GstAppSrc::is-live:
+   * GstAppSrc::is-live
    *
    * Instruct the source to behave like a live source. This includes that it
    * will only push out buffers in the PLAYING state.
@@ -332,7 +334,7 @@ gst_app_src_class_init (GstAppSrcClass * klass)
           "Whether to act as a live source",
           DEFAULT_PROP_IS_LIVE, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   /**
-   * GstAppSrc::min-latency:
+   * GstAppSrc::min-latency
    *
    * The minimum latency of the source. A value of -1 will use the default
    * latency calculations of #GstBaseSrc.
@@ -343,7 +345,7 @@ gst_app_src_class_init (GstAppSrcClass * klass)
           -1, G_MAXINT64, DEFAULT_PROP_MIN_LATENCY,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   /**
-   * GstAppSrc::max-latency:
+   * GstAppSrc::max-latency
    *
    * The maximum latency of the source. A value of -1 means an unlimited amout
    * of latency.
@@ -355,11 +357,13 @@ gst_app_src_class_init (GstAppSrcClass * klass)
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
   /**
-   * GstAppSrc::emit-signals:
+   * GstAppSrc::emit-signals
    *
    * Make appsrc emit the "need-data", "enough-data" and "seek-data" signals.
    * This option is by default enabled for backwards compatibility reasons but
    * can disabled when needed because signal emission is expensive.
+   *
+   * Since: 0.10.23
    */
   g_object_class_install_property (gobject_class, PROP_EMIT_SIGNALS,
       g_param_spec_boolean ("emit-signals", "Emit signals",
@@ -368,10 +372,12 @@ gst_app_src_class_init (GstAppSrcClass * klass)
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
   /**
-   * GstAppSrc::empty-percent:
+   * GstAppSrc::empty-percent
    *
    * Make appsrc emit the "need-data" signal when the amount of bytes in the
    * queue drops below this percentage of max-bytes.
+   *
+   * Since: 0.10.27
    */
   g_object_class_install_property (gobject_class, PROP_MIN_PERCENT,
       g_param_spec_uint ("min-percent", "Min Percent",
@@ -458,7 +464,7 @@ gst_app_src_class_init (GstAppSrcClass * klass)
           end_of_stream), NULL, NULL, __gst_app_marshal_ENUM__VOID,
       GST_TYPE_FLOW_RETURN, 0, G_TYPE_NONE);
 
-  gst_element_class_set_metadata (element_class, "AppSrc",
+  gst_element_class_set_details_simple (element_class, "AppSrc",
       "Generic/Source", "Allow the application to feed buffers to a pipeline",
       "David Schleef <ds@schleef.org>, Wim Taymans <wim.taymans@gmail.com>");
 
@@ -492,8 +498,8 @@ gst_app_src_init (GstAppSrc * appsrc)
   priv = appsrc->priv = G_TYPE_INSTANCE_GET_PRIVATE (appsrc, GST_TYPE_APP_SRC,
       GstAppSrcPrivate);
 
-  g_mutex_init (&priv->mutex);
-  g_cond_init (&priv->cond);
+  priv->mutex = g_mutex_new ();
+  priv->cond = g_cond_new ();
   priv->queue = g_queue_new ();
 
   priv->size = DEFAULT_PROP_SIZE;
@@ -541,39 +547,17 @@ gst_app_src_finalize (GObject * obj)
   GstAppSrc *appsrc = GST_APP_SRC_CAST (obj);
   GstAppSrcPrivate *priv = appsrc->priv;
 
-  g_mutex_clear (&priv->mutex);
-  g_cond_clear (&priv->cond);
+  g_mutex_free (priv->mutex);
+  g_cond_free (priv->cond);
   g_queue_free (priv->queue);
 
-  g_free (priv->uri);
-
   G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 static GstCaps *
 gst_app_src_internal_get_caps (GstBaseSrc * bsrc, GstCaps * filter)
 {
-  GstAppSrc *appsrc = GST_APP_SRC (bsrc);
-  GstCaps *caps;
-
-  GST_OBJECT_LOCK (appsrc);
-  if ((caps = appsrc->priv->caps))
-    gst_caps_ref (caps);
-  GST_OBJECT_UNLOCK (appsrc);
-
-  if (filter) {
-    if (caps) {
-      GstCaps *intersection =
-          gst_caps_intersect_full (filter, caps, GST_CAPS_INTERSECT_FIRST);
-      gst_caps_unref (caps);
-      caps = intersection;
-    } else {
-      caps = gst_caps_ref (filter);
-    }
-  }
-
-  GST_DEBUG_OBJECT (appsrc, "caps: %" GST_PTR_FORMAT, caps);
-  return caps;
+  return gst_app_src_get_caps (GST_APP_SRC_CAST (bsrc), filter);
 }
 
 static void
@@ -635,8 +619,16 @@ gst_app_src_get_property (GObject * object, guint prop_id, GValue * value,
 
   switch (prop_id) {
     case PROP_CAPS:
-      g_value_take_boxed (value, gst_app_src_get_caps (appsrc));
+    {
+      GstCaps *caps;
+
+      /* we're missing a _take_caps() function to transfer ownership */
+      caps = gst_app_src_get_caps (appsrc, NULL);
+      gst_value_set_caps (value, caps);
+      if (caps)
+        gst_caps_unref (caps);
       break;
+    }
     case PROP_SIZE:
       g_value_set_int64 (value, gst_app_src_get_size (appsrc));
       break;
@@ -689,11 +681,11 @@ gst_app_src_unlock (GstBaseSrc * bsrc)
   GstAppSrc *appsrc = GST_APP_SRC_CAST (bsrc);
   GstAppSrcPrivate *priv = appsrc->priv;
 
-  g_mutex_lock (&priv->mutex);
+  g_mutex_lock (priv->mutex);
   GST_DEBUG_OBJECT (appsrc, "unlock start");
   priv->flushing = TRUE;
-  g_cond_broadcast (&priv->cond);
-  g_mutex_unlock (&priv->mutex);
+  g_cond_broadcast (priv->cond);
+  g_mutex_unlock (priv->mutex);
 
   return TRUE;
 }
@@ -704,11 +696,11 @@ gst_app_src_unlock_stop (GstBaseSrc * bsrc)
   GstAppSrc *appsrc = GST_APP_SRC_CAST (bsrc);
   GstAppSrcPrivate *priv = appsrc->priv;
 
-  g_mutex_lock (&priv->mutex);
+  g_mutex_lock (priv->mutex);
   GST_DEBUG_OBJECT (appsrc, "unlock stop");
   priv->flushing = FALSE;
-  g_cond_broadcast (&priv->cond);
-  g_mutex_unlock (&priv->mutex);
+  g_cond_broadcast (priv->cond);
+  g_mutex_unlock (priv->mutex);
 
   return TRUE;
 }
@@ -719,15 +711,14 @@ gst_app_src_start (GstBaseSrc * bsrc)
   GstAppSrc *appsrc = GST_APP_SRC_CAST (bsrc);
   GstAppSrcPrivate *priv = appsrc->priv;
 
-  g_mutex_lock (&priv->mutex);
+  g_mutex_lock (priv->mutex);
   GST_DEBUG_OBJECT (appsrc, "starting");
-  priv->new_caps = FALSE;
   priv->started = TRUE;
   /* set the offset to -1 so that we always do a first seek. This is only used
    * in random-access mode. */
   priv->offset = -1;
   priv->flushing = FALSE;
-  g_mutex_unlock (&priv->mutex);
+  g_mutex_unlock (priv->mutex);
 
   gst_base_src_set_format (bsrc, priv->format);
 
@@ -740,13 +731,13 @@ gst_app_src_stop (GstBaseSrc * bsrc)
   GstAppSrc *appsrc = GST_APP_SRC_CAST (bsrc);
   GstAppSrcPrivate *priv = appsrc->priv;
 
-  g_mutex_lock (&priv->mutex);
+  g_mutex_lock (priv->mutex);
   GST_DEBUG_OBJECT (appsrc, "stopping");
   priv->is_eos = FALSE;
   priv->flushing = TRUE;
   priv->started = FALSE;
   gst_app_src_flush_queued (appsrc);
-  g_mutex_unlock (&priv->mutex);
+  g_mutex_unlock (priv->mutex);
 
   return TRUE;
 }
@@ -796,12 +787,12 @@ gst_app_src_query (GstBaseSrc * src, GstQuery * query)
       res = gst_base_src_query_latency (src, &live, &min, &max);
 
       /* overwrite with our values when we need to */
-      g_mutex_lock (&priv->mutex);
+      g_mutex_lock (priv->mutex);
       if (priv->min_latency != -1)
         min = priv->min_latency;
       if (priv->max_latency != -1)
         max = priv->max_latency;
-      g_mutex_unlock (&priv->mutex);
+      g_mutex_unlock (priv->mutex);
 
       gst_query_set_latency (query, live, min, max);
       break;
@@ -853,9 +844,9 @@ gst_app_src_do_seek (GstBaseSrc * src, GstSegment * segment)
   else {
     gboolean emit;
 
-    g_mutex_lock (&priv->mutex);
+    g_mutex_lock (priv->mutex);
     emit = priv->emit_signals;
-    g_mutex_unlock (&priv->mutex);
+    g_mutex_unlock (priv->mutex);
 
     if (emit)
       g_signal_emit (appsrc, gst_app_src_signals[SIGNAL_SEEK_DATA], 0,
@@ -882,7 +873,7 @@ gst_app_src_emit_seek (GstAppSrc * appsrc, guint64 offset)
   GstAppSrcPrivate *priv = appsrc->priv;
 
   emit = priv->emit_signals;
-  g_mutex_unlock (&priv->mutex);
+  g_mutex_unlock (priv->mutex);
 
   GST_DEBUG_OBJECT (appsrc,
       "we are at %" G_GINT64_FORMAT ", seek to %" G_GINT64_FORMAT,
@@ -894,7 +885,7 @@ gst_app_src_emit_seek (GstAppSrc * appsrc, guint64 offset)
     g_signal_emit (appsrc, gst_app_src_signals[SIGNAL_SEEK_DATA], 0,
         offset, &res);
 
-  g_mutex_lock (&priv->mutex);
+  g_mutex_lock (priv->mutex);
 
   return res;
 }
@@ -908,7 +899,7 @@ gst_app_src_emit_need_data (GstAppSrc * appsrc, guint size)
   GstAppSrcPrivate *priv = appsrc->priv;
 
   emit = priv->emit_signals;
-  g_mutex_unlock (&priv->mutex);
+  g_mutex_unlock (priv->mutex);
 
   /* we have no data, we need some. We fire the signal with the size hint. */
   if (priv->callbacks.need_data)
@@ -917,43 +908,29 @@ gst_app_src_emit_need_data (GstAppSrc * appsrc, guint size)
     g_signal_emit (appsrc, gst_app_src_signals[SIGNAL_NEED_DATA], 0, size,
         NULL);
 
-  g_mutex_lock (&priv->mutex);
+  g_mutex_lock (priv->mutex);
   /* we can be flushing now because we released the lock */
 }
 
-static gboolean
-gst_app_src_do_negotiate (GstBaseSrc * basesrc)
-{
-  GstAppSrc *appsrc = GST_APP_SRC_CAST (basesrc);
-  GstAppSrcPrivate *priv = appsrc->priv;
-  gboolean result;
-  GstCaps *caps;
-
-  GST_OBJECT_LOCK (basesrc);
-  caps = priv->caps ? gst_caps_ref (priv->caps) : NULL;
-  GST_OBJECT_UNLOCK (basesrc);
-
-  if (caps) {
-    result = gst_base_src_set_caps (basesrc, caps);
-    gst_caps_unref (caps);
-  } else {
-    result = GST_BASE_SRC_CLASS (parent_class)->negotiate (basesrc);
-  }
-
-  return result;
-}
-
 static gboolean
 gst_app_src_negotiate (GstBaseSrc * basesrc)
 {
   GstAppSrc *appsrc = GST_APP_SRC_CAST (basesrc);
   GstAppSrcPrivate *priv = appsrc->priv;
+  GstCaps *caps;
   gboolean result;
 
-  g_mutex_lock (&priv->mutex);
-  result = gst_app_src_do_negotiate (basesrc);
-  priv->new_caps = FALSE;
-  g_mutex_unlock (&priv->mutex);
+  GST_OBJECT_LOCK (appsrc);
+  if ((caps = priv->caps))
+    gst_caps_ref (caps);
+  GST_OBJECT_UNLOCK (appsrc);
+
+  if (caps) {
+    result = gst_base_src_set_caps (basesrc, caps);
+    gst_caps_unref (caps);
+  } else {
+    result = GST_BASE_SRC_CLASS (parent_class)->negotiate (basesrc);
+  }
   return result;
 }
 
@@ -975,12 +952,13 @@ gst_app_src_create (GstBaseSrc * bsrc, guint64 offset, guint size,
     GST_OBJECT_UNLOCK (appsrc);
 
     gst_element_post_message (GST_ELEMENT (appsrc),
-        gst_message_new_duration_changed (GST_OBJECT (appsrc)));
+        gst_message_new_duration (GST_OBJECT (appsrc), GST_FORMAT_BYTES,
+            priv->size));
   } else {
     GST_OBJECT_UNLOCK (appsrc);
   }
 
-  g_mutex_lock (&priv->mutex);
+  g_mutex_lock (priv->mutex);
   /* check flushing first */
   if (G_UNLIKELY (priv->flushing))
     goto flushing;
@@ -1012,10 +990,6 @@ gst_app_src_create (GstBaseSrc * bsrc, guint64 offset, guint size,
       buf_size = gst_buffer_get_size (*buf);
 
       GST_DEBUG_OBJECT (appsrc, "we have buffer %p of size %u", *buf, buf_size);
-      if (priv->new_caps) {
-        gst_app_src_do_negotiate (bsrc);
-        priv->new_caps = FALSE;
-      }
 
       priv->queued_bytes -= buf_size;
 
@@ -1024,7 +998,7 @@ gst_app_src_create (GstBaseSrc * bsrc, guint64 offset, guint size,
         priv->offset += buf_size;
 
       /* signal that we removed an item */
-      g_cond_broadcast (&priv->cond);
+      g_cond_broadcast (priv->cond);
 
       /* see if we go lower than the empty-percent */
       if (priv->min_percent && priv->max_bytes) {
@@ -1058,27 +1032,27 @@ gst_app_src_create (GstBaseSrc * bsrc, guint64 offset, guint size,
       goto eos;
 
     /* nothing to return, wait a while for new data or flushing. */
-    g_cond_wait (&priv->cond, &priv->mutex);
+    g_cond_wait (priv->cond, priv->mutex);
   }
-  g_mutex_unlock (&priv->mutex);
+  g_mutex_unlock (priv->mutex);
   return ret;
 
   /* ERRORS */
 flushing:
   {
     GST_DEBUG_OBJECT (appsrc, "we are flushing");
-    g_mutex_unlock (&priv->mutex);
+    g_mutex_unlock (priv->mutex);
     return GST_FLOW_FLUSHING;
   }
 eos:
   {
     GST_DEBUG_OBJECT (appsrc, "we are EOS");
-    g_mutex_unlock (&priv->mutex);
+    g_mutex_unlock (priv->mutex);
     return GST_FLOW_EOS;
   }
 seek_error:
   {
-    g_mutex_unlock (&priv->mutex);
+    g_mutex_unlock (priv->mutex);
     GST_ELEMENT_ERROR (appsrc, RESOURCE, READ, ("failed to seek"),
         GST_ERROR_SYSTEM);
     return GST_FLOW_ERROR;
@@ -1096,6 +1070,8 @@ seek_error:
  * a copy of the caps structure. After calling this method, the source will
  * only produce caps that match @caps. @caps must be fixed and the caps on the
  * buffers must match the caps or left NULL.
+ *
+ * Since: 0.10.22
  */
 void
 gst_app_src_set_caps (GstAppSrc * appsrc, const GstCaps * caps)
@@ -1116,9 +1092,6 @@ gst_app_src_set_caps (GstAppSrc * appsrc, const GstCaps * caps)
       priv->caps = NULL;
     if (old)
       gst_caps_unref (old);
-    g_mutex_lock (&priv->mutex);
-    priv->new_caps = TRUE;
-    g_mutex_unlock (&priv->mutex);
   }
   GST_OBJECT_UNLOCK (appsrc);
 }
@@ -1130,13 +1103,37 @@ gst_app_src_set_caps (GstAppSrc * appsrc, const GstCaps * caps)
  * Get the configured caps on @appsrc.
  *
  * Returns: the #GstCaps produced by the source. gst_caps_unref() after usage.
+ *
+ * Since: 0.10.22
  */
 GstCaps *
-gst_app_src_get_caps (GstAppSrc * appsrc)
+gst_app_src_get_caps (GstAppSrc * appsrc, GstCaps * filter)
 {
+  GstCaps *caps;
+  GstAppSrcPrivate *priv;
+
   g_return_val_if_fail (GST_IS_APP_SRC (appsrc), NULL);
 
-  return gst_app_src_internal_get_caps (GST_BASE_SRC_CAST (appsrc), NULL);
+  priv = appsrc->priv;
+
+  GST_OBJECT_LOCK (appsrc);
+  if ((caps = priv->caps))
+    gst_caps_ref (caps);
+
+  if (filter) {
+    if (caps) {
+      GstCaps *intersection =
+          gst_caps_intersect_full (filter, caps, GST_CAPS_INTERSECT_FIRST);
+      gst_caps_unref (caps);
+      caps = intersection;
+    } else {
+      caps = gst_caps_ref (filter);
+    }
+  }
+  GST_DEBUG_OBJECT (appsrc, "getting caps of %" GST_PTR_FORMAT, caps);
+  GST_OBJECT_UNLOCK (appsrc);
+
+  return caps;
 }
 
 /**
@@ -1146,6 +1143,8 @@ gst_app_src_get_caps (GstAppSrc * appsrc)
  *
  * Set the size of the stream in bytes. A value of -1 means that the size is
  * not known.
+ *
+ * Since: 0.10.22
  */
 void
 gst_app_src_set_size (GstAppSrc * appsrc, gint64 size)
@@ -1170,6 +1169,8 @@ gst_app_src_set_size (GstAppSrc * appsrc, gint64 size)
  * not known.
  *
  * Returns: the size of the stream previously set with gst_app_src_set_size();
+ *
+ * Since: 0.10.22
  */
 gint64
 gst_app_src_get_size (GstAppSrc * appsrc)
@@ -1198,6 +1199,8 @@ gst_app_src_get_size (GstAppSrc * appsrc)
  * be connected to.
  *
  * A stream_type stream
+ *
+ * Since: 0.10.22
  */
 void
 gst_app_src_set_stream_type (GstAppSrc * appsrc, GstAppStreamType type)
@@ -1222,6 +1225,8 @@ gst_app_src_set_stream_type (GstAppSrc * appsrc, GstAppStreamType type)
  * with gst_app_src_set_stream_type().
  *
  * Returns: the stream type.
+ *
+ * Since: 0.10.22
  */
 GstAppStreamType
 gst_app_src_get_stream_type (GstAppSrc * appsrc)
@@ -1249,6 +1254,8 @@ gst_app_src_get_stream_type (GstAppSrc * appsrc)
  * Set the maximum amount of bytes that can be queued in @appsrc.
  * After the maximum amount of bytes are queued, @appsrc will emit the
  * "enough-data" signal.
+ *
+ * Since: 0.10.22
  */
 void
 gst_app_src_set_max_bytes (GstAppSrc * appsrc, guint64 max)
@@ -1259,14 +1266,14 @@ gst_app_src_set_max_bytes (GstAppSrc * appsrc, guint64 max)
 
   priv = appsrc->priv;
 
-  g_mutex_lock (&priv->mutex);
+  g_mutex_lock (priv->mutex);
   if (max != priv->max_bytes) {
     GST_DEBUG_OBJECT (appsrc, "setting max-bytes to %" G_GUINT64_FORMAT, max);
     priv->max_bytes = max;
     /* signal the change */
-    g_cond_broadcast (&priv->cond);
+    g_cond_broadcast (priv->cond);
   }
-  g_mutex_unlock (&priv->mutex);
+  g_mutex_unlock (priv->mutex);
 }
 
 /**
@@ -1276,6 +1283,8 @@ gst_app_src_set_max_bytes (GstAppSrc * appsrc, guint64 max)
  * Get the maximum amount of bytes that can be queued in @appsrc.
  *
  * Returns: The maximum amount of bytes that can be queued.
+ *
+ * Since: 0.10.22
  */
 guint64
 gst_app_src_get_max_bytes (GstAppSrc * appsrc)
@@ -1287,10 +1296,10 @@ gst_app_src_get_max_bytes (GstAppSrc * appsrc)
 
   priv = appsrc->priv;
 
-  g_mutex_lock (&priv->mutex);
+  g_mutex_lock (priv->mutex);
   result = priv->max_bytes;
   GST_DEBUG_OBJECT (appsrc, "getting max-bytes of %" G_GUINT64_FORMAT, result);
-  g_mutex_unlock (&priv->mutex);
+  g_mutex_unlock (priv->mutex);
 
   return result;
 }
@@ -1302,7 +1311,7 @@ gst_app_src_set_latencies (GstAppSrc * appsrc, gboolean do_min, guint64 min,
   GstAppSrcPrivate *priv = appsrc->priv;
   gboolean changed = FALSE;
 
-  g_mutex_lock (&priv->mutex);
+  g_mutex_lock (priv->mutex);
   if (do_min && priv->min_latency != min) {
     priv->min_latency = min;
     changed = TRUE;
@@ -1311,7 +1320,7 @@ gst_app_src_set_latencies (GstAppSrc * appsrc, gboolean do_min, guint64 min,
     priv->max_latency = max;
     changed = TRUE;
   }
-  g_mutex_unlock (&priv->mutex);
+  g_mutex_unlock (priv->mutex);
 
   if (changed) {
     GST_DEBUG_OBJECT (appsrc, "posting latency changed");
@@ -1328,6 +1337,8 @@ gst_app_src_set_latencies (GstAppSrc * appsrc, gboolean do_min, guint64 min,
  *
  * Configure the @min and @max latency in @src. If @min is set to -1, the
  * default latency calculations for pseudo-live sources will be used.
+ *
+ * Since: 0.10.22
  */
 void
 gst_app_src_set_latency (GstAppSrc * appsrc, guint64 min, guint64 max)
@@ -1342,6 +1353,8 @@ gst_app_src_set_latency (GstAppSrc * appsrc, guint64 min, guint64 max)
  * @max: the min latency
  *
  * Retrieve the min and max latencies in @min and @max respectively.
+ *
+ * Since: 0.10.22
  */
 void
 gst_app_src_get_latency (GstAppSrc * appsrc, guint64 * min, guint64 * max)
@@ -1352,12 +1365,12 @@ gst_app_src_get_latency (GstAppSrc * appsrc, guint64 * min, guint64 * max)
 
   priv = appsrc->priv;
 
-  g_mutex_lock (&priv->mutex);
+  g_mutex_lock (priv->mutex);
   if (min)
     *min = priv->min_latency;
   if (max)
     *max = priv->max_latency;
-  g_mutex_unlock (&priv->mutex);
+  g_mutex_unlock (priv->mutex);
 }
 
 /**
@@ -1368,6 +1381,8 @@ gst_app_src_get_latency (GstAppSrc * appsrc, guint64 * min, guint64 * max)
  * Make appsrc emit the "new-preroll" and "new-buffer" signals. This option is
  * by default disabled because signal emission is expensive and unneeded when
  * the application prefers to operate in pull mode.
+ *
+ * Since: 0.10.23
  */
 void
 gst_app_src_set_emit_signals (GstAppSrc * appsrc, gboolean emit)
@@ -1378,9 +1393,9 @@ gst_app_src_set_emit_signals (GstAppSrc * appsrc, gboolean emit)
 
   priv = appsrc->priv;
 
-  g_mutex_lock (&priv->mutex);
+  g_mutex_lock (priv->mutex);
   priv->emit_signals = emit;
-  g_mutex_unlock (&priv->mutex);
+  g_mutex_unlock (priv->mutex);
 }
 
 /**
@@ -1391,6 +1406,8 @@ gst_app_src_set_emit_signals (GstAppSrc * appsrc, gboolean emit)
  *
  * Returns: %TRUE if @appsrc is emitting the "new-preroll" and "new-buffer"
  * signals.
+ *
+ * Since: 0.10.23
  */
 gboolean
 gst_app_src_get_emit_signals (GstAppSrc * appsrc)
@@ -1402,9 +1419,9 @@ gst_app_src_get_emit_signals (GstAppSrc * appsrc)
 
   priv = appsrc->priv;
 
-  g_mutex_lock (&priv->mutex);
+  g_mutex_lock (priv->mutex);
   result = priv->emit_signals;
-  g_mutex_unlock (&priv->mutex);
+  g_mutex_unlock (priv->mutex);
 
   return result;
 }
@@ -1421,7 +1438,7 @@ gst_app_src_push_buffer_full (GstAppSrc * appsrc, GstBuffer * buffer,
 
   priv = appsrc->priv;
 
-  g_mutex_lock (&priv->mutex);
+  g_mutex_lock (priv->mutex);
 
   while (TRUE) {
     /* can't accept buffers when we are flushing or EOS */
@@ -1441,7 +1458,7 @@ gst_app_src_push_buffer_full (GstAppSrc * appsrc, GstBuffer * buffer,
 
         emit = priv->emit_signals;
         /* only signal on the first push */
-        g_mutex_unlock (&priv->mutex);
+        g_mutex_unlock (priv->mutex);
 
         if (priv->callbacks.enough_data)
           priv->callbacks.enough_data (appsrc, priv->user_data);
@@ -1449,7 +1466,7 @@ gst_app_src_push_buffer_full (GstAppSrc * appsrc, GstBuffer * buffer,
           g_signal_emit (appsrc, gst_app_src_signals[SIGNAL_ENOUGH_DATA], 0,
               NULL);
 
-        g_mutex_lock (&priv->mutex);
+        g_mutex_lock (priv->mutex);
         /* continue to check for flushing/eos after releasing the lock */
         first = FALSE;
         continue;
@@ -1458,7 +1475,7 @@ gst_app_src_push_buffer_full (GstAppSrc * appsrc, GstBuffer * buffer,
         GST_DEBUG_OBJECT (appsrc, "waiting for free space");
         /* we are filled, wait until a buffer gets popped or when we
          * flush. */
-        g_cond_wait (&priv->cond, &priv->mutex);
+        g_cond_wait (priv->cond, priv->mutex);
       } else {
         /* no need to wait for free space, we just pump more data into the
          * queue hoping that the caller reacts to the enough-data signal and
@@ -1474,8 +1491,8 @@ gst_app_src_push_buffer_full (GstAppSrc * appsrc, GstBuffer * buffer,
     gst_buffer_ref (buffer);
   g_queue_push_tail (priv->queue, buffer);
   priv->queued_bytes += gst_buffer_get_size (buffer);
-  g_cond_broadcast (&priv->cond);
-  g_mutex_unlock (&priv->mutex);
+  g_cond_broadcast (priv->cond);
+  g_mutex_unlock (priv->mutex);
 
   return GST_FLOW_OK;
 
@@ -1485,7 +1502,7 @@ flushing:
     GST_DEBUG_OBJECT (appsrc, "refuse buffer %p, we are flushing", buffer);
     if (steal_ref)
       gst_buffer_unref (buffer);
-    g_mutex_unlock (&priv->mutex);
+    g_mutex_unlock (priv->mutex);
     return GST_FLOW_FLUSHING;
   }
 eos:
@@ -1493,7 +1510,7 @@ eos:
     GST_DEBUG_OBJECT (appsrc, "refuse buffer %p, we are EOS", buffer);
     if (steal_ref)
       gst_buffer_unref (buffer);
-    g_mutex_unlock (&priv->mutex);
+    g_mutex_unlock (priv->mutex);
     return GST_FLOW_EOS;
   }
 }
@@ -1512,6 +1529,8 @@ eos:
  * Returns: #GST_FLOW_OK when the buffer was successfuly queued.
  * #GST_FLOW_FLUSHING when @appsrc is not PAUSED or PLAYING.
  * #GST_FLOW_EOS when EOS occured.
+ *
+ * Since: 0.10.22
  */
 GstFlowReturn
 gst_app_src_push_buffer (GstAppSrc * appsrc, GstBuffer * buffer)
@@ -1536,6 +1555,8 @@ gst_app_src_push_buffer_action (GstAppSrc * appsrc, GstBuffer * buffer)
  *
  * Returns: #GST_FLOW_OK when the EOS was successfuly queued.
  * #GST_FLOW_FLUSHING when @appsrc is not PAUSED or PLAYING.
+ *
+ * Since: 0.10.22
  */
 GstFlowReturn
 gst_app_src_end_of_stream (GstAppSrc * appsrc)
@@ -1546,7 +1567,7 @@ gst_app_src_end_of_stream (GstAppSrc * appsrc)
 
   priv = appsrc->priv;
 
-  g_mutex_lock (&priv->mutex);
+  g_mutex_lock (priv->mutex);
   /* can't accept buffers when we are flushing. We can accept them when we are
    * EOS although it will not do anything. */
   if (priv->flushing)
@@ -1554,22 +1575,22 @@ gst_app_src_end_of_stream (GstAppSrc * appsrc)
 
   GST_DEBUG_OBJECT (appsrc, "sending EOS");
   priv->is_eos = TRUE;
-  g_cond_broadcast (&priv->cond);
-  g_mutex_unlock (&priv->mutex);
+  g_cond_broadcast (priv->cond);
+  g_mutex_unlock (priv->mutex);
 
   return GST_FLOW_OK;
 
   /* ERRORS */
 flushing:
   {
-    g_mutex_unlock (&priv->mutex);
+    g_mutex_unlock (priv->mutex);
     GST_DEBUG_OBJECT (appsrc, "refuse EOS, we are flushing");
     return GST_FLOW_FLUSHING;
   }
 }
 
 /**
- * gst_app_src_set_callbacks: (skip)
+ * gst_app_src_set_callbacks:
  * @appsrc: a #GstAppSrc
  * @callbacks: the callbacks
  * @user_data: a user_data argument for the callbacks
@@ -1582,6 +1603,8 @@ flushing:
  *
  * If callbacks are installed, no signals will be emitted for performance
  * reasons.
+ *
+ * Since: 0.10.23
  */
 void
 gst_app_src_set_callbacks (GstAppSrc * appsrc,
@@ -1636,20 +1659,14 @@ gst_app_src_uri_get_protocols (GType type)
 static gchar *
 gst_app_src_uri_get_uri (GstURIHandler * handler)
 {
-  GstAppSrc *appsrc = GST_APP_SRC (handler);
-
-  return appsrc->priv->uri ? g_strdup (appsrc->priv->uri) : NULL;
+  return g_strdup ("appsrc");
 }
 
 static gboolean
 gst_app_src_uri_set_uri (GstURIHandler * handler, const gchar * uri,
     GError ** error)
 {
-  GstAppSrc *appsrc = GST_APP_SRC (handler);
-
-  g_free (appsrc->priv->uri);
-  appsrc->priv->uri = uri ? g_strdup (uri) : NULL;
-
+  /* GstURIHandler checks the protocol for us */
   return TRUE;
 }
 
