@@ -35,6 +35,7 @@ G_BEGIN_DECLS
   (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_APP_SRC))
 #define GST_IS_APP_SRC_CLASS(klass) \
   (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_APP_SRC))
+/* Since 0.10.23 */
 #define GST_APP_SRC_CAST(obj) \
   ((GstAppSrc*)(obj))
 
@@ -56,6 +57,8 @@ typedef struct _GstAppSrcPrivate GstAppSrcPrivate;
  *
  * A set of callbacks that can be installed on the appsrc with
  * gst_app_src_set_callbacks().
+ *
+ * Since: 0.10.23
  */
 typedef struct {
   void      (*need_data)    (GstAppSrc *src, guint length, gpointer user_data);
@@ -100,13 +103,13 @@ struct _GstAppSrcClass
   GstBaseSrcClass basesrc_class;
 
   /* signals */
-  void          (*need_data)       (GstAppSrc *appsrc, guint length);
-  void          (*enough_data)     (GstAppSrc *appsrc);
-  gboolean      (*seek_data)       (GstAppSrc *appsrc, guint64 offset);
+  void          (*need_data)       (GstAppSrc *src, guint length);
+  void          (*enough_data)     (GstAppSrc *src);
+  gboolean      (*seek_data)       (GstAppSrc *src, guint64 offset);
 
   /* actions */
-  GstFlowReturn (*push_buffer)     (GstAppSrc *appsrc, GstBuffer *buffer);
-  GstFlowReturn (*end_of_stream)   (GstAppSrc *appsrc);
+  GstFlowReturn (*push_buffer)     (GstAppSrc *src, GstBuffer *buffer);
+  GstFlowReturn (*end_of_stream)   (GstAppSrc *src);
 
   /*< private >*/
   gpointer     _gst_reserved[GST_PADDING];
@@ -114,12 +117,12 @@ struct _GstAppSrcClass
 
 GType gst_app_src_get_type(void);
 
-/* GType getter for GstAppStreamType */
+/* GType getter for GstAppStreamType, since 0.10.32 */
 #define GST_TYPE_APP_STREAM_TYPE (gst_app_stream_type_get_type ())
 GType gst_app_stream_type_get_type (void);
 
 void             gst_app_src_set_caps         (GstAppSrc *appsrc, const GstCaps *caps);
-GstCaps*         gst_app_src_get_caps         (GstAppSrc *appsrc);
+GstCaps*         gst_app_src_get_caps         (GstAppSrc *appsrc, GstCaps * filter);
 
 void             gst_app_src_set_size         (GstAppSrc *appsrc, gint64 size);
 gint64           gst_app_src_get_size         (GstAppSrc *appsrc);
