@@ -165,15 +165,13 @@ gst_audio_base_src_class_init (GstAudioBaseSrcClass * klass)
 
   g_object_class_install_property (gobject_class, PROP_BUFFER_TIME,
       g_param_spec_int64 ("buffer-time", "Buffer Time",
-          "Size of audio buffer in microseconds, this is the maximum amount "
-          "of data that is buffered in the device and the maximum latency that "
-          "the source reports", 1, G_MAXINT64, DEFAULT_BUFFER_TIME,
+          "Size of audio buffer in microseconds", 1,
+          G_MAXINT64, DEFAULT_BUFFER_TIME,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
   g_object_class_install_property (gobject_class, PROP_LATENCY_TIME,
       g_param_spec_int64 ("latency-time", "Latency Time",
-          "The minimum amount of data to read in each iteration in microseconds, "
-          "this is the minimum latency that the source reports", 1,
+          "Audio latency in microseconds", 1,
           G_MAXINT64, DEFAULT_LATENCY_TIME,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
@@ -181,6 +179,8 @@ gst_audio_base_src_class_init (GstAudioBaseSrcClass * klass)
    * GstAudioBaseSrc:actual-buffer-time:
    *
    * Actual configured size of audio buffer in microseconds.
+   *
+   * Since: 0.10.20
    **/
   g_object_class_install_property (gobject_class, PROP_ACTUAL_BUFFER_TIME,
       g_param_spec_int64 ("actual-buffer-time", "Actual Buffer Time",
@@ -192,6 +192,8 @@ gst_audio_base_src_class_init (GstAudioBaseSrcClass * klass)
    * GstAudioBaseSrc:actual-latency-time:
    *
    * Actual configured audio latency in microseconds.
+   *
+   * Since: 0.10.20
    **/
   g_object_class_install_property (gobject_class, PROP_ACTUAL_LATENCY_TIME,
       g_param_spec_int64 ("actual-latency-time", "Actual Latency Time",
@@ -291,11 +293,10 @@ gst_audio_base_src_provide_clock (GstElement * elem)
   if (src->ringbuffer == NULL)
     goto wrong_state;
 
-  if (gst_audio_ring_buffer_is_flushing (src->ringbuffer))
+  if (!gst_audio_ring_buffer_is_acquired (src->ringbuffer))
     goto wrong_state;
 
   GST_OBJECT_LOCK (src);
-
   if (!GST_OBJECT_FLAG_IS_SET (src, GST_ELEMENT_FLAG_PROVIDE_CLOCK))
     goto clock_disabled;
 
@@ -307,7 +308,7 @@ gst_audio_base_src_provide_clock (GstElement * elem)
   /* ERRORS */
 wrong_state:
   {
-    GST_DEBUG_OBJECT (src, "ringbuffer is flushing");
+    GST_DEBUG_OBJECT (src, "ringbuffer not acquired");
     return NULL;
   }
 clock_disabled:
@@ -356,6 +357,8 @@ gst_audio_base_src_get_time (GstClock * clock, GstAudioBaseSrc * src)
  * Controls whether @src will provide a clock or not. If @provide is %TRUE, 
  * gst_element_provide_clock() will return a clock that reflects the datarate
  * of @src. If @provide is %FALSE, gst_element_provide_clock() will return NULL.
+ *
+ * Since: 0.10.16
  */
 void
 gst_audio_base_src_set_provide_clock (GstAudioBaseSrc * src, gboolean provide)
@@ -378,6 +381,8 @@ gst_audio_base_src_set_provide_clock (GstAudioBaseSrc * src, gboolean provide)
  * gst_audio_base_src_set_provide_clock.
  *
  * Returns: %TRUE if @src will provide a clock.
+ *
+ * Since: 0.10.16
  */
 gboolean
 gst_audio_base_src_get_provide_clock (GstAudioBaseSrc * src)
@@ -399,6 +404,8 @@ gst_audio_base_src_get_provide_clock (GstAudioBaseSrc * src)
  * @method: the new slave method
  *
  * Controls how clock slaving will be performed in @src.
+ *
+ * Since: 0.10.20
  */
 void
 gst_audio_base_src_set_slave_method (GstAudioBaseSrc * src,
@@ -418,6 +425,8 @@ gst_audio_base_src_set_slave_method (GstAudioBaseSrc * src,
  * Get the current slave method used by @src.
  *
  * Returns: The current slave method used by @src.
+ *
+ * Since: 0.10.20
  */
 GstAudioBaseSrcSlaveMethod
 gst_audio_base_src_get_slave_method (GstAudioBaseSrc * src)
@@ -762,9 +771,7 @@ gst_audio_base_src_create (GstBaseSrc * bsrc, guint64 offset, guint length,
   GstAudioRingBufferSpec *spec;
   guint read;
   GstClockTime timestamp, duration;
-  GstClockTime rb_timestamp = GST_CLOCK_TIME_NONE;
   GstClock *clock;
-  gboolean first;
 
   ringbuffer = src->ringbuffer;
   spec = &ringbuffer->spec;
@@ -808,16 +815,8 @@ gst_audio_base_src_create (GstBaseSrc * bsrc, guint64 offset, guint length,
 
   gst_buffer_map (buf, &info, GST_MAP_WRITE);
   ptr = info.data;
-  first = TRUE;
   do {
-    GstClockTime tmp_ts;
-
-    read =
-        gst_audio_ring_buffer_read (ringbuffer, sample, ptr, samples, &tmp_ts);
-    if (first && GST_CLOCK_TIME_IS_VALID (tmp_ts)) {
-      first = FALSE;
-      rb_timestamp = tmp_ts;
-    }
+    read = gst_audio_ring_buffer_read (ringbuffer, sample, ptr, samples);
     GST_DEBUG_OBJECT (src, "read %u of %u", read, samples);
     /* if we read all, we're done */
     if (read == samples)
@@ -997,13 +996,8 @@ gst_audio_base_src_create (GstBaseSrc * bsrc, guint64 offset, guint length,
   } else {
     GstClockTime base_time;
 
-    if (GST_CLOCK_TIME_IS_VALID (rb_timestamp)) {
-      /* the read method returned a timestamp so we use this instead */
-      timestamp = rb_timestamp;
-    } else {
-      /* to get the timestamp against the clock we also need to add our offset */
-      timestamp = gst_audio_clock_adjust (clock, timestamp);
-    }
+    /* to get the timestamp against the clock we also need to add our offset */
+    timestamp = gst_audio_clock_adjust (clock, timestamp);
 
     /* we are not slaved, subtract base_time */
     base_time = GST_ELEMENT_CAST (src)->base_time;
@@ -1032,9 +1026,6 @@ no_sync:
 
   *outbuf = buf;
 
-  GST_LOG_OBJECT (src, "Pushed buffer timestamp %" GST_TIME_FORMAT,
-      GST_TIME_ARGS (GST_BUFFER_TIMESTAMP (buf)));
-
   return GST_FLOW_OK;
 
   /* ERRORS */
@@ -1071,7 +1062,7 @@ stopped:
  * ::create_ringbuffer vmethod and will set @src as the parent of the returned
  * buffer (see gst_object_set_parent()).
  *
- * Returns: (transfer none): The new ringbuffer of @src.
+ * Returns: The new ringbuffer of @src.
  */
 GstAudioRingBuffer *
 gst_audio_base_src_create_ringbuffer (GstAudioBaseSrc * src)
