@@ -25,6 +25,7 @@
  * SECTION:gstaudiodecoder
  * @short_description: Base class for audio decoders
  * @see_also: #GstBaseTransform
+ * @since: 0.10.36
  *
  * This base class is for audio decoders turning encoded data into
  * raw audio samples.
@@ -184,7 +185,6 @@ typedef struct _GstAudioDecoderContext
   /* input */
   /* (output) audio format */
   GstAudioInfo info;
-  gboolean output_format_changed;
 
   /* parsing state */
   gboolean eos;
@@ -200,9 +200,6 @@ typedef struct _GstAudioDecoderContext
   /* MT-protected (with LOCK) */
   GstClockTime min_latency;
   GstClockTime max_latency;
-
-  GstAllocator *allocator;
-  GstAllocationParams params;
 } GstAudioDecoderContext;
 
 struct _GstAudioDecoderPrivate
@@ -233,8 +230,6 @@ struct _GstAudioDecoderPrivate
   gboolean drained;
   /* subclass currently being forcibly drained */
   gboolean force;
-  /* need to handle changed input caps */
-  gboolean do_caps;
 
   /* input bps estimatation */
   /* global in bytes seen */
@@ -247,7 +242,6 @@ struct _GstAudioDecoderPrivate
   gint error_count;
   /* codec id tag */
   GstTagList *taglist;
-  gboolean taglist_changed;
 
   /* whether circumstances allow output aggregation */
   gint agg;
@@ -305,12 +299,6 @@ static gboolean gst_audio_decoder_sink_query (GstPad * pad, GstObject * parent,
     GstQuery * query);
 static void gst_audio_decoder_reset (GstAudioDecoder * dec, gboolean full);
 
-static gboolean gst_audio_decoder_decide_allocation_default (GstAudioDecoder *
-    dec, GstQuery * query);
-static gboolean gst_audio_decoder_propose_allocation_default (GstAudioDecoder *
-    dec, GstQuery * query);
-static gboolean gst_audio_decoder_negotiate_default (GstAudioDecoder * dec);
-
 static GstElementClass *parent_class = NULL;
 
 static void gst_audio_decoder_class_init (GstAudioDecoderClass * klass);
@@ -391,12 +379,6 @@ gst_audio_decoder_class_init (GstAudioDecoderClass * klass)
       GST_DEBUG_FUNCPTR (gst_audio_decoder_sink_eventfunc);
   audiodecoder_class->src_event =
       GST_DEBUG_FUNCPTR (gst_audio_decoder_src_eventfunc);
-  audiodecoder_class->propose_allocation =
-      GST_DEBUG_FUNCPTR (gst_audio_decoder_propose_allocation_default);
-  audiodecoder_class->decide_allocation =
-      GST_DEBUG_FUNCPTR (gst_audio_decoder_decide_allocation_default);
-  audiodecoder_class->negotiate =
-      GST_DEBUG_FUNCPTR (gst_audio_decoder_negotiate_default);
 }
 
 static void
@@ -478,7 +460,6 @@ gst_audio_decoder_reset (GstAudioDecoder * dec, gboolean full)
       gst_tag_list_free (dec->priv->taglist);
       dec->priv->taglist = NULL;
     }
-    dec->priv->taglist_changed = FALSE;
 
     gst_segment_init (&dec->input_segment, GST_FORMAT_TIME);
     gst_segment_init (&dec->output_segment, GST_FORMAT_TIME);
@@ -486,10 +467,6 @@ gst_audio_decoder_reset (GstAudioDecoder * dec, gboolean full)
     g_list_foreach (dec->priv->pending_events, (GFunc) gst_event_unref, NULL);
     g_list_free (dec->priv->pending_events);
     dec->priv->pending_events = NULL;
-
-    if (dec->priv->ctx.allocator)
-      gst_object_unref (dec->priv->ctx.allocator);
-    dec->priv->ctx.allocator = NULL;
   }
 
   g_queue_foreach (&dec->priv->frames, (GFunc) gst_buffer_unref, NULL);
@@ -529,100 +506,6 @@ gst_audio_decoder_finalize (GObject * object)
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
-static gboolean
-gst_audio_decoder_negotiate_default (GstAudioDecoder * dec)
-{
-  GstAudioDecoderClass *klass;
-  gboolean res = TRUE;
-  GstCaps *caps = NULL;
-  GstQuery *query = NULL;
-  GstAllocator *allocator;
-  GstAllocationParams params;
-
-  g_return_val_if_fail (GST_IS_AUDIO_DECODER (dec), FALSE);
-  g_return_val_if_fail (GST_AUDIO_INFO_IS_VALID (&dec->priv->ctx.info), FALSE);
-
-  klass = GST_AUDIO_DECODER_GET_CLASS (dec);
-
-  GST_DEBUG_OBJECT (dec, "setting src caps %" GST_PTR_FORMAT, caps);
-
-  caps = gst_audio_info_to_caps (&dec->priv->ctx.info);
-
-  res = gst_pad_set_caps (dec->srcpad, caps);
-  if (!res)
-    goto done;
-  dec->priv->ctx.output_format_changed = FALSE;
-
-  query = gst_query_new_allocation (caps, TRUE);
-  if (!gst_pad_peer_query (dec->srcpad, query)) {
-    GST_DEBUG_OBJECT (dec, "didn't get downstream ALLOCATION hints");
-  }
-
-  g_assert (klass->decide_allocation != NULL);
-  res = klass->decide_allocation (dec, query);
-
-  GST_DEBUG_OBJECT (dec, "ALLOCATION (%d) params: %" GST_PTR_FORMAT, res,
-      query);
-
-  if (!res)
-    goto no_decide_allocation;
-
-  /* we got configuration from our peer or the decide_allocation method,
-   * parse them */
-  if (gst_query_get_n_allocation_params (query) > 0) {
-    gst_query_parse_nth_allocation_param (query, 0, &allocator, &params);
-  } else {
-    allocator = NULL;
-    gst_allocation_params_init (&params);
-  }
-
-  if (dec->priv->ctx.allocator)
-    gst_object_unref (dec->priv->ctx.allocator);
-  dec->priv->ctx.allocator = allocator;
-  dec->priv->ctx.params = params;
-
-done:
-
-  if (query)
-    gst_query_unref (query);
-  gst_caps_unref (caps);
-
-  return res;
-
-  /* ERRORS */
-no_decide_allocation:
-  {
-    GST_WARNING_OBJECT (dec, "Subclass failed to decide allocation");
-    goto done;
-  }
-}
-
-/**
- * gst_audio_decoder_negotiate:
- * @dec: a #GstAudioDecoder
- *
- * Negotiate with downstreame elements to currently configured #GstAudioInfo.
- *
- * Returns: #TRUE if the negotiation succeeded, else #FALSE.
- */
-gboolean
-gst_audio_decoder_negotiate (GstAudioDecoder * dec)
-{
-  GstAudioDecoderClass *klass;
-  gboolean res = TRUE;
-
-  g_return_val_if_fail (GST_IS_AUDIO_DECODER (dec), FALSE);
-
-  klass = GST_AUDIO_DECODER_GET_CLASS (dec);
-
-  GST_AUDIO_DECODER_STREAM_LOCK (dec);
-  if (klass->negotiate)
-    res = klass->negotiate (dec);
-  GST_AUDIO_DECODER_STREAM_UNLOCK (dec);
-
-  return res;
-}
-
 /**
  * gst_audio_decoder_set_output_format:
  * @dec: a #GstAudioDecoder
@@ -638,12 +521,9 @@ gst_audio_decoder_set_output_format (GstAudioDecoder * dec,
 {
   gboolean res = TRUE;
   guint old_rate;
-  GstCaps *caps = NULL;
+  GstCaps *caps;
   GstCaps *templ_caps;
 
-  g_return_val_if_fail (GST_IS_AUDIO_DECODER (dec), FALSE);
-  g_return_val_if_fail (GST_AUDIO_INFO_IS_VALID (info), FALSE);
-
   GST_DEBUG_OBJECT (dec, "Setting output format");
 
   GST_AUDIO_DECODER_STREAM_LOCK (dec);
@@ -657,8 +537,6 @@ gst_audio_decoder_set_output_format (GstAudioDecoder * dec,
   /* Only allow caps that are a subset of the template caps */
   templ_caps = gst_pad_get_pad_template_caps (dec->srcpad);
   if (!gst_caps_is_subset (caps, templ_caps)) {
-    GST_WARNING_OBJECT (dec, "Requested output format %" GST_PTR_FORMAT
-        " do not match template %" GST_PTR_FORMAT, caps, templ_caps);
     gst_caps_unref (caps);
     gst_caps_unref (templ_caps);
     goto refuse_caps;
@@ -675,14 +553,15 @@ gst_audio_decoder_set_output_format (GstAudioDecoder * dec,
 
   /* copy the GstAudioInfo */
   dec->priv->ctx.info = *info;
-  dec->priv->ctx.output_format_changed = TRUE;
 
-done:
+  GST_DEBUG_OBJECT (dec, "setting src caps %" GST_PTR_FORMAT, caps);
+
   GST_AUDIO_DECODER_STREAM_UNLOCK (dec);
 
-  if (caps)
-    gst_caps_unref (caps);
+  res = gst_pad_set_caps (dec->srcpad, caps);
+  gst_caps_unref (caps);
 
+done:
   return res;
 
   /* ERRORS */
@@ -708,12 +587,11 @@ gst_audio_decoder_sink_setcaps (GstAudioDecoder * dec, GstCaps * caps)
   /* NOTE pbutils only needed here */
   /* TODO maybe (only) upstream demuxer/parser etc should handle this ? */
 #if 0
-  if (!dec->priv->taglist)
-    dec->priv->taglist = gst_tag_list_new ();
-  dec->priv->taglist = gst_tag_list_make_writable (dec->priv->taglist);
+  if (dec->priv->taglist)
+    gst_tag_list_free (dec->priv->taglist);
+  dec->priv->taglist = gst_tag_list_new ();
   gst_pb_utils_add_codec_description_to_tag_list (dec->priv->taglist,
       GST_TAG_AUDIO_CODEC, caps);
-  dec->priv->taglist_changed = TRUE;
 #endif
 
   if (klass->set_format)
@@ -925,21 +803,6 @@ gst_audio_decoder_push_event (GstAudioDecoder * dec, GstEvent * event)
   return gst_pad_push_event (dec->srcpad, event);
 }
 
-static void
-send_pending_events (GstAudioDecoder * dec)
-{
-  GstAudioDecoderPrivate *priv = dec->priv;
-  GList *pending_events, *l;
-
-  pending_events = priv->pending_events;
-  priv->pending_events = NULL;
-
-  GST_DEBUG_OBJECT (dec, "Pushing pending events");
-  for (l = pending_events; l; l = l->next)
-    gst_audio_decoder_push_event (dec, l->data);
-  g_list_free (pending_events);
-}
-
 /**
  * gst_audio_decoder_finish_frame:
  * @dec: a #GstAudioDecoder
@@ -958,6 +821,8 @@ send_pending_events (GstAudioDecoder * dec)
  * invalidated by a call to this function.
  *
  * Returns: a #GstFlowReturn that should be escalated to caller (of caller)
+ *
+ * Since: 0.10.36
  */
 GstFlowReturn
 gst_audio_decoder_finish_frame (GstAudioDecoder * dec, GstBuffer * buf,
@@ -970,6 +835,9 @@ gst_audio_decoder_finish_frame (GstAudioDecoder * dec, GstBuffer * buf,
   gsize size;
   GstFlowReturn ret = GST_FLOW_OK;
 
+  /* subclass should know what it is producing by now */
+  g_return_val_if_fail (buf == NULL || gst_pad_has_current_caps (dec->srcpad),
+      GST_FLOW_ERROR);
   /* subclass should not hand us no data */
   g_return_val_if_fail (buf == NULL || gst_buffer_get_size (buf) > 0,
       GST_FLOW_ERROR);
@@ -991,17 +859,16 @@ gst_audio_decoder_finish_frame (GstAudioDecoder * dec, GstBuffer * buf,
 
   GST_AUDIO_DECODER_STREAM_LOCK (dec);
 
-  if (buf && G_UNLIKELY (ctx->output_format_changed ||
-          (GST_AUDIO_INFO_IS_VALID (&ctx->info)
-              && gst_pad_check_reconfigure (dec->srcpad)))) {
-    if (!gst_audio_decoder_negotiate (dec)) {
-      ret = GST_FLOW_NOT_NEGOTIATED;
-      goto exit;
-    }
-  }
+  if (priv->pending_events) {
+    GList *pending_events, *l;
 
-  if (buf && priv->pending_events) {
-    send_pending_events (dec);
+    pending_events = priv->pending_events;
+    priv->pending_events = NULL;
+
+    GST_DEBUG_OBJECT (dec, "Pushing pending events");
+    for (l = pending_events; l; l = l->next)
+      gst_audio_decoder_push_event (dec, l->data);
+    g_list_free (pending_events);
   }
 
   /* output shoud be whole number of sample frames */
@@ -1080,12 +947,14 @@ gst_audio_decoder_finish_frame (GstAudioDecoder * dec, GstBuffer * buf,
   }
 
   /* delayed one-shot stuff until confirmed data */
-  if (priv->taglist && priv->taglist_changed) {
+  if (priv->taglist) {
     GST_DEBUG_OBJECT (dec, "codec tag %" GST_PTR_FORMAT, priv->taglist);
-    if (!gst_tag_list_is_empty (priv->taglist))
-      gst_audio_decoder_push_event (dec,
-          gst_event_new_tag (gst_tag_list_ref (priv->taglist)));
-    priv->taglist_changed = FALSE;
+    if (gst_tag_list_is_empty (priv->taglist)) {
+      gst_tag_list_free (priv->taglist);
+    } else {
+      gst_audio_decoder_push_event (dec, gst_event_new_tag (priv->taglist));
+    }
+    priv->taglist = NULL;
   }
 
   buf = gst_buffer_make_writable (buf);
@@ -1568,18 +1437,6 @@ gst_audio_decoder_chain (GstPad * pad, GstObject * parent, GstBuffer * buffer)
 
   dec = GST_AUDIO_DECODER (parent);
 
-  if (G_UNLIKELY (dec->priv->do_caps)) {
-    GstCaps *caps = gst_pad_get_current_caps (dec->sinkpad);
-    if (caps) {
-      if (!gst_audio_decoder_sink_setcaps (dec, caps)) {
-        gst_caps_unref (caps);
-        goto not_negotiated;
-      }
-      gst_caps_unref (caps);
-    }
-    dec->priv->do_caps = FALSE;
-  }
-
   if (G_UNLIKELY (!gst_pad_has_current_caps (pad) && dec->priv->needs_format))
     goto not_negotiated;
 
@@ -1690,6 +1547,29 @@ gst_audio_decoder_sink_eventfunc (GstAudioDecoder * dec, GstEvent * event)
       /* finish current segment */
       gst_audio_decoder_drain (dec);
 
+#if 0
+      if (update) {
+        /* time progressed without data, see if we can fill the gap with
+         * some concealment data */
+        GST_DEBUG_OBJECT (dec,
+            "segment update: plc %d, do_plc %d, position %" GST_TIME_FORMAT,
+            dec->priv->plc, dec->priv->ctx.do_plc,
+            GST_TIME_ARGS (dec->input_segment.position));
+        if (dec->priv->plc && dec->priv->ctx.do_plc &&
+            dec->input_segment.rate > 0.0
+            && dec->input_segment.position < start) {
+          GstAudioDecoderClass *klass;
+          GstBuffer *buf;
+
+          klass = GST_AUDIO_DECODER_GET_CLASS (dec);
+          /* hand subclass empty frame with duration that needs covering */
+          buf = gst_buffer_new ();
+          GST_BUFFER_DURATION (buf) = start - dec->input_segment.position;
+          /* best effort, not much error handling */
+          gst_audio_decoder_handle_frame (dec, klass, buf);
+        }
+      } else
+#endif
       {
         /* prepare for next one */
         gst_audio_decoder_flush (dec, FALSE);
@@ -1711,39 +1591,7 @@ gst_audio_decoder_sink_eventfunc (GstAudioDecoder * dec, GstEvent * event)
       ret = TRUE;
       break;
     }
-    case GST_EVENT_GAP:{
-      GstClockTime timestamp, duration;
-      gst_event_parse_gap (event, &timestamp, &duration);
 
-      /* time progressed without data, see if we can fill the gap with
-       * some concealment data */
-      GST_DEBUG_OBJECT (dec,
-          "gap event: plc %d, do_plc %d, position %" GST_TIME_FORMAT
-          " duration %" GST_TIME_FORMAT,
-          dec->priv->plc, dec->priv->ctx.do_plc,
-          GST_TIME_ARGS (timestamp), GST_TIME_ARGS (duration));
-      if (dec->priv->plc && dec->priv->ctx.do_plc &&
-          dec->input_segment.rate > 0.0) {
-        GstAudioDecoderClass *klass;
-        GstBuffer *buf;
-
-        klass = GST_AUDIO_DECODER_GET_CLASS (dec);
-        /* hand subclass empty frame with duration that needs covering */
-        buf = gst_buffer_new ();
-        GST_BUFFER_TIMESTAMP (buf) = timestamp;
-        GST_BUFFER_DURATION (buf) = duration;
-        /* best effort, not much error handling */
-        gst_audio_decoder_handle_frame (dec, klass, buf);
-        ret = TRUE;
-        gst_event_unref (event);
-      } else {
-        /* FIXME: sub-class doesn't know how to handle empty buffers,
-         * so just try sending GAP downstream */
-        send_pending_events (dec);
-        ret = gst_audio_decoder_push_event (dec, event);
-      }
-      break;
-    }
     case GST_EVENT_FLUSH_STOP:
       GST_AUDIO_DECODER_STREAM_LOCK (dec);
       /* prepare for fresh start */
@@ -1774,34 +1622,16 @@ gst_audio_decoder_sink_eventfunc (GstAudioDecoder * dec, GstEvent * event)
       GstCaps *caps;
 
       gst_event_parse_caps (event, &caps);
-      ret = TRUE;
-      dec->priv->do_caps = TRUE;
+      gst_audio_decoder_sink_setcaps (dec, caps);
       gst_event_unref (event);
+      ret = TRUE;
       break;
     }
-    case GST_EVENT_TAG:
-    {
-      GstTagList *tags;
-
-      gst_event_parse_tag (event, &tags);
-
-      if (gst_tag_list_get_scope (tags) == GST_TAG_SCOPE_STREAM) {
-        gst_audio_decoder_merge_tags (dec, tags, GST_TAG_MERGE_REPLACE);
-        gst_event_unref (event);
-        event = NULL;
-        ret = TRUE;
-        break;
-      }
-
-      /* fall through */
-    }
     default:
       if (!GST_EVENT_IS_SERIALIZED (event)) {
         ret =
             gst_pad_event_default (dec->sinkpad, GST_OBJECT_CAST (dec), event);
       } else {
-        GST_DEBUG_OBJECT (dec, "Enqueuing event %d, %s", GST_EVENT_TYPE (event),
-            GST_EVENT_TYPE_NAME (event));
         GST_AUDIO_DECODER_STREAM_LOCK (dec);
         dec->priv->pending_events =
             g_list_append (dec->priv->pending_events, event);
@@ -1905,12 +1735,12 @@ gst_audio_decoder_src_eventfunc (GstAudioDecoder * dec, GstEvent * event)
       GstFormat format;
       gdouble rate;
       GstSeekFlags flags;
-      GstSeekType start_type, stop_type;
-      gint64 start, stop;
-      gint64 tstart, tstop;
+      GstSeekType cur_type, stop_type;
+      gint64 cur, stop;
+      gint64 tcur, tstop;
       guint32 seqnum;
 
-      gst_event_parse_seek (event, &rate, &format, &flags, &start_type, &start,
+      gst_event_parse_seek (event, &rate, &format, &flags, &cur_type, &cur,
           &stop_type, &stop);
       seqnum = gst_event_get_seqnum (event);
 
@@ -1928,8 +1758,8 @@ gst_audio_decoder_src_eventfunc (GstAudioDecoder * dec, GstEvent * event)
       /* ... though a non-time seek can be aided as well */
       /* First bring the requested format to time */
       if (!(res =
-              gst_pad_query_convert (dec->srcpad, format, start,
-                  GST_FORMAT_TIME, &tstart)))
+              gst_pad_query_convert (dec->srcpad, format, cur, GST_FORMAT_TIME,
+                  &tcur)))
         goto convert_error;
       if (!(res =
               gst_pad_query_convert (dec->srcpad, format, stop, GST_FORMAT_TIME,
@@ -1938,7 +1768,7 @@ gst_audio_decoder_src_eventfunc (GstAudioDecoder * dec, GstEvent * event)
 
       /* then seek with time on the peer */
       event = gst_event_new_seek (rate, GST_FORMAT_TIME,
-          flags, start_type, tstart, stop_type, tstop);
+          flags, cur_type, tcur, stop_type, tstop);
       gst_event_set_seqnum (event, seqnum);
 
       res = gst_pad_push_event (dec->sinkpad, event);
@@ -1982,43 +1812,6 @@ gst_audio_decoder_src_event (GstPad * pad, GstObject * parent, GstEvent * event)
   return ret;
 }
 
-static gboolean
-gst_audio_decoder_decide_allocation_default (GstAudioDecoder * dec,
-    GstQuery * query)
-{
-  GstAllocator *allocator = NULL;
-  GstAllocationParams params;
-  gboolean update_allocator;
-
-  /* we got configuration from our peer or the decide_allocation method,
-   * parse them */
-  if (gst_query_get_n_allocation_params (query) > 0) {
-    /* try the allocator */
-    gst_query_parse_nth_allocation_param (query, 0, &allocator, &params);
-    update_allocator = TRUE;
-  } else {
-    allocator = NULL;
-    gst_allocation_params_init (&params);
-    update_allocator = FALSE;
-  }
-
-  if (update_allocator)
-    gst_query_set_nth_allocation_param (query, 0, allocator, &params);
-  else
-    gst_query_add_allocation_param (query, allocator, &params);
-  if (allocator)
-    gst_object_unref (allocator);
-
-  return TRUE;
-}
-
-static gboolean
-gst_audio_decoder_propose_allocation_default (GstAudioDecoder * dec,
-    GstQuery * query)
-{
-  return TRUE;
-}
-
 /*
  * gst_audio_encoded_audio_convert:
  * @fmt: audio format of the encoded audio
@@ -2121,14 +1914,6 @@ gst_audio_decoder_sink_query (GstPad * pad, GstObject * parent,
       gst_query_set_convert (query, src_fmt, src_val, dest_fmt, dest_val);
       break;
     }
-    case GST_QUERY_ALLOCATION:
-    {
-      GstAudioDecoderClass *klass = GST_AUDIO_DECODER_GET_CLASS (dec);
-
-      if (klass->propose_allocation)
-        res = klass->propose_allocation (dec, query);
-      break;
-    }
     case GST_QUERY_SEEKING:
     {
       GstFormat format;
@@ -2465,6 +2250,8 @@ _gst_audio_decoder_error (GstAudioDecoder * dec, gint weight,
  * @dec: a #GstAudioDecoder
  *
  * Returns: a #GstAudioInfo describing the input audio format
+ *
+ * Since: 0.10.36
  */
 GstAudioInfo *
 gst_audio_decoder_get_audio_info (GstAudioDecoder * dec)
@@ -2480,6 +2267,8 @@ gst_audio_decoder_get_audio_info (GstAudioDecoder * dec)
  * @plc: new plc state
  *
  * Indicates whether or not subclass handles packet loss concealment (plc).
+ *
+ * Since: 0.10.36
  */
 void
 gst_audio_decoder_set_plc_aware (GstAudioDecoder * dec, gboolean plc)
@@ -2494,6 +2283,8 @@ gst_audio_decoder_set_plc_aware (GstAudioDecoder * dec, gboolean plc)
  * @dec: a #GstAudioDecoder
  *
  * Returns: currently configured plc handling
+ *
+ * Since: 0.10.36
  */
 gint
 gst_audio_decoder_get_plc_aware (GstAudioDecoder * dec)
@@ -2509,6 +2300,8 @@ gst_audio_decoder_get_plc_aware (GstAudioDecoder * dec)
  * @enabled: whether to enable byte to time conversion
  *
  * Allows baseclass to perform byte to time estimated conversion.
+ *
+ * Since: 0.10.36
  */
 void
 gst_audio_decoder_set_estimate_rate (GstAudioDecoder * dec, gboolean enabled)
@@ -2523,6 +2316,8 @@ gst_audio_decoder_set_estimate_rate (GstAudioDecoder * dec, gboolean enabled)
  * @dec: a #GstAudioDecoder
  *
  * Returns: currently configured byte to time conversion setting
+ *
+ * Since: 0.10.36
  */
 gint
 gst_audio_decoder_get_estimate_rate (GstAudioDecoder * dec)
@@ -2537,6 +2332,8 @@ gst_audio_decoder_get_estimate_rate (GstAudioDecoder * dec)
  * @dec: a #GstAudioDecoder
  *
  * Returns: currently configured decoder delay
+ *
+ * Since: 0.10.36
  */
 gint
 gst_audio_decoder_get_delay (GstAudioDecoder * dec)
@@ -2554,6 +2351,8 @@ gst_audio_decoder_get_delay (GstAudioDecoder * dec)
  * Sets numbers of tolerated decoder errors, where a tolerated one is then only
  * warned about, but more than tolerated will lead to fatal error.  Default
  * is set to GST_AUDIO_DECODER_MAX_ERRORS.
+ *
+ * Since: 0.10.36
  */
 void
 gst_audio_decoder_set_max_errors (GstAudioDecoder * dec, gint num)
@@ -2568,6 +2367,8 @@ gst_audio_decoder_set_max_errors (GstAudioDecoder * dec, gint num)
  * @dec: a #GstAudioDecoder
  *
  * Returns: currently configured decoder tolerated error count.
+ *
+ * Since: 0.10.36
  */
 gint
 gst_audio_decoder_get_max_errors (GstAudioDecoder * dec)
@@ -2584,6 +2385,8 @@ gst_audio_decoder_get_max_errors (GstAudioDecoder * dec)
  * @max: maximum latency
  *
  * Sets decoder latency.
+ *
+ * Since: 0.10.36
  */
 void
 gst_audio_decoder_set_latency (GstAudioDecoder * dec,
@@ -2605,6 +2408,8 @@ gst_audio_decoder_set_latency (GstAudioDecoder * dec,
  *
  * Sets the variables pointed to by @min and @max to the currently configured
  * latency.
+ *
+ * Since: 0.10.36
  */
 void
 gst_audio_decoder_get_latency (GstAudioDecoder * dec,
@@ -2627,6 +2432,8 @@ gst_audio_decoder_get_latency (GstAudioDecoder * dec,
  * @eos: a pointer to a variable to hold the current eos state
  *
  * Return current parsing (sync and eos) state.
+ *
+ * Since: 0.10.36
  */
 void
 gst_audio_decoder_get_parse_state (GstAudioDecoder * dec,
@@ -2649,6 +2456,8 @@ gst_audio_decoder_get_parse_state (GstAudioDecoder * dec,
  * and codec are capable and allow handling plc.
  *
  * MT safe.
+ *
+ * Since: 0.10.36
  */
 void
 gst_audio_decoder_set_plc (GstAudioDecoder * dec, gboolean enabled)
@@ -2671,6 +2480,8 @@ gst_audio_decoder_set_plc (GstAudioDecoder * dec, gboolean enabled)
  * Returns: TRUE if packet loss concealment is enabled.
  *
  * MT safe.
+ *
+ * Since: 0.10.36
  */
 gboolean
 gst_audio_decoder_get_plc (GstAudioDecoder * dec)
@@ -2694,9 +2505,11 @@ gst_audio_decoder_get_plc (GstAudioDecoder * dec)
  * Sets decoder minimum aggregation latency.
  *
  * MT safe.
+ *
+ * Since: 0.10.36
  */
 void
-gst_audio_decoder_set_min_latency (GstAudioDecoder * dec, GstClockTime num)
+gst_audio_decoder_set_min_latency (GstAudioDecoder * dec, gint64 num)
 {
   g_return_if_fail (GST_IS_AUDIO_DECODER (dec));
 
@@ -2714,11 +2527,13 @@ gst_audio_decoder_set_min_latency (GstAudioDecoder * dec, GstClockTime num)
  * Returns: aggregation latency.
  *
  * MT safe.
+ *
+ * Since: 0.10.36
  */
-GstClockTime
+gint64
 gst_audio_decoder_get_min_latency (GstAudioDecoder * dec)
 {
-  GstClockTime result;
+  gint64 result;
 
   g_return_val_if_fail (GST_IS_AUDIO_DECODER (dec), FALSE);
 
@@ -2737,9 +2552,11 @@ gst_audio_decoder_get_min_latency (GstAudioDecoder * dec)
  * Configures decoder audio jitter tolerance threshold.
  *
  * MT safe.
+ *
+ * Since: 0.10.36
  */
 void
-gst_audio_decoder_set_tolerance (GstAudioDecoder * dec, GstClockTime tolerance)
+gst_audio_decoder_set_tolerance (GstAudioDecoder * dec, gint64 tolerance)
 {
   g_return_if_fail (GST_IS_AUDIO_DECODER (dec));
 
@@ -2757,11 +2574,13 @@ gst_audio_decoder_set_tolerance (GstAudioDecoder * dec, GstClockTime tolerance)
  * Returns: decoder audio jitter tolerance threshold.
  *
  * MT safe.
+ *
+ * Since: 0.10.36
  */
-GstClockTime
+gint64
 gst_audio_decoder_get_tolerance (GstAudioDecoder * dec)
 {
-  GstClockTime result;
+  gint64 result;
 
   g_return_val_if_fail (GST_IS_AUDIO_DECODER (dec), 0);
 
@@ -2783,6 +2602,8 @@ gst_audio_decoder_get_tolerance (GstAudioDecoder * dec)
  * real data.
  *
  * MT safe.
+ *
+ * Since: 0.10.36
  */
 void
 gst_audio_decoder_set_drainable (GstAudioDecoder * dec, gboolean enabled)
@@ -2803,6 +2624,8 @@ gst_audio_decoder_set_drainable (GstAudioDecoder * dec, gboolean enabled)
  * Returns: TRUE if drainable handling is enabled.
  *
  * MT safe.
+ *
+ * Since: 0.10.36
  */
 gboolean
 gst_audio_decoder_get_drainable (GstAudioDecoder * dec)
@@ -2831,6 +2654,8 @@ gst_audio_decoder_get_drainable (GstAudioDecoder * dec)
  * or based on the input data.
  *
  * MT safe.
+ *
+ * Since: 0.10.36
  */
 void
 gst_audio_decoder_set_needs_format (GstAudioDecoder * dec, gboolean enabled)
@@ -2851,6 +2676,8 @@ gst_audio_decoder_set_needs_format (GstAudioDecoder * dec, gboolean enabled)
  * Returns: TRUE if required format handling is enabled.
  *
  * MT safe.
+ *
+ * Since: 0.10.36
  */
 gboolean
 gst_audio_decoder_get_needs_format (GstAudioDecoder * dec)
@@ -2881,6 +2708,8 @@ gst_audio_decoder_get_needs_format (GstAudioDecoder * dec)
  * of the usual CODEC/AUDIO_CODEC tags.
  *
  * MT safe.
+ *
+ * Since: 0.10.37
  */
 void
 gst_audio_decoder_merge_tags (GstAudioDecoder * dec,
@@ -2897,72 +2726,6 @@ gst_audio_decoder_merge_tags (GstAudioDecoder * dec,
   otags = dec->priv->taglist;
   dec->priv->taglist = gst_tag_list_merge (dec->priv->taglist, tags, mode);
   if (otags)
-    gst_tag_list_unref (otags);
-  dec->priv->taglist_changed = TRUE;
+    gst_tag_list_free (otags);
   GST_AUDIO_DECODER_STREAM_UNLOCK (dec);
 }
-
-/**
- * gst_audio_decoder_allocate_output_buffer:
- * @dec: a #GstAudioDecoder
- * @size: size of the buffer
- *
- * Helper function that allocates a buffer to hold an audio frame
- * for @dec's current output format.
- *
- * Returns: (transfer full): allocated buffer
- */
-GstBuffer *
-gst_audio_decoder_allocate_output_buffer (GstAudioDecoder * dec, gsize size)
-{
-  GstBuffer *buffer = NULL;
-
-  g_return_val_if_fail (size > 0, NULL);
-
-  GST_DEBUG ("alloc src buffer");
-
-  GST_AUDIO_DECODER_STREAM_LOCK (dec);
-
-  if (G_UNLIKELY (dec->priv->ctx.output_format_changed ||
-          (GST_AUDIO_INFO_IS_VALID (&dec->priv->ctx.info)
-              && gst_pad_check_reconfigure (dec->srcpad)))) {
-    if (!gst_audio_decoder_negotiate (dec))
-      goto done;
-  }
-
-  buffer =
-      gst_buffer_new_allocate (dec->priv->ctx.allocator, size,
-      &dec->priv->ctx.params);
-
-done:
-  GST_AUDIO_DECODER_STREAM_UNLOCK (dec);
-
-  return buffer;
-}
-
-/**
- * gst_audio_decoder_get_allocator:
- * @dec: a #GstAudioDecoder
- * @allocator: (out) (allow-none) (transfer full): the #GstAllocator
- * used
- * @params: (out) (allow-none) (transfer full): the
- * #GstAllocatorParams of @allocator
- *
- * Lets #GstAudioDecoder sub-classes to know the memory @allocator
- * used by the base class and its @params.
- *
- * Unref the @allocator after use it.
- */
-void
-gst_audio_decoder_get_allocator (GstAudioDecoder * dec,
-    GstAllocator ** allocator, GstAllocationParams * params)
-{
-  g_return_if_fail (GST_IS_AUDIO_DECODER (dec));
-
-  if (allocator)
-    *allocator = dec->priv->ctx.allocator ?
-        gst_object_ref (dec->priv->ctx.allocator) : NULL;
-
-  if (params)
-    *params = dec->priv->ctx.params;
-}
