@@ -22,6 +22,7 @@
 /**
  * SECTION:gstaudioiec61937
  * @short_description: Utility functions for IEC 61937 payloading
+ * @since: 0.10.36
  *
  * This module contains some helper functions for encapsulating various
  * audio formats in IEC 61937 headers and padding.
@@ -67,6 +68,8 @@ caps_get_string_field (const GstCaps * caps, const gchar * field)
  *
  * Returns: the size or 0 if the given @type is not supported or cannot be
  * payloaded.
+ *
+ * Since: 0.10.36
  */
 guint
 gst_audio_iec61937_frame_size (const GstAudioRingBufferSpec * spec)
@@ -128,10 +131,10 @@ gst_audio_iec61937_frame_size (const GstAudioRingBufferSpec * spec)
 
 /**
  * gst_audio_iec61937_payload:
- * @src: (array length=src_n): a buffer containing the data to payload
+ * @src: a buffer containing the data to payload
  * @src_n: size of @src in bytes
- * @dst: (array length=dst_n): the destination buffer to store the
- *       payloaded contents in. Should not overlap with @src
+ * @dst: the destination buffer to store the payloaded contents in. Should not
+ *       overlap with @src
  * @dst_n: size of @dst in bytes
  * @spec: the ringbufer spec for @src
  *
@@ -141,6 +144,8 @@ gst_audio_iec61937_frame_size (const GstAudioRingBufferSpec * spec)
  *
  * Returns: transfer-full: %TRUE if the payloading was successful, %FALSE
  * otherwise.
+ *
+ * Since: 0.10.36
  */
 gboolean
 gst_audio_iec61937_payload (const guint8 * src, guint src_n, guint8 * dst,
@@ -231,10 +236,9 @@ gst_audio_iec61937_payload (const guint8 * src, guint src_n, guint8 * dst,
        *     bit  0-4  - data type (11 = type I, 12 = type II,
        *                            13 = type III) */
       dst[five] = 11 + (blocksize / 1024);
-      /* Pd: bit 15-0  - frame size, in bits (for type I-III) */
-      tmp = src_n * 8;
-      dst[six] = ((guint16) tmp) >> 8;
-      dst[seven] = ((guint16) tmp) & 0xff;
+      /* Pd: bit 15-0  - frame size in bytes */
+      dst[six] = ((guint16) src_n) >> 8;
+      dst[seven] = ((guint16) src_n) & 0xff;
       break;
     }
 
