@@ -67,9 +67,6 @@ gst_discoverer_stream_info_finalize (GObject * object)
   if (info->tags)
     gst_tag_list_free (info->tags);
 
-  if (info->toc)
-    gst_toc_unref (info->toc);
-
   if (info->misc)
     gst_structure_free (info->misc);
 }
@@ -129,9 +126,6 @@ gst_discoverer_info_copy_int (GstDiscovererStreamInfo * info,
   if (info->tags)
     ret->tags = gst_tag_list_copy (info->tags);
 
-  if (info->toc)
-    ret->toc = gst_toc_ref (info->toc);
-
   if (info->misc)
     ret->misc = gst_structure_copy (info->misc);
 
@@ -367,9 +361,6 @@ gst_discoverer_info_finalize (GObject * object)
 
   if (info->tags)
     gst_tag_list_free (info->tags);
-
-  if (info->toc)
-    gst_toc_unref (info->toc);
 }
 
 static GstDiscovererInfo *
@@ -421,9 +412,6 @@ gst_discoverer_info_copy (GstDiscovererInfo * ptr)
   if (ptr->tags)
     ret->tags = gst_tag_list_copy (ptr->tags);
 
-  if (ptr->toc)
-    ret->toc = gst_toc_ref (ptr->toc);
-
   g_hash_table_destroy (stream_map);
   return ret;
 }
@@ -462,6 +450,8 @@ gst_discoverer_stream_info_list_free (GList * infos)
  * Returns: (transfer full) (element-type GstPbutils.DiscovererStreamInfo): A #GList of
  * matching #GstDiscovererStreamInfo. The caller should free it with
  * gst_discoverer_stream_info_list_free().
+ *
+ * Since: 0.10.31
  */
 GList *
 gst_discoverer_info_get_streams (GstDiscovererInfo * info, GType streamtype)
@@ -487,6 +477,8 @@ gst_discoverer_info_get_streams (GstDiscovererInfo * info, GType streamtype)
  * Returns: (transfer full) (element-type GstPbutils.DiscovererStreamInfo): A #GList of
  * matching #GstDiscovererStreamInfo. The caller should free it with
  * gst_discoverer_stream_info_list_free().
+ *
+ * Since: 0.10.31
  */
 GList *
 gst_discoverer_info_get_audio_streams (GstDiscovererInfo * info)
@@ -503,6 +495,8 @@ gst_discoverer_info_get_audio_streams (GstDiscovererInfo * info)
  * Returns: (transfer full) (element-type GstPbutils.DiscovererStreamInfo): A #GList of
  * matching #GstDiscovererStreamInfo. The caller should free it with
  * gst_discoverer_stream_info_list_free().
+ *
+ * Since: 0.10.31
  */
 GList *
 gst_discoverer_info_get_video_streams (GstDiscovererInfo * info)
@@ -519,6 +513,8 @@ gst_discoverer_info_get_video_streams (GstDiscovererInfo * info)
  * Returns: (transfer full) (element-type GstPbutils.DiscovererStreamInfo): A #GList of
  * matching #GstDiscovererStreamInfo. The caller should free it with
  * gst_discoverer_stream_info_list_free().
+ *
+ * Since: 0.10.36
  */
 GList *
 gst_discoverer_info_get_subtitle_streams (GstDiscovererInfo * info)
@@ -536,6 +532,8 @@ gst_discoverer_info_get_subtitle_streams (GstDiscovererInfo * info)
  * Returns: (transfer full) (element-type GstPbutils.DiscovererStreamInfo): A #GList of
  * matching #GstDiscovererStreamInfo. The caller should free it with
  * gst_discoverer_stream_info_list_free().
+ *
+ * Since: 0.10.31
  */
 GList *
 gst_discoverer_info_get_container_streams (GstDiscovererInfo * info)
@@ -550,6 +548,8 @@ gst_discoverer_info_get_container_streams (GstDiscovererInfo * info)
  *
  * Returns: a human readable name for the stream type of the given @info (ex : "audio",
  * "container",...).
+ *
+ * Since: 0.10.31
  */
 const gchar *
 gst_discoverer_stream_info_get_stream_type_nick (GstDiscovererStreamInfo * info)
@@ -586,6 +586,8 @@ gst_discoverer_stream_info_get_stream_type_nick (GstDiscovererStreamInfo * info)
  * Returns: (transfer full): the previous #GstDiscovererStreamInfo in a chain.
  * %NULL for starting points. Unref with #gst_discoverer_stream_info_unref
  * after usage.
+ *
+ * Since: 0.10.31
  */
 GstDiscovererStreamInfo *
 gst_discoverer_stream_info_get_previous (GstDiscovererStreamInfo * info)
@@ -604,6 +606,8 @@ gst_discoverer_stream_info_get_previous (GstDiscovererStreamInfo * info)
  * Returns: (transfer full): the next #GstDiscovererStreamInfo in a chain. %NULL
  * for final streams.
  * Unref with #gst_discoverer_stream_info_unref after usage.
+ *
+ * Since: 0.10.31
  */
 GstDiscovererStreamInfo *
 gst_discoverer_stream_info_get_next (GstDiscovererStreamInfo * info)
@@ -622,6 +626,8 @@ gst_discoverer_stream_info_get_next (GstDiscovererStreamInfo * info)
  *
  * Returns: (transfer full): the #GstCaps of the stream. Unref with
  * #gst_caps_unref after usage.
+ *
+ * Since: 0.10.31
  */
 GstCaps *
 gst_discoverer_stream_info_get_caps (GstDiscovererStreamInfo * info)
@@ -639,7 +645,10 @@ gst_discoverer_stream_info_get_caps (GstDiscovererStreamInfo * info)
  *
  * Returns: (transfer none): the tags contained in this stream. If you wish to
  * use the tags after the life-time of @info you will need to copy them.
+ *
+ * Since: 0.10.31
  */
+
 const GstTagList *
 gst_discoverer_stream_info_get_tags (GstDiscovererStreamInfo * info)
 {
@@ -648,21 +657,6 @@ gst_discoverer_stream_info_get_tags (GstDiscovererStreamInfo * info)
   return info->tags;
 }
 
-/**
- * gst_discoverer_stream_info_get_toc:
- * @info: a #GstDiscovererStreamInfo
- *
- * Returns: (transfer none): the TOC contained in this stream. If you wish to
- * use the TOC after the life-time of @info you will need to copy it.
- */
-const GstToc *
-gst_discoverer_stream_info_get_toc (GstDiscovererStreamInfo * info)
-{
-  g_return_val_if_fail (GST_IS_DISCOVERER_STREAM_INFO (info), NULL);
-
-  return info->toc;
-}
-
 /**
  * gst_discoverer_stream_info_get_misc:
  * @info: a #GstDiscovererStreamInfo
@@ -670,6 +664,8 @@ gst_discoverer_stream_info_get_toc (GstDiscovererStreamInfo * info)
  * Returns: (transfer none): additional information regarding the stream (for
  * example codec version, profile, etc..). If you wish to use the #GstStructure
  * after the life-time of @info you will need to copy it.
+ *
+ * Since: 0.10.31
  */
 const GstStructure *
 gst_discoverer_stream_info_get_misc (GstDiscovererStreamInfo * info)
@@ -688,6 +684,8 @@ gst_discoverer_stream_info_get_misc (GstDiscovererStreamInfo * info)
  * Returns: (transfer full) (element-type GstPbutils.DiscovererStreamInfo): the list of
  * #GstDiscovererStreamInfo this container stream offers.
  * Free with gst_discoverer_stream_info_list_free() after usage.
+ *
+ * Since: 0.10.31
  */
 
 GList *
@@ -717,6 +715,8 @@ gst_discoverer_container_info_get_streams (GstDiscovererContainerInfo * info)
  * @info: a #GstDiscovererAudioInfo
  *
  * Returns: the number of channels in the stream.
+ *
+ * Since: 0.10.31
  */
 
 AUDIO_INFO_ACCESSOR_CODE (channels, guint, 0);
@@ -726,6 +726,8 @@ AUDIO_INFO_ACCESSOR_CODE (channels, guint, 0);
  * @info: a #GstDiscovererAudioInfo
  *
  * Returns: the sample rate of the stream in Hertz.
+ *
+ * Since: 0.10.31
  */
 
 AUDIO_INFO_ACCESSOR_CODE (sample_rate, guint, 0);
@@ -735,6 +737,8 @@ AUDIO_INFO_ACCESSOR_CODE (sample_rate, guint, 0);
  * @info: a #GstDiscovererAudioInfo
  *
  * Returns: the number of bits used per sample in each channel.
+ *
+ * Since: 0.10.31
  */
 
 AUDIO_INFO_ACCESSOR_CODE (depth, guint, 0);
@@ -744,6 +748,8 @@ AUDIO_INFO_ACCESSOR_CODE (depth, guint, 0);
  * @info: a #GstDiscovererAudioInfo
  *
  * Returns: the average or nominal bitrate of the stream in bits/second.
+ *
+ * Since: 0.10.31
  */
 
 AUDIO_INFO_ACCESSOR_CODE (bitrate, guint, 0);
@@ -753,6 +759,8 @@ AUDIO_INFO_ACCESSOR_CODE (bitrate, guint, 0);
  * @info: a #GstDiscovererAudioInfo
  *
  * Returns: the maximum bitrate of the stream in bits/second.
+ *
+ * Since: 0.10.31
  */
 
 AUDIO_INFO_ACCESSOR_CODE (max_bitrate, guint, 0);
@@ -762,6 +770,8 @@ AUDIO_INFO_ACCESSOR_CODE (max_bitrate, guint, 0);
  * @info: a #GstDiscovererAudioInfo
  *
  * Returns: the language of the stream, or NULL if unknown.
+ *
+ * Since: 0.10.36
  */
 
 AUDIO_INFO_ACCESSOR_CODE (language, const gchar *, NULL);
@@ -778,6 +788,8 @@ AUDIO_INFO_ACCESSOR_CODE (language, const gchar *, NULL);
  * @info: a #GstDiscovererVideoInfo
  *
  * Returns: the width of the video stream in pixels.
+ *
+ * Since: 0.10.31
  */
 
 VIDEO_INFO_ACCESSOR_CODE (width, guint, 0);
@@ -787,6 +799,8 @@ VIDEO_INFO_ACCESSOR_CODE (width, guint, 0);
  * @info: a #GstDiscovererVideoInfo
  *
  * Returns: the height of the video stream in pixels.
+ *
+ * Since: 0.10.31
  */
 
 VIDEO_INFO_ACCESSOR_CODE (height, guint, 0);
@@ -796,6 +810,8 @@ VIDEO_INFO_ACCESSOR_CODE (height, guint, 0);
  * @info: a #GstDiscovererVideoInfo
  *
  * Returns: the depth in bits of the video stream.
+ *
+ * Since: 0.10.31
  */
 
 VIDEO_INFO_ACCESSOR_CODE (depth, guint, 0);
@@ -805,6 +821,8 @@ VIDEO_INFO_ACCESSOR_CODE (depth, guint, 0);
  * @info: a #GstDiscovererVideoInfo
  *
  * Returns: the framerate of the video stream (numerator).
+ *
+ * Since: 0.10.31
  */
 
 VIDEO_INFO_ACCESSOR_CODE (framerate_num, guint, 0);
@@ -814,6 +832,8 @@ VIDEO_INFO_ACCESSOR_CODE (framerate_num, guint, 0);
  * @info: a #GstDiscovererVideoInfo
  *
  * Returns: the framerate of the video stream (denominator).
+ *
+ * Since: 0.10.31
  */
 
 VIDEO_INFO_ACCESSOR_CODE (framerate_denom, guint, 0);
@@ -823,6 +843,8 @@ VIDEO_INFO_ACCESSOR_CODE (framerate_denom, guint, 0);
  * @info: a #GstDiscovererVideoInfo
  *
  * Returns: the Pixel Aspect Ratio (PAR) of the video stream (numerator).
+ *
+ * Since: 0.10.31
  */
 
 VIDEO_INFO_ACCESSOR_CODE (par_num, guint, 0);
@@ -832,6 +854,8 @@ VIDEO_INFO_ACCESSOR_CODE (par_num, guint, 0);
  * @info: a #GstDiscovererVideoInfo
  *
  * Returns: the Pixel Aspect Ratio (PAR) of the video stream (denominator).
+ *
+ * Since: 0.10.31
  */
 
 VIDEO_INFO_ACCESSOR_CODE (par_denom, guint, 0);
@@ -841,6 +865,8 @@ VIDEO_INFO_ACCESSOR_CODE (par_denom, guint, 0);
  * @info: a #GstDiscovererVideoInfo
  *
  * Returns: %TRUE if the stream is interlaced, else %FALSE.
+ *
+ * Since: 0.10.31
  */
 gboolean
 gst_discoverer_video_info_is_interlaced (const GstDiscovererVideoInfo * info)
@@ -855,6 +881,8 @@ gst_discoverer_video_info_is_interlaced (const GstDiscovererVideoInfo * info)
  * @info: a #GstDiscovererVideoInfo
  *
  * Returns: the average or nominal bitrate of the video stream in bits/second.
+ *
+ * Since: 0.10.31
  */
 
 VIDEO_INFO_ACCESSOR_CODE (bitrate, guint, 0);
@@ -864,6 +892,8 @@ VIDEO_INFO_ACCESSOR_CODE (bitrate, guint, 0);
  * @info: a #GstDiscovererVideoInfo
  *
  * Returns: the maximum bitrate of the video stream in bits/second.
+ *
+ * Since: 0.10.31
  */
 
 VIDEO_INFO_ACCESSOR_CODE (max_bitrate, guint, 0);
@@ -874,6 +904,8 @@ VIDEO_INFO_ACCESSOR_CODE (max_bitrate, guint, 0);
  *
  * Returns: #TRUE if the video stream corresponds to an image (i.e. only contains
  * one frame).
+ *
+ * Since: 0.10.31
  */
 gboolean
 gst_discoverer_video_info_is_image (const GstDiscovererVideoInfo * info)
@@ -895,6 +927,8 @@ gst_discoverer_video_info_is_image (const GstDiscovererVideoInfo * info)
  * @info: a #GstDiscovererSubtitleInfo
  *
  * Returns: the language of the stream, or NULL if unknown.
+ *
+ * Since: 0.10.36
  */
 
 SUBTITLE_INFO_ACCESSOR_CODE (language, const gchar *, NULL);
@@ -912,6 +946,8 @@ SUBTITLE_INFO_ACCESSOR_CODE (language, const gchar *, NULL);
  *
  * Returns: (transfer none): the URI to which this information corresponds to.
  * Copy it if you wish to use it after the life-time of @info.
+ *
+ * Since: 0.10.31
  */
 
 DISCOVERER_INFO_ACCESSOR_CODE (uri, const gchar *, NULL);
@@ -921,6 +957,8 @@ DISCOVERER_INFO_ACCESSOR_CODE (uri, const gchar *, NULL);
  * @info: a #GstDiscovererInfo
  *
  * Returns: the result of the discovery as a #GstDiscovererResult.
+ *
+ * Since: 0.10.31
  */
 
 DISCOVERER_INFO_ACCESSOR_CODE (result, GstDiscovererResult, GST_DISCOVERER_OK);
@@ -933,6 +971,8 @@ DISCOVERER_INFO_ACCESSOR_CODE (result, GstDiscovererResult, GST_DISCOVERER_OK);
  * #GstDiscovererStreamInfo.
  * This structure can be traversed to see the original hierarchy. Unref with
  * gst_discoverer_stream_info_unref() after usage.
+ *
+ * Since: 0.10.31
  */
 
 GstDiscovererStreamInfo *
@@ -952,6 +992,8 @@ gst_discoverer_info_get_stream_info (GstDiscovererInfo * info)
  * Returns: (transfer full) (element-type GstPbutils.DiscovererStreamInfo): the list of
  * all streams contained in the #info. Free after usage
  * with gst_discoverer_stream_info_list_free().
+ *
+ * Since: 0.10.31
  */
 GList *
 gst_discoverer_info_get_stream_list (GstDiscovererInfo * info)
@@ -973,6 +1015,8 @@ gst_discoverer_info_get_stream_list (GstDiscovererInfo * info)
  * @info: a #GstDiscovererInfo
  *
  * Returns: the duration of the URI in #GstClockTime (nanoseconds).
+ *
+ * Since: 0.10.31
  */
 
 DISCOVERER_INFO_ACCESSOR_CODE (duration, GstClockTime, GST_CLOCK_TIME_NONE);
@@ -982,6 +1026,8 @@ DISCOVERER_INFO_ACCESSOR_CODE (duration, GstClockTime, GST_CLOCK_TIME_NONE);
  * @info: a #GstDiscovererInfo
  *
  * Returns: the whether the URI is seekable.
+ *
+ * Since: 0.10.32
  */
 
 DISCOVERER_INFO_ACCESSOR_CODE (seekable, gboolean, FALSE);
@@ -993,6 +1039,8 @@ DISCOVERER_INFO_ACCESSOR_CODE (seekable, gboolean, FALSE);
  * Returns: (transfer none): Miscellaneous information stored as a #GstStructure
  * (for example: information about missing plugins). If you wish to use the
  * #GstStructure after the life-time of @info, you will need to copy it.
+ *
+ * Since: 0.10.31
  */
 
 DISCOVERER_INFO_ACCESSOR_CODE (misc, const GstStructure *, NULL);
@@ -1003,20 +1051,12 @@ DISCOVERER_INFO_ACCESSOR_CODE (misc, const GstStructure *, NULL);
  *
  * Returns: (transfer none): all tags contained in the URI. If you wish to use
  * the tags after the life-time of @info, you will need to copy them.
+ *
+ * Since: 0.10.31
  */
 
 DISCOVERER_INFO_ACCESSOR_CODE (tags, const GstTagList *, NULL);
 
-/**
- * gst_discoverer_info_get_toc:
- * @info: a #GstDiscovererInfo
- *
- * Returns: (transfer none): TOC contained in the URI. If you wish to use
- * the TOC after the life-time of @info, you will need to copy it.
- */
-
-DISCOVERER_INFO_ACCESSOR_CODE (toc, const GstToc *, NULL);
-
 /**
  * gst_discoverer_info_ref:
  * @info: a #GstDiscovererInfo
@@ -1024,6 +1064,8 @@ DISCOVERER_INFO_ACCESSOR_CODE (toc, const GstToc *, NULL);
  * Increments the reference count of @info.
  *
  * Returns: the same #GstDiscovererInfo object
+ *
+ * Since: 0.10.31
  */
 
 /**
@@ -1031,6 +1073,8 @@ DISCOVERER_INFO_ACCESSOR_CODE (toc, const GstToc *, NULL);
  * @info: a #GstDiscovererInfo
  *
  * Decrements the reference count of @info.
+ *
+ * Since: 0.10.31
  */
 
 /**
@@ -1040,6 +1084,8 @@ DISCOVERER_INFO_ACCESSOR_CODE (toc, const GstToc *, NULL);
  * Increments the reference count of @info.
  *
  * Returns: the same #GstDiscovererStreamInfo object
+ *
+ * Since: 0.10.31
  */
 
 /**
@@ -1047,4 +1093,6 @@ DISCOVERER_INFO_ACCESSOR_CODE (toc, const GstToc *, NULL);
  * @info: a #GstDiscovererStreamInfo
  *
  * Decrements the reference count of @info.
+ *
+ * Since: 0.10.31
  */
