@@ -36,6 +36,8 @@
  * asks for the discovery to begin (through gst_discoverer_start()).
  *
  * All the information is returned in a #GstDiscovererInfo structure.
+ *
+ * Since: 0.10.31
  */
 
 #ifdef HAVE_CONFIG_H
@@ -43,17 +45,18 @@
 #endif
 
 #include <gst/video/video.h>
-#include <gst/audio/audio.h>
 
 #include "pbutils.h"
+#include "pbutils-marshal.h"
 #include "pbutils-private.h"
 
+#include "gst/glib-compat-private.h"
+
 GST_DEBUG_CATEGORY_STATIC (discoverer_debug);
 #define GST_CAT_DEFAULT discoverer_debug
 
 static GQuark _CAPS_QUARK;
 static GQuark _TAGS_QUARK;
-static GQuark _TOC_QUARK;
 static GQuark _MISSING_PLUGIN_QUARK;
 static GQuark _STREAM_TOPOLOGY_QUARK;
 static GQuark _TOPOLOGY_PAD_QUARK;
@@ -66,7 +69,6 @@ typedef struct
   GstElement *queue;
   GstElement *sink;
   GstTagList *tags;
-  GstToc *toc;
 } PrivateStream;
 
 struct _GstDiscovererPrivate
@@ -79,7 +81,7 @@ struct _GstDiscovererPrivate
   /* list of pending URI to process (current excluded) */
   GList *pending_uris;
 
-  GMutex lock;
+  GMutex *lock;
 
   /* TRUE if processing a URI */
   gboolean processing;
@@ -119,13 +121,12 @@ struct _GstDiscovererPrivate
   /* Handler ids for various callbacks */
   gulong pad_added_id;
   gulong pad_remove_id;
-  gulong source_chg_id;
   gulong element_added_id;
   gulong bus_cb_id;
 };
 
-#define DISCO_LOCK(dc) g_mutex_lock (&dc->priv->lock);
-#define DISCO_UNLOCK(dc) g_mutex_unlock (&dc->priv->lock);
+#define DISCO_LOCK(dc) g_mutex_lock (dc->priv->lock);
+#define DISCO_UNLOCK(dc) g_mutex_unlock (dc->priv->lock);
 
 static void
 _do_init (void)
@@ -134,7 +135,6 @@ _do_init (void)
 
   _CAPS_QUARK = g_quark_from_static_string ("caps");
   _TAGS_QUARK = g_quark_from_static_string ("tags");
-  _TOC_QUARK = g_quark_from_static_string ("toc");
   _MISSING_PLUGIN_QUARK = g_quark_from_static_string ("missing-plugin");
   _STREAM_TOPOLOGY_QUARK = g_quark_from_static_string ("stream-topology");
   _TOPOLOGY_PAD_QUARK = g_quark_from_static_string ("pad");
@@ -148,7 +148,6 @@ enum
   SIGNAL_FINISHED,
   SIGNAL_STARTING,
   SIGNAL_DISCOVERED,
-  SIGNAL_SOURCE_SETUP,
   LAST_SIGNAL
 };
 
@@ -172,11 +171,8 @@ static void uridecodebin_pad_added_cb (GstElement * uridecodebin, GstPad * pad,
     GstDiscoverer * dc);
 static void uridecodebin_pad_removed_cb (GstElement * uridecodebin,
     GstPad * pad, GstDiscoverer * dc);
-static void uridecodebin_source_changed_cb (GstElement * uridecodebin,
-    GParamSpec * pspec, GstDiscoverer * dc);
 
 static void gst_discoverer_dispose (GObject * dc);
-static void gst_discoverer_finalize (GObject * dc);
 static void gst_discoverer_set_property (GObject * object, guint prop_id,
     const GValue * value, GParamSpec * pspec);
 static void gst_discoverer_get_property (GObject * object, guint prop_id,
@@ -188,7 +184,6 @@ gst_discoverer_class_init (GstDiscovererClass * klass)
   GObjectClass *gobject_class = (GObjectClass *) klass;
 
   gobject_class->dispose = gst_discoverer_dispose;
-  gobject_class->finalize = gst_discoverer_finalize;
 
   gobject_class->set_property = gst_discoverer_set_property;
   gobject_class->get_property = gst_discoverer_get_property;
@@ -197,7 +192,7 @@ gst_discoverer_class_init (GstDiscovererClass * klass)
 
   /* properties */
   /**
-   * GstDiscoverer:timeout:
+   * GstDiscoverer:timeout
    *
    * The duration (in nanoseconds) after which the discovery of an individual
    * URI will timeout.
@@ -238,40 +233,16 @@ gst_discoverer_class_init (GstDiscovererClass * klass)
    * @discoverer: the #GstDiscoverer
    * @info: the results #GstDiscovererInfo
    * @error: (type GLib.Error): #GError, which will be non-NULL if an error
-   *                            occurred during discovery. You must not
-   *                            free this #GError, it will be freed by
-   *                            the discoverer.
+   *                            occurred during discovery
    *
-   * Will be emitted when all information on a URI could be discovered, or
-   * an error ocurred.
-   *
-   * When an error occurs, @info might still contain some partial information,
-   * depending on the circumstances of the error.
+   * Will be emitted when all information on a URI could be discovered.
    */
   gst_discoverer_signals[SIGNAL_DISCOVERED] =
       g_signal_new ("discovered", G_TYPE_FROM_CLASS (klass), G_SIGNAL_RUN_LAST,
       G_STRUCT_OFFSET (GstDiscovererClass, discovered),
-      NULL, NULL, g_cclosure_marshal_generic,
+      NULL, NULL, pbutils_marshal_VOID__POINTER_BOXED,
       G_TYPE_NONE, 2, GST_TYPE_DISCOVERER_INFO,
       G_TYPE_ERROR | G_SIGNAL_TYPE_STATIC_SCOPE);
-
-  /**
-   * GstDiscoverer::source-setup:
-   * @discoverer: the #GstDiscoverer
-   * @source: source element
-   *
-   * This signal is emitted after the source element has been created for, so
-   * the URI being discovered, so it can be configured by setting additional
-   * properties (e.g. set a proxy server for an http source, or set the device
-   * and read speed for an audio cd source).
-   *
-   * This signal is usually emitted from the context of a GStreamer streaming
-   * thread.
-   */
-  gst_discoverer_signals[SIGNAL_SOURCE_SETUP] =
-      g_signal_new ("source-setup", G_TYPE_FROM_CLASS (klass),
-      G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (GstDiscovererClass, source_setup),
-      NULL, NULL, g_cclosure_marshal_generic, G_TYPE_NONE, 1, GST_TYPE_ELEMENT);
 }
 
 static void
@@ -299,7 +270,7 @@ gst_discoverer_init (GstDiscoverer * dc)
   dc->priv->async = FALSE;
   dc->priv->async_done = FALSE;
 
-  g_mutex_init (&dc->priv->lock);
+  dc->priv->lock = g_mutex_new ();
 
   dc->priv->pending_subtitle_pads = 0;
 
@@ -321,9 +292,6 @@ gst_discoverer_init (GstDiscoverer * dc)
   dc->priv->pad_remove_id =
       g_signal_connect_object (dc->priv->uridecodebin, "pad-removed",
       G_CALLBACK (uridecodebin_pad_removed_cb), dc, 0);
-  dc->priv->source_chg_id =
-      g_signal_connect_object (dc->priv->uridecodebin, "notify::source",
-      G_CALLBACK (uridecodebin_source_changed_cb), dc, 0);
 
   GST_LOG_OBJECT (dc, "Getting pipeline bus");
   dc->priv->bus = gst_pipeline_get_bus ((GstPipeline *) dc->priv->pipeline);
@@ -382,7 +350,6 @@ gst_discoverer_dispose (GObject * obj)
     /* Workaround for bug #118536 */
     DISCONNECT_SIGNAL (dc->priv->uridecodebin, dc->priv->pad_added_id);
     DISCONNECT_SIGNAL (dc->priv->uridecodebin, dc->priv->pad_remove_id);
-    DISCONNECT_SIGNAL (dc->priv->uridecodebin, dc->priv->source_chg_id);
     DISCONNECT_SIGNAL (dc->priv->uridecodebin, dc->priv->element_added_id);
     DISCONNECT_SIGNAL (dc->priv->bus, dc->priv->bus_cb_id);
 
@@ -397,6 +364,11 @@ gst_discoverer_dispose (GObject * obj)
 
   gst_discoverer_stop (dc);
 
+  if (dc->priv->lock) {
+    g_mutex_free (dc->priv->lock);
+    dc->priv->lock = NULL;
+  }
+
   if (dc->priv->seeking_query) {
     gst_query_unref (dc->priv->seeking_query);
     dc->priv->seeking_query = NULL;
@@ -405,16 +377,6 @@ gst_discoverer_dispose (GObject * obj)
   G_OBJECT_CLASS (gst_discoverer_parent_class)->dispose (obj);
 }
 
-static void
-gst_discoverer_finalize (GObject * obj)
-{
-  GstDiscoverer *dc = (GstDiscoverer *) obj;
-
-  g_mutex_clear (&dc->priv->lock);
-
-  G_OBJECT_CLASS (gst_discoverer_parent_class)->finalize (obj);
-}
-
 static void
 gst_discoverer_set_property (GObject * object, guint prop_id,
     const GValue * value, GParamSpec * pspec)
@@ -487,27 +449,13 @@ _event_probe (GstPad * pad, GstPadProbeInfo * info, PrivateStream * ps)
     DISCO_UNLOCK (ps->dc);
   }
 
-  if (GST_EVENT_TYPE (event) == GST_EVENT_TOC) {
-    GstToc *tmp;
-
-    gst_event_parse_toc (event, &tmp, NULL);
-    GST_DEBUG_OBJECT (pad, "toc %" GST_PTR_FORMAT, tmp);
-    DISCO_LOCK (ps->dc);
-    ps->toc = tmp;
-    if (G_LIKELY (ps->dc->priv->processing)) {
-      GST_DEBUG_OBJECT (pad, "private stream %p toc %" GST_PTR_FORMAT, ps, tmp);
-    } else
-      GST_DEBUG_OBJECT (pad, "Dropping toc since preroll is done");
-    DISCO_UNLOCK (ps->dc);
-  }
-
   return GST_PAD_PROBE_OK;
 }
 
-static GstStaticCaps subtitle_caps = GST_STATIC_CAPS ("text/x-raw; "
-    "subpicture/x-pgs; subpicture/x-dvb; subpicture/x-dvd; "
+static GstStaticCaps subtitle_caps = GST_STATIC_CAPS ("text/plain; "
+    "text/x-pango-markup; subpicture/x-pgs; subpicture/x-dvb; "
     "application/x-subtitle-unknown; application/x-ssa; application/x-ass; "
-    "subtitle/x-kate; application/x-kate");
+    "subtitle/x-kate; application/x-kate; video/x-dvd-subpicture");
 
 static gboolean
 is_subtitle_caps (const GstCaps * caps)
@@ -546,20 +494,6 @@ got_subtitle_data (GstPad * pad, GstPadProbeInfo * info, GstDiscoverer * dc)
 
 }
 
-static void
-uridecodebin_source_changed_cb (GstElement * uridecodebin,
-    GParamSpec * pspec, GstDiscoverer * dc)
-{
-  GstElement *src;
-  /* get a handle to the source */
-  g_object_get (uridecodebin, pspec->name, &src, NULL);
-
-  GST_DEBUG_OBJECT (dc, "got a new source %p", src);
-
-  g_signal_emit (dc, gst_discoverer_signals[SIGNAL_SOURCE_SETUP], 0, src);
-  gst_object_unref (src);
-}
-
 static void
 uridecodebin_pad_added_cb (GstElement * uridecodebin, GstPad * pad,
     GstDiscoverer * dc)
@@ -682,9 +616,6 @@ uridecodebin_pad_removed_cb (GstElement * uridecodebin, GstPad * pad,
   if (ps->tags) {
     gst_tag_list_free (ps->tags);
   }
-  if (ps->toc) {
-    gst_toc_unref (ps->toc);
-  }
 
   g_slice_free (PrivateStream, ps);
 
@@ -717,8 +648,6 @@ collect_stream_information (GstDiscoverer * dc, PrivateStream * ps, guint idx)
   }
   if (ps->tags)
     gst_structure_id_set (st, _TAGS_QUARK, GST_TYPE_TAG_LIST, ps->tags, NULL);
-  if (ps->toc)
-    gst_structure_id_set (st, _TOC_QUARK, GST_TYPE_TOC, ps->toc, NULL);
 
   return st;
 }
@@ -750,7 +679,6 @@ collect_information (GstDiscoverer * dc, const GstStructure * st,
   GstCaps *caps;
   GstStructure *caps_st;
   GstTagList *tags_st;
-  GstToc *toc_st;
   const gchar *name;
   int tmp;
   guint utmp;
@@ -770,7 +698,6 @@ collect_information (GstDiscoverer * dc, const GstStructure * st,
 
   if (g_str_has_prefix (name, "audio/")) {
     GstDiscovererAudioInfo *info;
-    const gchar *format_str;
 
     if (parent)
       info = (GstDiscovererAudioInfo *) gst_discoverer_stream_info_ref (parent);
@@ -786,17 +713,8 @@ collect_information (GstDiscoverer * dc, const GstStructure * st,
     if (gst_structure_get_int (caps_st, "channels", &tmp))
       info->channels = (guint) tmp;
 
-    /* FIXME: we only want to extract depth if raw audio is what's in the
-     * container (i.e. not if there is a decoder involved) */
-    format_str = gst_structure_get_string (caps_st, "format");
-    if (format_str != NULL) {
-      const GstAudioFormatInfo *finfo;
-      GstAudioFormat format;
-
-      format = gst_audio_format_from_string (format_str);
-      finfo = gst_audio_format_get_info (format);
-      info->depth = GST_AUDIO_FORMAT_INFO_DEPTH (finfo);
-    }
+    if (gst_structure_get_int (caps_st, "depth", &tmp))
+      info->depth = (guint) tmp;
 
     if (gst_structure_id_has_field (st, _TAGS_QUARK)) {
       gst_structure_id_get (st, _TAGS_QUARK, GST_TYPE_TAG_LIST, &tags_st, NULL);
@@ -811,11 +729,6 @@ collect_information (GstDiscoverer * dc, const GstStructure * st,
       gst_discoverer_merge_and_replace_tags (&info->parent.tags, tags_st);
     }
 
-    if (gst_structure_id_has_field (st, _TOC_QUARK)) {
-      gst_structure_id_get (st, _TOC_QUARK, GST_TYPE_TOC, &toc_st, NULL);
-      info->parent.toc = toc_st;
-    }
-
     if (!info->language && ((GstDiscovererStreamInfo *) info)->tags) {
       gchar *language;
       if (gst_tag_list_get_string (((GstDiscovererStreamInfo *) info)->tags,
@@ -840,7 +753,11 @@ collect_information (GstDiscoverer * dc, const GstStructure * st,
       info->parent.caps = gst_caps_ref (caps);
     }
 
-    if (gst_video_info_from_caps (&vinfo, caps)) {
+    /* FIXME : gst_video_info_from_caps only works with raw caps,
+     * wouldn't we want to get all the info below for non-raw caps ? 
+     */
+    if (g_str_has_prefix (name, "video/x-raw") &&
+        gst_video_info_from_caps (&vinfo, caps)) {
       info->width = (guint) vinfo.width;
       info->height = (guint) vinfo.height;
 
@@ -870,11 +787,6 @@ collect_information (GstDiscoverer * dc, const GstStructure * st,
           (GstTagList *) tags_st);
     }
 
-    if (gst_structure_id_has_field (st, _TOC_QUARK)) {
-      gst_structure_id_get (st, _TOC_QUARK, GST_TYPE_TOC, &toc_st, NULL);
-      info->parent.toc = toc_st;
-    }
-
     gst_caps_unref (caps);
     return (GstDiscovererStreamInfo *) info;
 
@@ -903,11 +815,6 @@ collect_information (GstDiscoverer * dc, const GstStructure * st,
       gst_discoverer_merge_and_replace_tags (&info->parent.tags, tags_st);
     }
 
-    if (gst_structure_id_has_field (st, _TOC_QUARK)) {
-      gst_structure_id_get (st, _TOC_QUARK, GST_TYPE_TOC, &toc_st, NULL);
-      info->parent.toc = toc_st;
-    }
-
     if (!info->language && ((GstDiscovererStreamInfo *) info)->tags) {
       gchar *language;
       if (gst_tag_list_get_string (((GstDiscovererStreamInfo *) info)->tags,
@@ -936,10 +843,6 @@ collect_information (GstDiscoverer * dc, const GstStructure * st,
       gst_discoverer_merge_and_replace_tags (&info->tags, tags_st);
     }
 
-    if (gst_structure_id_get (st, _TOC_QUARK, GST_TYPE_TOC, &toc_st, NULL)) {
-      info->toc = toc_st;
-    }
-
     gst_caps_unref (caps);
     return info;
   }
@@ -957,7 +860,7 @@ find_stream_for_node (GstDiscoverer * dc, const GstStructure * topology)
   GList *tmp;
 
   if (!gst_structure_id_has_field (topology, _TOPOLOGY_PAD_QUARK)) {
-    GST_DEBUG ("Could not find pad for node %" GST_PTR_FORMAT, topology);
+    GST_DEBUG ("Could not find pad for node %" GST_PTR_FORMAT "\n", topology);
     return NULL;
   }
 
@@ -1220,14 +1123,12 @@ discoverer_collect (GstDiscoverer * dc)
     if (dc->priv->current_info->duration == 0 &&
         dc->priv->current_info->stream_info != NULL &&
         dc->priv->current_info->stream_info->next == NULL) {
-      GstDiscovererStreamInfo *stream_info;
-      GstStructure *st;
-
-      stream_info = dc->priv->current_info->stream_info;
-      st = gst_caps_get_structure (stream_info->caps, 0);
+      GstStructure *st =
+          gst_caps_get_structure (dc->priv->current_info->stream_info->caps, 0);
 
       if (g_str_has_prefix (gst_structure_get_name (st), "image/"))
-        ((GstDiscovererVideoInfo *) stream_info)->is_image = TRUE;
+        ((GstDiscovererVideoInfo *) dc->priv->current_info->stream_info)->
+            is_image = TRUE;
     }
   }
 
@@ -1237,7 +1138,6 @@ discoverer_collect (GstDiscoverer * dc)
         dc->priv->current_info, dc->priv->current_error);
     /* Clients get a copy of current_info since it is a boxed type */
     gst_discoverer_info_unref (dc->priv->current_info);
-    dc->priv->current_info = NULL;
   }
 }
 
@@ -1385,18 +1285,6 @@ handle_message (GstDiscoverer * dc, GstMessage * msg)
     }
       break;
 
-    case GST_MESSAGE_TOC:
-    {
-      GstToc *tmp;
-
-      gst_message_parse_toc (msg, &tmp, NULL);
-      GST_DEBUG_OBJECT (GST_MESSAGE_SRC (msg), "Got toc %" GST_PTR_FORMAT, tmp);
-      dc->priv->current_info->toc = tmp;
-      GST_DEBUG_OBJECT (GST_MESSAGE_SRC (msg), "Current info %p, toc %"
-          GST_PTR_FORMAT, dc->priv->current_info, tmp);
-    }
-      break;
-
     default:
       break;
   }
@@ -1592,6 +1480,8 @@ beach:
  * Allow asynchronous discovering of URIs to take place.
  * A #GMainLoop must be available for #GstDiscoverer to properly work in
  * asynchronous mode.
+ *
+ * Since: 0.10.31
  */
 void
 gst_discoverer_start (GstDiscoverer * discoverer)
@@ -1632,6 +1522,8 @@ gst_discoverer_start (GstDiscoverer * discoverer)
  *
  * Stop the discovery of any pending URIs and clears the list of
  * pending URIS (if any).
+ *
+ * Since: 0.10.31
  */
 void
 gst_discoverer_stop (GstDiscoverer * discoverer)
@@ -1694,6 +1586,8 @@ gst_discoverer_stop (GstDiscoverer * discoverer)
  *
  * Returns: %TRUE if the @uri was successfully appended to the list of pending
  * uris, else %FALSE
+ *
+ * Since: 0.10.31
  */
 gboolean
 gst_discoverer_discover_uri_async (GstDiscoverer * discoverer,
@@ -1730,6 +1624,8 @@ gst_discoverer_discover_uri_async (GstDiscoverer * discoverer,
  *
  * Returns: (transfer full): the result of the scanning. Can be %NULL if an
  * error occurred.
+ *
+ * Since: 0.10.31
  */
 GstDiscovererInfo *
 gst_discoverer_discover_uri (GstDiscoverer * discoverer, const gchar * uri,
@@ -1785,6 +1681,8 @@ gst_discoverer_discover_uri (GstDiscoverer * discoverer, const gchar * uri,
  * If an error occurred when creating the discoverer, @err will be set
  * accordingly and %NULL will be returned. If @err is set, the caller must
  * free it when no longer needed using g_error_free().
+ *
+ * Since: 0.10.31
  */
 GstDiscoverer *
 gst_discoverer_new (GstClockTime timeout, GError ** err)
