@@ -67,6 +67,8 @@
 
 #include "gstrtspconnection.h"
 
+#include "gst/glib-compat-private.h"
+
 #ifdef IP_TOS
 union gst_sockaddr
 {
@@ -234,6 +236,8 @@ gst_rtsp_connection_create (const GstRTSPUrl * url, GstRTSPConnection ** conn)
  * @socket which should be used before starting to read new data.
  *
  * Returns: #GST_RTSP_OK when @conn contains a valid connection.
+ *
+ * Since: 0.10.25
  */
 GstRTSPResult
 gst_rtsp_connection_create_from_socket (GSocket * socket, const gchar * ip,
@@ -290,6 +294,8 @@ newconn_failed:
  * handling communication on new socket.
  *
  * Returns: #GST_RTSP_OK when @conn contains a valid connection.
+ *
+ * Since: 0.10.23
  */
 GstRTSPResult
 gst_rtsp_connection_accept (GSocket * socket, GstRTSPConnection ** conn,
@@ -316,12 +322,10 @@ gst_rtsp_connection_accept (GSocket * socket, GstRTSPConnection ** conn,
   ip = g_inet_address_to_string (g_inet_socket_address_get_address
       (G_INET_SOCKET_ADDRESS (addr)));
   port = g_inet_socket_address_get_port (G_INET_SOCKET_ADDRESS (addr));
-  g_object_unref (addr);
 
   ret =
       gst_rtsp_connection_create_from_socket (client_sock, ip, port, NULL,
       conn);
-  g_object_unref (client_sock);
   g_free (ip);
 
   return ret;
@@ -422,7 +426,6 @@ do_connect (const gchar * ip, guint16 port, GSocket ** socket_out,
   if (!g_socket_connect (socket, saddr, cancellable, &err)) {
     if (!g_error_matches (err, G_IO_ERROR, G_IO_ERROR_PENDING))
       goto sys_error;
-    g_clear_error (&err);
   } else {
     goto done;
   }
@@ -2090,7 +2093,7 @@ gst_rtsp_connection_receive (GstRTSPConnection * conn, GstRTSPMessage * message,
             G_IO_IN | G_IO_PRI | G_IO_ERR | G_IO_HUP, conn->cancellable,
             &err)) {
       g_socket_set_timeout (conn->read_socket, 0);
-      if (g_error_matches (err, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
+      if (g_error_matches (err, G_IO_ERROR, G_IO_ERROR_BUSY)) {
         g_clear_error (&err);
         goto stopped;
       } else if (g_error_matches (err, G_IO_ERROR, G_IO_ERROR_TIMED_OUT)) {
@@ -2152,17 +2155,6 @@ gst_rtsp_connection_close (GstRTSPConnection * conn)
 {
   g_return_val_if_fail (conn != NULL, GST_RTSP_EINVAL);
 
-  /* last unref closes the connection we don't want to explicitly close here
-   * because these sockets might have been provided at construction */
-  if (conn->socket0) {
-    g_object_unref (conn->socket0);
-    conn->socket0 = NULL;
-  }
-  if (conn->socket1) {
-    g_object_unref (conn->socket1);
-    conn->socket1 = NULL;
-  }
-
   g_free (conn->ip);
   conn->ip = NULL;
 
@@ -2205,6 +2197,10 @@ gst_rtsp_connection_free (GstRTSPConnection * conn)
   g_return_val_if_fail (conn != NULL, GST_RTSP_EINVAL);
 
   res = gst_rtsp_connection_close (conn);
+  if (conn->socket0)
+    g_object_unref (conn->socket0);
+  if (conn->socket1)
+    g_object_unref (conn->socket1);
 
   if (conn->cancellable)
     g_object_unref (conn->cancellable);
@@ -2234,6 +2230,8 @@ gst_rtsp_connection_free (GstRTSPConnection * conn)
  * This function can be cancelled with gst_rtsp_connection_flush().
  * 
  * Returns: #GST_RTSP_OK on success.
+ *
+ * Since: 0.10.15
  */
 GstRTSPResult
 gst_rtsp_connection_poll (GstRTSPConnection * conn, GstRTSPEvent events,
@@ -2404,6 +2402,8 @@ gst_rtsp_connection_flush (GstRTSPConnection * conn, gboolean flush)
  * Set the proxy host and port.
  * 
  * Returns: #GST_RTSP_OK.
+ *
+ * Since: 0.10.23
  */
 GstRTSPResult
 gst_rtsp_connection_set_proxy (GstRTSPConnection * conn,
@@ -2508,6 +2508,8 @@ str_case_equal (gconstpointer v1, gconstpointer v2)
  * #GST_RTSP_AUTH_DIGEST, directives should be taken from the digest challenge
  * in the WWW-Authenticate response header and can include realm, domain,
  * nonce, opaque, stale, algorithm, qop as per RFC2617.
+ * 
+ * Since: 0.10.20
  */
 void
 gst_rtsp_connection_set_auth_param (GstRTSPConnection * conn,
@@ -2528,6 +2530,8 @@ gst_rtsp_connection_set_auth_param (GstRTSPConnection * conn,
  * @conn: a #GstRTSPConnection
  *
  * Clear the list of authentication directives stored in @conn.
+ *
+ * Since: 0.10.20
  */
 void
 gst_rtsp_connection_clear_auth_params (GstRTSPConnection * conn)
@@ -2608,6 +2612,8 @@ wrong_family:
  * Configure @conn to use the specified DSCP value.
  *
  * Returns: #GST_RTSP_OK on success.
+ *
+ * Since: 0.10.20
  */
 GstRTSPResult
 gst_rtsp_connection_set_qos_dscp (GstRTSPConnection * conn, guint qos_dscp)
@@ -2634,6 +2640,8 @@ gst_rtsp_connection_set_qos_dscp (GstRTSPConnection * conn, guint qos_dscp)
  *
  * Returns: The URL. This value remains valid until the
  * connection is freed.
+ *
+ * Since: 0.10.23
  */
 GstRTSPUrl *
 gst_rtsp_connection_get_url (const GstRTSPConnection * conn)
@@ -2651,6 +2659,8 @@ gst_rtsp_connection_get_url (const GstRTSPConnection * conn)
  *
  * Returns: The IP address as a string. this value remains valid until the
  * connection is closed.
+ *
+ * Since: 0.10.20
  */
 const gchar *
 gst_rtsp_connection_get_ip (const GstRTSPConnection * conn)
@@ -2666,6 +2676,8 @@ gst_rtsp_connection_get_ip (const GstRTSPConnection * conn)
  * @ip: an ip address
  *
  * Set the IP address of the server.
+ *
+ * Since: 0.10.23
  */
 void
 gst_rtsp_connection_set_ip (GstRTSPConnection * conn, const gchar * ip)
@@ -2684,6 +2696,8 @@ gst_rtsp_connection_set_ip (GstRTSPConnection * conn, const gchar * ip)
  *
  * Returns: the file descriptor used for reading or %NULL on error. The file
  * descriptor remains valid until the connection is closed.
+ *
+ * Since: 0.10.23
  */
 GSocket *
 gst_rtsp_connection_get_read_socket (const GstRTSPConnection * conn)
@@ -2702,6 +2716,8 @@ gst_rtsp_connection_get_read_socket (const GstRTSPConnection * conn)
  *
  * Returns: the file descriptor used for writing or NULL on error. The file
  * descriptor remains valid until the connection is closed.
+ *
+ * Since: 0.10.23
  */
 GSocket *
 gst_rtsp_connection_get_write_socket (const GstRTSPConnection * conn)
@@ -2720,6 +2736,8 @@ gst_rtsp_connection_get_write_socket (const GstRTSPConnection * conn)
  * By setting the HTTP mode to %TRUE the message parsing will support HTTP
  * messages in addition to the RTSP messages. It will also disable the
  * automatic handling of setting up an HTTP tunnel.
+ *
+ * Since: 0.10.25
  */
 void
 gst_rtsp_connection_set_http_mode (GstRTSPConnection * conn, gboolean enable)
@@ -2736,6 +2754,8 @@ gst_rtsp_connection_set_http_mode (GstRTSPConnection * conn, gboolean enable)
  *
  * Set the HTTP tunneling state of the connection. This must be configured before
  * the @conn is connected.
+ *
+ * Since: 0.10.23
  */
 void
 gst_rtsp_connection_set_tunneled (GstRTSPConnection * conn, gboolean tunneled)
@@ -2754,6 +2774,8 @@ gst_rtsp_connection_set_tunneled (GstRTSPConnection * conn, gboolean tunneled)
  * Get the tunneling state of the connection. 
  *
  * Returns: if @conn is using HTTP tunneling.
+ *
+ * Since: 0.10.23
  */
 gboolean
 gst_rtsp_connection_is_tunneled (const GstRTSPConnection * conn)
@@ -2770,6 +2792,8 @@ gst_rtsp_connection_is_tunneled (const GstRTSPConnection * conn)
  * Get the tunnel session id the connection. 
  *
  * Returns: returns a non-empty string if @conn is being tunneled over HTTP.
+ *
+ * Since: 0.10.23
  */
 const gchar *
 gst_rtsp_connection_get_tunnelid (const GstRTSPConnection * conn)
@@ -2798,6 +2822,8 @@ gst_rtsp_connection_get_tunnelid (const GstRTSPConnection * conn)
  * @conn.
  *
  * Returns: return GST_RTSP_OK on success.
+ *
+ * Since: 0.10.23
  */
 GstRTSPResult
 gst_rtsp_connection_do_tunnel (GstRTSPConnection * conn,
@@ -2828,11 +2854,6 @@ gst_rtsp_connection_do_tunnel (GstRTSPConnection * conn,
     conn->read_socket = conn->socket1;
 
     conn->tstate = TUNNEL_STATE_COMPLETE;
-
-    g_free (conn->initial_buffer);
-    conn->initial_buffer = conn2->initial_buffer;
-    conn2->initial_buffer = NULL;
-    conn->initial_buffer_offset = conn2->initial_buffer_offset;
   }
 
   /* we need base64 decoding for the readfd */
@@ -2872,7 +2893,7 @@ struct _GstRTSPWatch
 
   /* queued message for transmission */
   guint id;
-  GMutex mutex;
+  GMutex *mutex;
   GQueue *messages;
   guint8 *write_data;
   guint write_off;
@@ -3015,7 +3036,7 @@ gst_rtsp_source_dispatch (GSource * source, GSourceFunc callback G_GNUC_UNUSED,
     if (watch->writefd.revents & WRITE_ERR)
       goto write_error;
 
-    g_mutex_lock (&watch->mutex);
+    g_mutex_lock (watch->mutex);
     do {
       if (watch->write_data == NULL) {
         GstRTSPRec *rec;
@@ -3035,7 +3056,7 @@ gst_rtsp_source_dispatch (GSource * source, GSourceFunc callback G_GNUC_UNUSED,
 
       res = write_bytes (watch->conn->write_socket, watch->write_data,
           &watch->write_off, watch->write_size, watch->conn->cancellable);
-      g_mutex_unlock (&watch->mutex);
+      g_mutex_unlock (watch->mutex);
 
       if (res == GST_RTSP_EINTR)
         goto write_blocked;
@@ -3045,7 +3066,7 @@ gst_rtsp_source_dispatch (GSource * source, GSourceFunc callback G_GNUC_UNUSED,
       } else {
         goto write_error;
       }
-      g_mutex_lock (&watch->mutex);
+      g_mutex_lock (watch->mutex);
 
       g_free (watch->write_data);
       watch->write_data = NULL;
@@ -3053,7 +3074,7 @@ gst_rtsp_source_dispatch (GSource * source, GSourceFunc callback G_GNUC_UNUSED,
 
     watch->writefd.events = WRITE_ERR;
 
-    g_mutex_unlock (&watch->mutex);
+    g_mutex_unlock (watch->mutex);
   }
 
 write_blocked:
@@ -3131,7 +3152,7 @@ gst_rtsp_source_finalize (GSource * source)
   watch->messages = NULL;
   g_free (watch->write_data);
 
-  g_mutex_clear (&watch->mutex);
+  g_mutex_free (watch->mutex);
 
   if (watch->notify)
     watch->notify (watch->user_data);
@@ -3163,6 +3184,8 @@ static GSourceFuncs gst_rtsp_source_funcs = {
  *
  * Returns: a #GstRTSPWatch that can be used for asynchronous RTSP
  * communication. Free with gst_rtsp_watch_unref () after usage.
+ *
+ * Since: 0.10.23
  */
 GstRTSPWatch *
 gst_rtsp_watch_new (GstRTSPConnection * conn,
@@ -3181,7 +3204,7 @@ gst_rtsp_watch_new (GstRTSPConnection * conn,
   result->conn = conn;
   result->builder.state = STATE_START;
 
-  g_mutex_init (&result->mutex);
+  result->mutex = g_mutex_new ();
   result->messages = g_queue_new ();
 
   result->readfd.fd = -1;
@@ -3202,6 +3225,8 @@ gst_rtsp_watch_new (GstRTSPConnection * conn,
  *
  * Reset @watch, this is usually called after gst_rtsp_connection_do_tunnel()
  * when the file descriptors of the connection might have changed.
+ *
+ * Since: 0.10.23
  */
 void
 gst_rtsp_watch_reset (GstRTSPWatch * watch)
@@ -3233,6 +3258,8 @@ gst_rtsp_watch_reset (GstRTSPWatch * watch)
  * Adds a #GstRTSPWatch to a context so that it will be executed within that context.
  *
  * Returns: the ID (greater than 0) for the watch within the GMainContext. 
+ *
+ * Since: 0.10.23
  */
 guint
 gst_rtsp_watch_attach (GstRTSPWatch * watch, GMainContext * context)
@@ -3248,6 +3275,8 @@ gst_rtsp_watch_attach (GstRTSPWatch * watch, GMainContext * context)
  *
  * Decreases the reference count of @watch by one. If the resulting reference
  * count is zero the watch and associated memory will be destroyed.
+ *
+ * Since: 0.10.23
  */
 void
 gst_rtsp_watch_unref (GstRTSPWatch * watch)
@@ -3274,6 +3303,8 @@ gst_rtsp_watch_unref (GstRTSPWatch * watch)
  * This function will take ownership of @data and g_free() it after use.
  *
  * Returns: #GST_RTSP_OK on success.
+ *
+ * Since: 0.10.25
  */
 GstRTSPResult
 gst_rtsp_watch_write_data (GstRTSPWatch * watch, const guint8 * data,
@@ -3288,7 +3319,7 @@ gst_rtsp_watch_write_data (GstRTSPWatch * watch, const guint8 * data,
   g_return_val_if_fail (data != NULL, GST_RTSP_EINVAL);
   g_return_val_if_fail (size != 0, GST_RTSP_EINVAL);
 
-  g_mutex_lock (&watch->mutex);
+  g_mutex_lock (watch->mutex);
 
   /* try to send the message synchronously first */
   if (watch->messages->length == 0 && watch->write_data == NULL) {
@@ -3334,7 +3365,7 @@ gst_rtsp_watch_write_data (GstRTSPWatch * watch, const guint8 * data,
   res = GST_RTSP_OK;
 
 done:
-  g_mutex_unlock (&watch->mutex);
+  g_mutex_unlock (watch->mutex);
 
   if (context)
     g_main_context_wakeup (context);
@@ -3356,6 +3387,8 @@ done:
  * callback.
  *
  * Returns: #GST_RTSP_OK on success.
+ *
+ * Since: 0.10.25
  */
 GstRTSPResult
 gst_rtsp_watch_send_message (GstRTSPWatch * watch, GstRTSPMessage * message,
