@@ -515,7 +515,7 @@ gst_exif_reader_reset (GstExifReader * reader, gboolean return_taglist)
   }
 
   if (reader->taglist) {
-    gst_tag_list_unref (reader->taglist);
+    gst_tag_list_free (reader->taglist);
   }
 
   return ret;
@@ -900,7 +900,6 @@ write_exif_undefined_tag_from_taglist (GstExifWriter * writer,
   guint8 *data = NULL;
   gsize size = 0;
   gint tag_size = gst_tag_list_get_tag_size (taglist, exiftag->gst_tag);
-  GstSample *sample = NULL;
   GstBuffer *buf = NULL;
 
   if (tag_size != 1) {
@@ -917,9 +916,8 @@ write_exif_undefined_tag_from_taglist (GstExifWriter * writer,
       size = strlen ((gchar *) data);   /* no need to +1, undefined doesn't require it */
       break;
     default:
-      if (G_VALUE_TYPE (value) == GST_TYPE_SAMPLE) {
-        sample = gst_value_get_sample (value);
-        buf = gst_sample_get_buffer (sample);
+      if (G_VALUE_TYPE (value) == GST_TYPE_BUFFER) {
+        buf = gst_value_get_buffer (value);
         gst_buffer_map (buf, &info, GST_MAP_READ);
         data = info.data;
         size = info.size;
@@ -1351,17 +1349,15 @@ parse_exif_undefined_tag (GstExifReader * reader, const GstExifTagMatch * tag,
   }
 
   tagtype = gst_tag_get_type (tag->gst_tag);
-  if (tagtype == GST_TYPE_SAMPLE) {
-    GstSample *sample;
+  if (tagtype == GST_TYPE_BUFFER) {
     GstBuffer *buf;
 
     buf = gst_buffer_new_wrapped (data, count);
     data = NULL;
 
-    sample = gst_sample_new (buf, NULL, NULL, NULL);
     gst_tag_list_add (reader->taglist, GST_TAG_MERGE_APPEND, tag->gst_tag,
-        sample, NULL);
-    gst_sample_unref (sample);
+        buf, NULL);
+
     gst_buffer_unref (buf);
   } else if (tagtype == G_TYPE_STRING) {
     gst_tag_list_add (reader->taglist, GST_TAG_MERGE_REPLACE, tag->gst_tag,
@@ -1780,6 +1776,8 @@ read_error:
  * the tags IFD and is followed by the data pointed by the tag entries.
  *
  * Returns: A GstBuffer containing the tag entries followed by the tag data
+ *
+ * Since: 0.10.30
  */
 GstBuffer *
 gst_tag_list_to_exif_buffer (const GstTagList * taglist, gint byte_order,
@@ -1796,6 +1794,8 @@ gst_tag_list_to_exif_buffer (const GstTagList * taglist, gint byte_order,
  * is put in the beginning of the buffer.
  *
  * Returns: A GstBuffer containing the data
+ *
+ * Since: 0.10.30
  */
 GstBuffer *
 gst_tag_list_to_exif_buffer_with_tiff_header (const GstTagList * taglist)
@@ -1861,6 +1861,8 @@ gst_tag_list_to_exif_buffer_with_tiff_header (const GstTagList * taglist)
  * start
  *
  * Returns: The parsed taglist
+ *
+ * Since: 0.10.30
  */
 GstTagList *
 gst_tag_list_from_exif_buffer (GstBuffer * buffer, gint byte_order,
@@ -1892,6 +1894,8 @@ read_error:
  * Parses the exif tags starting with a tiff header structure.
  *
  * Returns: The taglist
+ *
+ * Since: 0.10.30
  */
 GstTagList *
 gst_tag_list_from_exif_buffer_with_tiff_header (GstBuffer * buffer)
