@@ -115,11 +115,14 @@
  *   and if it exceeds the recorded one, save it and emit a GST_MESSAGE_LATENCY
  */
 
+/* FIXME 0.11: suppress warnings for deprecated API such as GStaticRecMutex
+ * with newer GLib versions (>= 2.31.0) */
+#define GLIB_DISABLE_DEPRECATION_WARNINGS
+
 #include "gstvideoencoder.h"
 #include "gstvideoutils.h"
 
 #include <gst/video/gstvideometa.h>
-#include <gst/video/gstvideopool.h>
 
 #include <string.h>
 
@@ -138,7 +141,6 @@ struct _GstVideoEncoderPrivate
   /* FIXME : (and introduce a context ?) */
   gboolean drained;
   gboolean at_eos;
-  gboolean do_caps;
 
   gint64 min_latency;
   gint64 max_latency;
@@ -150,7 +152,7 @@ struct _GstVideoEncoderPrivate
 
   GList *force_key_unit;        /* List of pending forced keyunits */
 
-  guint32 system_frame_number;
+  guint64 system_frame_number;
 
   GList *frames;                /* Protected with OBJECT_LOCK */
   GstVideoCodecState *input_state;
@@ -159,12 +161,6 @@ struct _GstVideoEncoderPrivate
 
   gint64 bytes;
   gint64 time;
-
-  GstAllocator *allocator;
-  GstAllocationParams params;
-
-  GstTagList *tags;
-  gboolean tags_changed;
 };
 
 typedef struct _ForcedKeyUnitEvent ForcedKeyUnitEvent;
@@ -219,18 +215,14 @@ static gboolean gst_video_encoder_sink_query (GstPad * pad, GstObject * parent,
 static gboolean gst_video_encoder_src_query (GstPad * pad, GstObject * parent,
     GstQuery * query);
 static GstVideoCodecFrame *gst_video_encoder_new_frame (GstVideoEncoder *
-    encoder, GstBuffer * buf, GstClockTime pts, GstClockTime dts,
-    GstClockTime duration);
+    encoder, GstBuffer * buf, GstClockTime timestamp, GstClockTime duration);
 
 static gboolean gst_video_encoder_sink_event_default (GstVideoEncoder * encoder,
     GstEvent * event);
 static gboolean gst_video_encoder_src_event_default (GstVideoEncoder * encoder,
     GstEvent * event);
-static gboolean gst_video_encoder_decide_allocation_default (GstVideoEncoder *
-    encoder, GstQuery * query);
 static gboolean gst_video_encoder_propose_allocation_default (GstVideoEncoder *
     encoder, GstQuery * query);
-static gboolean gst_video_encoder_negotiate_default (GstVideoEncoder * encoder);
 
 /* we can't use G_DEFINE_ABSTRACT_TYPE because we need the klass in the _init
  * method to get to the padtemplates */
@@ -291,8 +283,6 @@ gst_video_encoder_class_init (GstVideoEncoderClass * klass)
   klass->sink_event = gst_video_encoder_sink_event_default;
   klass->src_event = gst_video_encoder_src_event_default;
   klass->propose_allocation = gst_video_encoder_propose_allocation_default;
-  klass->decide_allocation = gst_video_encoder_decide_allocation_default;
-  klass->negotiate = gst_video_encoder_negotiate_default;
 }
 
 static void
@@ -340,11 +330,6 @@ gst_video_encoder_reset (GstVideoEncoder * encoder)
     gst_video_codec_state_unref (priv->output_state);
   priv->output_state = NULL;
 
-  if (priv->tags)
-    gst_tag_list_unref (priv->tags);
-  priv->tags = NULL;
-  priv->tags_changed = FALSE;
-
   GST_VIDEO_ENCODER_STREAM_UNLOCK (encoder);
 }
 
@@ -455,6 +440,8 @@ exit:
  * @headers: (transfer full) (element-type GstBuffer): a list of #GstBuffer containing the codec header
  *
  * Set the codec headers to be sent downstream whenever requested.
+ *
+ * Since: 0.10.36
  */
 void
 gst_video_encoder_set_headers (GstVideoEncoder * video_encoder, GList * headers)
@@ -624,13 +611,14 @@ parse_fail:
  * gst_video_encoder_proxy_getcaps:
  * @enc: a #GstVideoEncoder
  * @caps: initial caps
- * @filter: filter caps
  *
  * Returns caps that express @caps (or sink template caps if @caps == NULL)
  * restricted to resolution/format/... combinations supported by downstream
  * elements (e.g. muxers).
  *
  * Returns: a #GstCaps owned by caller
+ *
+ * Since: 0.10.36
  */
 GstCaps *
 gst_video_encoder_proxy_getcaps (GstVideoEncoder * encoder, GstCaps * caps,
@@ -719,91 +707,11 @@ gst_video_encoder_sink_getcaps (GstVideoEncoder * encoder, GstCaps * filter)
   return caps;
 }
 
-static gboolean
-gst_video_encoder_decide_allocation_default (GstVideoEncoder * encoder,
-    GstQuery * query)
-{
-  GstAllocator *allocator = NULL;
-  GstAllocationParams params;
-  gboolean update_allocator;
-
-  /* we got configuration from our peer or the decide_allocation method,
-   * parse them */
-  if (gst_query_get_n_allocation_params (query) > 0) {
-    /* try the allocator */
-    gst_query_parse_nth_allocation_param (query, 0, &allocator, &params);
-    update_allocator = TRUE;
-  } else {
-    allocator = NULL;
-    gst_allocation_params_init (&params);
-    update_allocator = FALSE;
-  }
-
-  if (update_allocator)
-    gst_query_set_nth_allocation_param (query, 0, allocator, &params);
-  else
-    gst_query_add_allocation_param (query, allocator, &params);
-  if (allocator)
-    gst_object_unref (allocator);
-
-  return TRUE;
-}
-
 static gboolean
 gst_video_encoder_propose_allocation_default (GstVideoEncoder * encoder,
     GstQuery * query)
 {
-  GstCaps *caps;
-  GstVideoInfo info;
-  GstBufferPool *pool;
-  guint size;
-
-  gst_query_parse_allocation (query, &caps, NULL);
-
-  if (caps == NULL)
-    return FALSE;
-
-  if (!gst_video_info_from_caps (&info, caps))
-    return FALSE;
-
-  size = GST_VIDEO_INFO_SIZE (&info);
-
-  if (gst_query_get_n_allocation_pools (query) == 0) {
-    GstStructure *structure;
-    GstAllocator *allocator = NULL;
-    GstAllocationParams params = { 0, 15, 0, 0 };
-
-    if (gst_query_get_n_allocation_params (query) > 0)
-      gst_query_parse_nth_allocation_param (query, 0, &allocator, &params);
-    else
-      gst_query_add_allocation_param (query, allocator, &params);
-
-    pool = gst_video_buffer_pool_new ();
-
-    structure = gst_buffer_pool_get_config (pool);
-    gst_buffer_pool_config_set_params (structure, caps, size, 0, 0);
-    gst_buffer_pool_config_set_allocator (structure, allocator, &params);
-
-    if (allocator)
-      gst_object_unref (allocator);
-
-    if (!gst_buffer_pool_set_config (pool, structure))
-      goto config_failed;
-
-    gst_query_add_allocation_pool (query, pool, size, 0, 0);
-    gst_object_unref (pool);
-    gst_query_add_allocation_meta (query, GST_VIDEO_META_API_TYPE, NULL);
-  }
-
   return TRUE;
-
-  /* ERRORS */
-config_failed:
-  {
-    GST_ERROR_OBJECT (encoder, "failed to set config");
-    gst_object_unref (pool);
-    return FALSE;
-  }
 }
 
 static gboolean
@@ -856,11 +764,6 @@ gst_video_encoder_finalize (GObject * object)
   }
   g_rec_mutex_clear (&encoder->stream_lock);
 
-  if (encoder->priv->allocator) {
-    gst_object_unref (encoder->priv->allocator);
-    encoder->priv->allocator = NULL;
-  }
-
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -910,8 +813,7 @@ gst_video_encoder_sink_event_default (GstVideoEncoder * encoder,
       GstCaps *caps;
 
       gst_event_parse_caps (event, &caps);
-      ret = TRUE;
-      encoder->priv->do_caps = TRUE;
+      ret = gst_video_encoder_setcaps (encoder, caps);
       gst_event_unref (event);
       event = NULL;
       break;
@@ -984,36 +886,6 @@ gst_video_encoder_sink_event_default (GstVideoEncoder * encoder,
       }
       break;
     }
-    case GST_EVENT_TAG:
-    {
-      GstTagList *tags;
-
-      gst_event_parse_tag (event, &tags);
-
-      if (gst_tag_list_get_scope (tags) == GST_TAG_SCOPE_STREAM) {
-        tags = gst_tag_list_copy (tags);
-
-        /* FIXME: make generic based on GST_TAG_FLAG_ENCODED */
-        gst_tag_list_remove_tag (tags, GST_TAG_CODEC);
-        gst_tag_list_remove_tag (tags, GST_TAG_AUDIO_CODEC);
-        gst_tag_list_remove_tag (tags, GST_TAG_VIDEO_CODEC);
-        gst_tag_list_remove_tag (tags, GST_TAG_SUBTITLE_CODEC);
-        gst_tag_list_remove_tag (tags, GST_TAG_CONTAINER_FORMAT);
-        gst_tag_list_remove_tag (tags, GST_TAG_BITRATE);
-        gst_tag_list_remove_tag (tags, GST_TAG_NOMINAL_BITRATE);
-        gst_tag_list_remove_tag (tags, GST_TAG_MAXIMUM_BITRATE);
-        gst_tag_list_remove_tag (tags, GST_TAG_MINIMUM_BITRATE);
-        gst_tag_list_remove_tag (tags, GST_TAG_ENCODER);
-        gst_tag_list_remove_tag (tags, GST_TAG_ENCODER_VERSION);
-
-        gst_video_encoder_merge_tags (encoder, tags, GST_TAG_MERGE_REPLACE);
-        gst_tag_list_unref (tags);
-        gst_event_unref (event);
-        event = NULL;
-        ret = TRUE;
-      }
-      break;
-    }
     default:
       break;
   }
@@ -1194,7 +1066,7 @@ error:
 
 static GstVideoCodecFrame *
 gst_video_encoder_new_frame (GstVideoEncoder * encoder, GstBuffer * buf,
-    GstClockTime pts, GstClockTime dts, GstClockTime duration)
+    GstClockTime timestamp, GstClockTime duration)
 {
   GstVideoEncoderPrivate *priv = encoder->priv;
   GstVideoCodecFrame *frame;
@@ -1214,8 +1086,7 @@ gst_video_encoder_new_frame (GstVideoEncoder * encoder, GstBuffer * buf,
   frame->events = priv->current_frame_events;
   priv->current_frame_events = NULL;
   frame->input_buffer = buf;
-  frame->pts = pts;
-  frame->dts = dts;
+  frame->pts = timestamp;
   frame->duration = duration;
 
   return frame;
@@ -1229,9 +1100,8 @@ gst_video_encoder_chain (GstPad * pad, GstObject * parent, GstBuffer * buf)
   GstVideoEncoderPrivate *priv;
   GstVideoEncoderClass *klass;
   GstVideoCodecFrame *frame;
-  GstClockTime pts, dts, duration;
   GstFlowReturn ret = GST_FLOW_OK;
-  guint64 start, stop, cstart, cstop;
+  guint64 start, stop = GST_CLOCK_TIME_NONE, cstart, cstop;
 
   encoder = GST_VIDEO_ENCODER (parent);
   priv = encoder->priv;
@@ -1239,41 +1109,22 @@ gst_video_encoder_chain (GstPad * pad, GstObject * parent, GstBuffer * buf)
 
   g_return_val_if_fail (klass->handle_frame != NULL, GST_FLOW_ERROR);
 
-  if (G_UNLIKELY (encoder->priv->do_caps)) {
-    GstCaps *caps = gst_pad_get_current_caps (encoder->sinkpad);
-    if (!caps)
-      goto not_negotiated;
-    if (!gst_video_encoder_setcaps (encoder, caps)) {
-      gst_caps_unref (caps);
-      goto not_negotiated;
-    }
-    gst_caps_unref (caps);
-    encoder->priv->do_caps = FALSE;
-  }
-
   GST_VIDEO_ENCODER_STREAM_LOCK (encoder);
 
-  pts = GST_BUFFER_PTS (buf);
-  dts = GST_BUFFER_DTS (buf);
-  duration = GST_BUFFER_DURATION (buf);
+  start = GST_BUFFER_TIMESTAMP (buf);
+  if (GST_CLOCK_TIME_IS_VALID (GST_BUFFER_DURATION (buf)))
+    stop = start + GST_BUFFER_DURATION (buf);
 
   GST_LOG_OBJECT (encoder,
-      "received buffer of size %" G_GSIZE_FORMAT " with PTS %" GST_TIME_FORMAT
-      ", PTS %" GST_TIME_FORMAT ", duration %" GST_TIME_FORMAT,
-      gst_buffer_get_size (buf), GST_TIME_ARGS (pts), GST_TIME_ARGS (dts),
-      GST_TIME_ARGS (duration));
+      "received buffer of size %d with ts %" GST_TIME_FORMAT
+      ", duration %" GST_TIME_FORMAT, gst_buffer_get_size (buf),
+      GST_TIME_ARGS (start), GST_TIME_ARGS (GST_BUFFER_DURATION (buf)));
 
   if (priv->at_eos) {
     ret = GST_FLOW_EOS;
     goto done;
   }
 
-  start = pts;
-  if (GST_CLOCK_TIME_IS_VALID (duration))
-    stop = start + duration;
-  else
-    stop = GST_CLOCK_TIME_NONE;
-
   /* Drop buffers outside of segment */
   if (!gst_segment_clip (&encoder->output_segment,
           GST_FORMAT_TIME, start, stop, &cstart, &cstop)) {
@@ -1282,8 +1133,7 @@ gst_video_encoder_chain (GstPad * pad, GstObject * parent, GstBuffer * buf)
     goto done;
   }
 
-  frame =
-      gst_video_encoder_new_frame (encoder, buf, cstart, dts, cstop - cstart);
+  frame = gst_video_encoder_new_frame (encoder, buf, cstart, cstop - cstart);
 
   GST_OBJECT_LOCK (encoder);
   if (priv->force_key_unit) {
@@ -1293,7 +1143,7 @@ gst_video_encoder_chain (GstPad * pad, GstObject * parent, GstBuffer * buf)
 
     running_time =
         gst_segment_to_running_time (&encoder->output_segment, GST_FORMAT_TIME,
-        cstart);
+        GST_BUFFER_TIMESTAMP (buf));
 
     for (l = priv->force_key_unit; l; l = l->next) {
       ForcedKeyUnitEvent *tmp = l->data;
@@ -1327,7 +1177,6 @@ gst_video_encoder_chain (GstPad * pad, GstObject * parent, GstBuffer * buf)
   }
   GST_OBJECT_UNLOCK (encoder);
 
-  gst_video_codec_frame_ref (frame);
   priv->frames = g_list_append (priv->frames, frame);
 
   /* new data, more finish needed */
@@ -1336,21 +1185,13 @@ gst_video_encoder_chain (GstPad * pad, GstObject * parent, GstBuffer * buf)
   GST_LOG_OBJECT (encoder, "passing frame pfn %d to subclass",
       frame->presentation_frame_number);
 
+  gst_video_codec_frame_ref (frame);
   ret = klass->handle_frame (encoder, frame);
 
 done:
   GST_VIDEO_ENCODER_STREAM_UNLOCK (encoder);
 
   return ret;
-
-  /* ERRORS */
-not_negotiated:
-  {
-    GST_ELEMENT_ERROR (encoder, CORE, NEGOTIATION, (NULL),
-        ("encoder not initialized"));
-    gst_buffer_unref (buf);
-    return GST_FLOW_NOT_NEGOTIATED;
-  }
 }
 
 static GstStateChangeReturn
@@ -1429,15 +1270,11 @@ close_failed:
 }
 
 static gboolean
-gst_video_encoder_negotiate_default (GstVideoEncoder * encoder)
+gst_video_encoder_set_src_caps (GstVideoEncoder * encoder)
 {
-  GstVideoEncoderClass *klass = GST_VIDEO_ENCODER_GET_CLASS (encoder);
-  GstAllocator *allocator;
-  GstAllocationParams params;
   gboolean ret;
   GstVideoCodecState *state = encoder->priv->output_state;
   GstVideoInfo *info = &state->info;
-  GstQuery *query = NULL;
 
   g_return_val_if_fail (state->caps != NULL, FALSE);
 
@@ -1465,147 +1302,8 @@ gst_video_encoder_negotiate_default (GstVideoEncoder * encoder)
   }
 
   ret = gst_pad_set_caps (encoder->srcpad, state->caps);
-  if (!ret)
-    goto done;
-
-  query = gst_query_new_allocation (state->caps, TRUE);
-  if (!gst_pad_peer_query (encoder->srcpad, query)) {
-    GST_DEBUG_OBJECT (encoder, "didn't get downstream ALLOCATION hints");
-  }
-
-  g_assert (klass->decide_allocation != NULL);
-  ret = klass->decide_allocation (encoder, query);
-
-  GST_DEBUG_OBJECT (encoder, "ALLOCATION (%d) params: %" GST_PTR_FORMAT, ret,
-      query);
-
-  if (!ret)
-    goto no_decide_allocation;
-
-  /* we got configuration from our peer or the decide_allocation method,
-   * parse them */
-  if (gst_query_get_n_allocation_params (query) > 0) {
-    gst_query_parse_nth_allocation_param (query, 0, &allocator, &params);
-  } else {
-    allocator = NULL;
-    gst_allocation_params_init (&params);
-  }
-
-  if (encoder->priv->allocator)
-    gst_object_unref (encoder->priv->allocator);
-  encoder->priv->allocator = allocator;
-  encoder->priv->params = params;
-
-done:
-  if (query)
-    gst_query_unref (query);
 
   return ret;
-
-  /* Errors */
-no_decide_allocation:
-  {
-    GST_WARNING_OBJECT (encoder, "Subclass failed to decide allocation");
-    goto done;
-  }
-}
-
-/**
- * gst_video_encoder_negotiate:
- * @encoder: a #GstVideoEncoder
- *
- * Negotiate with downstream elements to currently configured #GstVideoCodecState.
- *
- * Returns: #TRUE if the negotiation succeeded, else #FALSE.
- */
-gboolean
-gst_video_encoder_negotiate (GstVideoEncoder * encoder)
-{
-  GstVideoEncoderClass *klass;
-  gboolean ret = TRUE;
-
-  g_return_val_if_fail (GST_IS_VIDEO_ENCODER (encoder), FALSE);
-
-  klass = GST_VIDEO_ENCODER_GET_CLASS (encoder);
-
-  GST_VIDEO_ENCODER_STREAM_LOCK (encoder);
-  if (klass->negotiate)
-    ret = klass->negotiate (encoder);
-  GST_VIDEO_ENCODER_STREAM_UNLOCK (encoder);
-
-  return ret;
-}
-
-/**
- * gst_video_encoder_allocate_output_buffer:
- * @encoder: a #GstVideoEncoder
- * @size: size of the buffer
- *
- * Helper function that allocates a buffer to hold an encoded video frame
- * for @encoder's current #GstVideoCodecState.
- *
- * Returns: (transfer full): allocated buffer
- */
-GstBuffer *
-gst_video_encoder_allocate_output_buffer (GstVideoEncoder * encoder, gsize size)
-{
-  GstBuffer *buffer;
-
-  g_return_val_if_fail (size > 0, NULL);
-
-  GST_DEBUG ("alloc src buffer");
-
-  GST_VIDEO_ENCODER_STREAM_LOCK (encoder);
-  if (G_UNLIKELY (encoder->priv->output_state_changed
-          || (encoder->priv->output_state
-              && gst_pad_check_reconfigure (encoder->srcpad))))
-    gst_video_encoder_negotiate (encoder);
-
-  buffer =
-      gst_buffer_new_allocate (encoder->priv->allocator, size,
-      &encoder->priv->params);
-
-  GST_VIDEO_ENCODER_STREAM_UNLOCK (encoder);
-
-  return buffer;
-}
-
-/**
- * gst_video_encoder_allocate_output_frame:
- * @encoder: a #GstVideoEncoder
- * @frame: a #GstVideoCodecFrame
- * @size: size of the buffer
- *
- * Helper function that allocates a buffer to hold an encoded video frame for @encoder's
- * current #GstVideoCodecState.  Subclass should already have configured video
- * state and set src pad caps.
- *
- * The buffer allocated here is owned by the frame and you should only
- * keep references to the frame, not the buffer.
- *
- * Returns: %GST_FLOW_OK if an output buffer could be allocated
- */
-GstFlowReturn
-gst_video_encoder_allocate_output_frame (GstVideoEncoder *
-    encoder, GstVideoCodecFrame * frame, gsize size)
-{
-  g_return_val_if_fail (frame->output_buffer == NULL, GST_FLOW_ERROR);
-
-  GST_VIDEO_ENCODER_STREAM_LOCK (encoder);
-  if (G_UNLIKELY (encoder->priv->output_state_changed
-          || (encoder->priv->output_state
-              && gst_pad_check_reconfigure (encoder->srcpad))))
-    gst_video_encoder_negotiate (encoder);
-
-  GST_LOG_OBJECT (encoder, "alloc buffer size %" G_GSIZE_FORMAT, size);
-
-  frame->output_buffer =
-      gst_buffer_new_allocate (encoder->priv->allocator, size,
-      &encoder->priv->params);
-
-  GST_VIDEO_ENCODER_STREAM_UNLOCK (encoder);
-
-  return frame->output_buffer ? GST_FLOW_OK : GST_FLOW_ERROR;
 }
 
 /**
@@ -1619,11 +1317,9 @@ gst_video_encoder_allocate_output_frame (GstVideoEncoder *
  * It is subsequently pushed downstream or provided to @pre_push.
  * In any case, the frame is considered finished and released.
  *
- * After calling this function the output buffer of the frame is to be
- * considered read-only. This function will also change the metadata
- * of the buffer.
- *
  * Returns: a #GstFlowReturn resulting from sending data downstream
+ *
+ * Since: 0.10.36
  */
 GstFlowReturn
 gst_video_encoder_finish_frame (GstVideoEncoder * encoder,
@@ -1641,16 +1337,10 @@ gst_video_encoder_finish_frame (GstVideoEncoder * encoder,
   GST_LOG_OBJECT (encoder,
       "finish frame fpn %d", frame->presentation_frame_number);
 
-  GST_LOG_OBJECT (encoder, "frame PTS %" GST_TIME_FORMAT
-      ", DTS %" GST_TIME_FORMAT, GST_TIME_ARGS (frame->pts),
-      GST_TIME_ARGS (frame->dts));
-
   GST_VIDEO_ENCODER_STREAM_LOCK (encoder);
 
-  if (G_UNLIKELY (priv->output_state_changed || (priv->output_state
-              && gst_pad_check_reconfigure (encoder->srcpad))))
-    gst_video_encoder_negotiate (encoder);
-
+  if (G_UNLIKELY (priv->output_state_changed))
+    gst_video_encoder_set_src_caps (encoder);
 
   if (G_UNLIKELY (priv->output_state == NULL))
     goto no_output_state;
@@ -1672,12 +1362,6 @@ gst_video_encoder_finish_frame (GstVideoEncoder * encoder,
       break;
   }
 
-  if (priv->tags && priv->tags_changed) {
-    gst_video_encoder_push_event (encoder,
-        gst_event_new_tag (gst_tag_list_ref (priv->tags)));
-    priv->tags_changed = FALSE;
-  }
-
   /* no buffer data means this frame is skipped/dropped */
   if (!frame->output_buffer) {
     GST_DEBUG_OBJECT (encoder, "skipping frame %" GST_TIME_FORMAT,
@@ -1747,11 +1431,7 @@ gst_video_encoder_finish_frame (GstVideoEncoder * encoder,
     priv->distance_from_sync = 0;
     GST_BUFFER_FLAG_UNSET (frame->output_buffer, GST_BUFFER_FLAG_DELTA_UNIT);
     /* For keyframes, DTS = PTS */
-    if (!GST_CLOCK_TIME_IS_VALID (frame->dts)) {
-      frame->dts = frame->pts;
-    } else if (GST_CLOCK_TIME_IS_VALID (frame->pts) && frame->pts != frame->dts) {
-      GST_WARNING_OBJECT (encoder, "keyframe PTS != DTS");
-    }
+    frame->dts = frame->pts;
   } else {
     GST_BUFFER_FLAG_SET (frame->output_buffer, GST_BUFFER_FLAG_DELTA_UNIT);
   }
@@ -1759,8 +1439,7 @@ gst_video_encoder_finish_frame (GstVideoEncoder * encoder,
   frame->distance_from_sync = priv->distance_from_sync;
   priv->distance_from_sync++;
 
-  GST_BUFFER_PTS (frame->output_buffer) = frame->pts;
-  GST_BUFFER_DTS (frame->output_buffer) = frame->dts;
+  GST_BUFFER_TIMESTAMP (frame->output_buffer) = frame->pts;
   GST_BUFFER_DURATION (frame->output_buffer) = frame->duration;
 
   /* update rate estimate */
@@ -1810,24 +1489,17 @@ gst_video_encoder_finish_frame (GstVideoEncoder * encoder,
   if (encoder_class->pre_push)
     ret = encoder_class->pre_push (encoder, frame);
 
-  /* A reference always needs to be owned by the frame on the buffer.
-   * For that reason, we use a complete sub-buffer (zero-cost) to push
-   * downstream.
-   * The original buffer will be free-ed only when downstream AND the
-   * current implementation are done with the frame. */
   if (ret == GST_FLOW_OK)
-    ret = gst_pad_push (encoder->srcpad, gst_buffer_ref (frame->output_buffer));
+    ret = gst_pad_push (encoder->srcpad, frame->output_buffer);
+
+  frame->output_buffer = NULL;
 
 done:
   /* handed out */
-
-  /* unref once from the list */
-  l = g_list_find (priv->frames, frame);
-  if (l) {
-    gst_video_codec_frame_unref (frame);
-    priv->frames = g_list_delete_link (priv->frames, l);
-  }
-  /* unref because this function takes ownership */
+  priv->frames = g_list_remove (priv->frames, frame);
+  /* Remove the reference from the list and the reference that
+   * was provided to us */
+  gst_video_codec_frame_unref (frame);
   gst_video_codec_frame_unref (frame);
 
   GST_VIDEO_ENCODER_STREAM_UNLOCK (encoder);
@@ -1850,6 +1522,8 @@ no_output_state:
  * Get the current #GstVideoCodecState
  *
  * Returns: (transfer full): #GstVideoCodecState describing format of video data.
+ *
+ * Since: 0.10.36
  */
 GstVideoCodecState *
 gst_video_encoder_get_output_state (GstVideoEncoder * encoder)
@@ -1889,6 +1563,8 @@ gst_video_encoder_get_output_state (GstVideoEncoder * encoder)
  * from the next call to #gst_video_encoder_finish_frame().
  *
  * Returns: (transfer full): the newly configured output state.
+ *
+ * Since: 0.10.36
  */
 GstVideoCodecState *
 gst_video_encoder_set_output_state (GstVideoEncoder * encoder, GstCaps * caps,
@@ -1919,6 +1595,8 @@ gst_video_encoder_set_output_state (GstVideoEncoder * encoder, GstCaps * caps,
  * @max_latency: maximum latency
  *
  * Informs baseclass of encoding latency.
+ *
+ * Since: 0.10.36
  */
 void
 gst_video_encoder_set_latency (GstVideoEncoder * encoder,
@@ -1939,13 +1617,12 @@ gst_video_encoder_set_latency (GstVideoEncoder * encoder,
 /**
  * gst_video_encoder_get_latency:
  * @encoder: a #GstVideoEncoder
- * @min_latency: (out) (allow-none): address of variable in which to store the
- *     configured minimum latency, or %NULL
- * @max_latency: (out) (allow-none): address of variable in which to store the
- *     configured maximum latency, or %NULL
+ * @min_latency: (out) (allow-none): the configured minimum latency
+ * @max_latency: (out) (allow-none): the configured maximum latency
  *
- * Query the configured encoding latency. Results will be returned via
- * @min_latency and @max_latency.
+ * Returns the configured encoding latency.
+ *
+ * Since: 0.10.36
  */
 void
 gst_video_encoder_get_latency (GstVideoEncoder * encoder,
@@ -1966,6 +1643,8 @@ gst_video_encoder_get_latency (GstVideoEncoder * encoder,
  * Get the oldest unfinished pending #GstVideoCodecFrame
  *
  * Returns: (transfer full): oldest unfinished pending #GstVideoCodecFrame
+ *
+ * Since: 0.10.36
  */
 GstVideoCodecFrame *
 gst_video_encoder_get_oldest_frame (GstVideoEncoder * encoder)
@@ -1987,7 +1666,9 @@ gst_video_encoder_get_oldest_frame (GstVideoEncoder * encoder)
  *
  * Get a pending unfinished #GstVideoCodecFrame
  * 
- * Returns: (transfer full): pending unfinished #GstVideoCodecFrame identified by @frame_number.
+ * Returns: (transfer none): pending unfinished #GstVideoCodecFrame identified by @frame_number.
+ *
+ * Since: 0.10.36
  */
 GstVideoCodecFrame *
 gst_video_encoder_get_frame (GstVideoEncoder * encoder, int frame_number)
@@ -2002,7 +1683,7 @@ gst_video_encoder_get_frame (GstVideoEncoder * encoder, int frame_number)
     GstVideoCodecFrame *tmp = g->data;
 
     if (tmp->system_frame_number == frame_number) {
-      frame = gst_video_codec_frame_ref (tmp);
+      frame = tmp;
       break;
     }
   }
@@ -2010,85 +1691,3 @@ gst_video_encoder_get_frame (GstVideoEncoder * encoder, int frame_number)
 
   return frame;
 }
-
-/**
- * gst_video_encoder_get_frames:
- * @encoder: a #GstVideoEncoder
- *
- * Get all pending unfinished #GstVideoCodecFrame
- * 
- * Returns: (transfer full) (element-type GstVideoCodecFrame): pending unfinished #GstVideoCodecFrame.
- */
-GList *
-gst_video_encoder_get_frames (GstVideoEncoder * encoder)
-{
-  GList *frames;
-
-  GST_VIDEO_ENCODER_STREAM_LOCK (encoder);
-  frames = g_list_copy (encoder->priv->frames);
-  g_list_foreach (frames, (GFunc) gst_video_codec_frame_ref, NULL);
-  GST_VIDEO_ENCODER_STREAM_UNLOCK (encoder);
-
-  return frames;
-}
-
-/**
- * gst_video_encoder_merge_tags:
- * @encoder: a #GstVideoEncoder
- * @tags: a #GstTagList to merge
- * @mode: the #GstTagMergeMode to use
- *
- * Adds tags to so-called pending tags, which will be processed
- * before pushing out data downstream.
- *
- * Note that this is provided for convenience, and the subclass is
- * not required to use this and can still do tag handling on its own.
- *
- * MT safe.
- */
-void
-gst_video_encoder_merge_tags (GstVideoEncoder * encoder,
-    const GstTagList * tags, GstTagMergeMode mode)
-{
-  GstTagList *otags;
-
-  g_return_if_fail (GST_IS_VIDEO_ENCODER (encoder));
-  g_return_if_fail (tags == NULL || GST_IS_TAG_LIST (tags));
-
-  GST_VIDEO_ENCODER_STREAM_LOCK (encoder);
-  if (tags)
-    GST_DEBUG_OBJECT (encoder, "merging tags %" GST_PTR_FORMAT, tags);
-  otags = encoder->priv->tags;
-  encoder->priv->tags = gst_tag_list_merge (encoder->priv->tags, tags, mode);
-  if (otags)
-    gst_tag_list_unref (otags);
-  encoder->priv->tags_changed = TRUE;
-  GST_VIDEO_ENCODER_STREAM_UNLOCK (encoder);
-}
-
-/**
- * gst_video_encoder_get_allocator:
- * @encoder: a #GstVideoEncoder
- * @allocator: (out) (allow-none) (transfer full): the #GstAllocator
- * used
- * @params: (out) (allow-none) (transfer full): the
- * #GstAllocatorParams of @allocator
- *
- * Lets #GstVideoEncoder sub-classes to know the memory @allocator
- * used by the base class and its @params.
- *
- * Unref the @allocator after use it.
- */
-void
-gst_video_encoder_get_allocator (GstVideoEncoder * encoder,
-    GstAllocator ** allocator, GstAllocationParams * params)
-{
-  g_return_if_fail (GST_IS_VIDEO_ENCODER (encoder));
-
-  if (allocator)
-    *allocator = encoder->priv->allocator ?
-        gst_object_ref (encoder->priv->allocator) : NULL;
-
-  if (params)
-    *params = encoder->priv->params;
-}
