@@ -71,10 +71,7 @@ struct _GstAdder {
   /* src event handling */
   volatile gboolean flush_stop_pending;
 
-  /* current caps */
-  GstCaps *current_caps;
-
-  /* target caps (set via property) */
+  /* target caps */
   GstCaps *filter_caps;
 
   /* Pending inline events */
