@@ -120,12 +120,12 @@
 
 typedef enum
 {
-  GST_ENCODEBIN_FLAG_NO_AUDIO_CONVERSION = (1 << 0),
-  GST_ENCODEBIN_FLAG_NO_VIDEO_CONVERSION = (1 << 1)
-} GstEncodeBinFlags;
+  GST_ENC_FLAG_NO_AUDIO_CONVERSION = (1 << 0),
+  GST_ENC_FLAG_NO_VIDEO_CONVERSION = (1 << 1)
+} GstEncFlags;
 
-#define GST_TYPE_ENCODEBIN_FLAGS (gst_encodebin_flags_get_type())
-GType gst_encodebin_flags_get_type (void);
+#define GST_TYPE_ENC_FLAGS (gst_enc_flags_get_type())
+GType gst_enc_flags_get_type (void);
 
 /* generic templates */
 static GstStaticPadTemplate muxer_src_template =
@@ -190,7 +190,7 @@ struct _GstEncodeBin
   guint64 tolerance;
   gboolean avoid_reencoding;
 
-  GstEncodeBinFlags flags;
+  GstEncFlags flags;
 };
 
 struct _GstEncodeBinClass
@@ -232,8 +232,9 @@ struct _StreamGroup
 #define DEFAULT_RAW_CAPS			\
   "video/x-raw; "				\
   "audio/x-raw; "				\
-  "text/x-raw; "				\
-  "subpicture/x-dvd; "			\
+  "text/plain; "				\
+  "text/x-pango-markup; "			\
+  "video/x-dvd-subpicture; "			\
   "subpicture/x-pgs"
 
 /* Properties */
@@ -260,13 +261,13 @@ enum
 #define C_FLAGS(v) ((guint) v)
 
 GType
-gst_encodebin_flags_get_type (void)
+gst_enc_flags_get_type (void)
 {
   static const GFlagsValue values[] = {
-    {C_FLAGS (GST_ENCODEBIN_FLAG_NO_AUDIO_CONVERSION), "Do not use audio "
-          "conversion elements", "no-audio-conversion"},
-    {C_FLAGS (GST_ENCODEBIN_FLAG_NO_VIDEO_CONVERSION), "Do not use video "
-          "conversion elements", "no-video-conversion"},
+    {C_FLAGS (GST_ENC_FLAG_NO_AUDIO_CONVERSION), "Do not use audio conversion "
+          "elements", "no-audio-conversion"},
+    {C_FLAGS (GST_ENC_FLAG_NO_VIDEO_CONVERSION), "Do not use video conversion "
+          "elements", "no-video-conversion"},
     {0, NULL, NULL}
   };
   static volatile GType id = 0;
@@ -274,7 +275,7 @@ gst_encodebin_flags_get_type (void)
   if (g_once_init_enter ((gsize *) & id)) {
     GType _id;
 
-    _id = g_flags_register_static ("GstEncodeBinFlags", values);
+    _id = g_flags_register_static ("GstEncFlags", values);
 
     g_once_init_leave ((gsize *) & id, _id);
   }
@@ -380,7 +381,7 @@ gst_encode_bin_class_init (GstEncodeBinClass * klass)
    */
   g_object_class_install_property (gobject_klass, PROP_FLAGS,
       g_param_spec_flags ("flags", "Flags", "Flags to control behaviour",
-          GST_TYPE_ENCODEBIN_FLAGS, DEFAULT_FLAGS,
+          GST_TYPE_ENC_FLAGS, DEFAULT_FLAGS,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
   /* Signals */
@@ -399,7 +400,7 @@ gst_encode_bin_class_init (GstEncodeBinClass * klass)
   gst_encode_bin_signals[SIGNAL_REQUEST_PAD] =
       g_signal_new ("request-pad", G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, G_STRUCT_OFFSET (GstEncodeBinClass,
-          request_pad), NULL, NULL, g_cclosure_marshal_generic,
+          request_pad), NULL, NULL, gst_encode_marshal_OBJECT__BOXED,
       GST_TYPE_PAD, 1, GST_TYPE_CAPS);
 
   klass->request_pad = gst_encode_bin_request_pad_signal;
@@ -482,7 +483,7 @@ gst_encode_bin_init (GstEncodeBin * encode_bin)
   encode_bin->raw_video_caps = gst_caps_from_string ("video/x-raw");
   encode_bin->raw_audio_caps = gst_caps_from_string ("audio/x-raw");
   /* encode_bin->raw_text_caps = */
-  /*     gst_caps_from_string ("text/x-raw"); */
+  /*     gst_caps_from_string ("text/plain;text/x-pango-markup"); */
 
   encode_bin->queue_buffers_max = DEFAULT_QUEUE_BUFFERS_MAX;
   encode_bin->queue_bytes_max = DEFAULT_QUEUE_BYTES_MAX;
@@ -1228,7 +1229,7 @@ _create_stream_group (GstEncodeBin * ebin, GstEncodingProfile * sprof,
   /* FIXME : Once we have properties for specific converters, use those */
   if (GST_IS_ENCODING_VIDEO_PROFILE (sprof)) {
     const gboolean native_video =
-        ! !(ebin->flags & GST_ENCODEBIN_FLAG_NO_VIDEO_CONVERSION);
+        ! !(ebin->flags & GST_ENC_FLAG_NO_VIDEO_CONVERSION);
     GstElement *cspace = NULL, *scale, *vrate, *cspace2 = NULL;
 
     GST_LOG ("Adding conversion elements for video stream");
@@ -1290,7 +1291,7 @@ _create_stream_group (GstEncodeBin * ebin, GstEncodingProfile * sprof,
     }
 
   } else if (GST_IS_ENCODING_AUDIO_PROFILE (sprof)
-      && !(ebin->flags & GST_ENCODEBIN_FLAG_NO_AUDIO_CONVERSION)) {
+      && !(ebin->flags & GST_ENC_FLAG_NO_AUDIO_CONVERSION)) {
     GstElement *aconv, *ares, *arate, *aconv2;
 
     GST_LOG ("Adding conversion elements for audio stream");
@@ -1495,9 +1496,8 @@ static gboolean
 _factory_can_handle_caps (GstElementFactory * factory, const GstCaps * caps,
     GstPadDirection dir, gboolean exact)
 {
-  const GList *templates;
+  GList *templates = factory->staticpadtemplates;
 
-  templates = gst_element_factory_get_static_pad_templates (factory);
   while (templates) {
     GstStaticPadTemplate *template = (GstStaticPadTemplate *) templates->data;
 
