@@ -29,7 +29,7 @@
  * <refsect2>
  * <title>Examples</title>
  * |[
- * gst-launch -v filesrc location=test.mkv ! matroskademux name=demux ! "video/x-h264" ! queue2 ! decodebin ! subtitleoverlay name=overlay ! videoconvert ! autovideosink  demux. ! "subpicture/x-dvd" ! queue2 ! overlay.
+ * gst-launch -v filesrc location=test.mkv ! matroskademux name=demux ! "video/x-h264" ! queue2 ! decodebin ! subtitleoverlay name=overlay ! videoconvert ! autovideosink  demux. ! "video/x-dvd-subpicture" ! queue2 ! overlay.
  * ]| This will play back the given Matroska file with h264 video and subpicture subtitles.
  * </refsect2>
  */
@@ -44,6 +44,8 @@
 #include <gst/video/video.h>
 #include <string.h>
 
+#include "gst/glib-compat-private.h"
+
 GST_DEBUG_CATEGORY_STATIC (subtitle_overlay_debug);
 #define GST_CAT_DEFAULT subtitle_overlay_debug
 
@@ -99,8 +101,8 @@ static void
 do_async_done (GstSubtitleOverlay * self)
 {
   if (self->do_async) {
-    GstMessage *msg = gst_message_new_async_done (GST_OBJECT_CAST (self),
-        GST_CLOCK_TIME_NONE);
+    GstMessage *msg =
+        gst_message_new_async_done (GST_OBJECT_CAST (self), FALSE);
 
     GST_DEBUG_OBJECT (self, "Posting async-done");
     GST_BIN_CLASS (parent_class)->handle_message (GST_BIN_CAST (self), msg);
@@ -162,8 +164,15 @@ gst_subtitle_overlay_finalize (GObject * object)
 {
   GstSubtitleOverlay *self = GST_SUBTITLE_OVERLAY (object);
 
-  g_mutex_clear (&self->lock);
-  g_mutex_clear (&self->factories_lock);
+  if (self->lock) {
+    g_mutex_free (self->lock);
+    self->lock = NULL;
+  }
+
+  if (self->factories_lock) {
+    g_mutex_free (self->factories_lock);
+    self->factories_lock = NULL;
+  }
 
   if (self->factories)
     gst_plugin_feature_list_free (self->factories);
@@ -599,80 +608,13 @@ _remove_element (GstSubtitleOverlay * self, GstElement ** element)
   }
 }
 
-static gboolean
-_pad_query_convert_to_time (GstPad * pad, GstFormat src_format, gint64 src_val,
-    gint64 * dest_val)
-{
-  GstFormat dest_format;
-
-  if (src_val == GST_CLOCK_TIME_NONE) {
-    *dest_val = GST_CLOCK_TIME_NONE;
-    return TRUE;
-  }
-
-  dest_format = GST_FORMAT_TIME;
-  return gst_pad_query_convert (pad, src_format, src_val, dest_format,
-      dest_val);
-}
-
 static void
-_generate_update_segment_event (GstPad * pad, GstSegment * segment,
-    GstEvent ** event1)
+_generate_update_segment_event (GstSegment * segment, GstEvent ** event1)
 {
   GstEvent *event;
   GstStructure *structure;
-  GstSegment newsegment;
-  gboolean use_newseg = FALSE;
-  gint64 start, stop, base, time, position, duration;
 
-  /* always push newsegment with format TIME */
-  if (segment->format != GST_FORMAT_TIME) {
-    gboolean res;
-    GstPad *peer;
-
-    peer = gst_pad_get_peer (pad);
-    if (peer) {
-      res = _pad_query_convert_to_time (peer, segment->format,
-          segment->start, &start);
-      res = res && _pad_query_convert_to_time (peer, segment->format,
-          segment->stop, &stop);
-      res = res && _pad_query_convert_to_time (peer, segment->format,
-          segment->time, &time);
-      res = res && _pad_query_convert_to_time (peer, segment->format,
-          segment->base, &base);
-      res = res && _pad_query_convert_to_time (peer, segment->format,
-          segment->position, &position);
-      res = res && _pad_query_convert_to_time (peer, segment->format,
-          segment->duration, &duration);
-      if (!res) {
-        start = 0;
-        stop = GST_CLOCK_TIME_NONE;
-        time = 0;
-        position = 0;
-        duration = GST_CLOCK_TIME_NONE;
-        base = 0;
-      } else {
-        use_newseg = TRUE;
-        gst_segment_init (&newsegment, GST_FORMAT_TIME);
-        newsegment.rate = segment->rate;
-        newsegment.applied_rate = segment->applied_rate;
-        newsegment.start = start;
-        newsegment.stop = stop;
-        newsegment.time = time;
-        newsegment.base = base;
-        newsegment.position = position;
-        newsegment.duration = duration;
-      }
-
-      gst_object_unref (peer);
-    }
-  }
-
-  if (use_newseg) {
-    event = gst_event_new_segment (&newsegment);
-  } else {
-    event = gst_event_new_segment (segment);
-  }
+  event = gst_event_new_segment (segment);
   structure = gst_event_writable_structure (event);
   gst_structure_id_set (structure, _subtitle_overlay_event_marker_id,
       G_TYPE_BOOLEAN, TRUE, NULL);
@@ -742,7 +684,7 @@ _setup_passthrough (GstSubtitleOverlay * self)
   if (self->video_segment.format != GST_FORMAT_UNDEFINED) {
     GstEvent *event1;
 
-    _generate_update_segment_event (sink, &self->video_segment, &event1);
+    _generate_update_segment_event (&self->video_segment, &event1);
     GST_DEBUG_OBJECT (self,
         "Pushing video segment event: %" GST_PTR_FORMAT, event1);
     gst_pad_send_event (sink, event1);
@@ -870,9 +812,8 @@ _setup_renderer (GstSubtitleOverlay * self, GstElement * renderer)
 
   if (strcmp (name, "textoverlay") == 0) {
     /* Set some textoverlay specific properties */
-    gst_util_set_object_arg (G_OBJECT (renderer), "halignment", "center");
-    gst_util_set_object_arg (G_OBJECT (renderer), "valignment", "bottom");
-    g_object_set (G_OBJECT (renderer), "wait-text", FALSE, NULL);
+    g_object_set (G_OBJECT (renderer),
+        "halign", "center", "valign", "bottom", "wait-text", FALSE, NULL);
     if (self->font_desc)
       g_object_set (G_OBJECT (renderer), "font-desc", self->font_desc, NULL);
     self->silent_property = "silent";
@@ -1174,7 +1115,7 @@ _pad_blocked_cb (GstPad * pad, GstPadProbeInfo * info, gpointer user_data)
   self->subtitle_flush = FALSE;
 
   /* Find our factories */
-  g_mutex_lock (&self->factories_lock);
+  g_mutex_lock (self->factories_lock);
   gst_subtitle_overlay_update_factory_list (self);
   if (subcaps) {
     factories =
@@ -1190,7 +1131,7 @@ _pad_blocked_cb (GstPad * pad, GstPadProbeInfo * info, gpointer user_data)
       self->subtitle_error = TRUE;
     }
   }
-  g_mutex_unlock (&self->factories_lock);
+  g_mutex_unlock (self->factories_lock);
 
   if (!subcaps) {
     _setup_passthrough (self);
@@ -1247,14 +1188,14 @@ _pad_blocked_cb (GstPad * pad, GstPadProbeInfo * info, gpointer user_data)
 
       g_assert (parser_caps != NULL);
 
-      g_mutex_lock (&self->factories_lock);
+      g_mutex_lock (self->factories_lock);
       gst_subtitle_overlay_update_factory_list (self);
       GST_DEBUG_OBJECT (self,
           "Searching overlay factories for caps %" GST_PTR_FORMAT, parser_caps);
       overlay_factories =
           gst_subtitle_overlay_get_factories_for_caps (self->factories,
           parser_caps);
-      g_mutex_unlock (&self->factories_lock);
+      g_mutex_unlock (self->factories_lock);
 
       if (!overlay_factories) {
         GST_WARNING_OBJECT (self,
@@ -1372,7 +1313,7 @@ _pad_blocked_cb (GstPad * pad, GstPadProbeInfo * info, gpointer user_data)
       sink = _get_video_pad ((self->renderer) ? self->renderer : self->overlay);
     }
 
-    _generate_update_segment_event (sink, &self->video_segment, &event1);
+    _generate_update_segment_event (&self->video_segment, &event1);
     GST_DEBUG_OBJECT (self,
         "Pushing video update segment event: %" GST_PTR_FORMAT,
         gst_event_get_structure (event1));
@@ -1389,7 +1330,7 @@ _pad_blocked_cb (GstPad * pad, GstPadProbeInfo * info, gpointer user_data)
     else
       sink = gst_element_get_static_pad (self->parser, "sink");
 
-    _generate_update_segment_event (sink, &self->subtitle_segment, &event1);
+    _generate_update_segment_event (&self->subtitle_segment, &event1);
     GST_DEBUG_OBJECT (self,
         "Pushing subtitle update segment event: %" GST_PTR_FORMAT,
         gst_event_get_structure (event1));
@@ -1420,12 +1361,12 @@ gst_subtitle_overlay_change_state (GstElement * element,
   switch (transition) {
     case GST_STATE_CHANGE_NULL_TO_READY:
       GST_DEBUG_OBJECT (self, "State change NULL->READY");
-      g_mutex_lock (&self->factories_lock);
+      g_mutex_lock (self->factories_lock);
       if (G_UNLIKELY (!gst_subtitle_overlay_update_factory_list (self))) {
-        g_mutex_unlock (&self->factories_lock);
+        g_mutex_unlock (self->factories_lock);
         return GST_STATE_CHANGE_FAILURE;
       }
-      g_mutex_unlock (&self->factories_lock);
+      g_mutex_unlock (self->factories_lock);
 
       GST_SUBTITLE_OVERLAY_LOCK (self);
       /* Set the internal pads to blocking */
@@ -1763,7 +1704,7 @@ gst_subtitle_overlay_src_proxy_event (GstPad * proxypad, GstObject * parent,
     event = NULL;
     ret = TRUE;
   } else {
-    ret = gst_pad_event_default (proxypad, parent, event);
+    ret = gst_proxy_pad_event_default (proxypad, parent, event);
     event = NULL;
   }
 
@@ -1850,7 +1791,7 @@ gst_subtitle_overlay_video_sink_event (GstPad * pad, GstObject * parent,
       break;
   }
 
-  ret = gst_pad_event_default (pad, parent, gst_event_ref (event));
+  ret = gst_proxy_pad_event_default (pad, parent, gst_event_ref (event));
 
   if (GST_EVENT_TYPE (event) == GST_EVENT_SEGMENT) {
     GST_DEBUG_OBJECT (pad, "segment event: %" GST_PTR_FORMAT, event);
@@ -1933,7 +1874,7 @@ gst_subtitle_overlay_subtitle_sink_getcaps (GstPad * pad, GstCaps * filter)
   GstSubtitleOverlay *self = GST_SUBTITLE_OVERLAY (gst_pad_get_parent (pad));
   GstCaps *ret;
 
-  g_mutex_lock (&self->factories_lock);
+  g_mutex_lock (self->factories_lock);
   if (G_UNLIKELY (!gst_subtitle_overlay_update_factory_list (self)))
     ret = gst_caps_new_empty ();
   else if (filter)
@@ -1942,7 +1883,7 @@ gst_subtitle_overlay_subtitle_sink_getcaps (GstPad * pad, GstCaps * filter)
         GST_CAPS_INTERSECT_FIRST);
   else
     ret = gst_caps_ref (self->factory_caps);
-  g_mutex_unlock (&self->factories_lock);
+  g_mutex_unlock (self->factories_lock);
 
   GST_DEBUG_OBJECT (pad, "Returning subtitle caps %" GST_PTR_FORMAT, ret);
 
@@ -1990,6 +1931,7 @@ static GstPadLinkReturn
 gst_subtitle_overlay_subtitle_sink_link (GstPad * pad, GstPad * peer)
 {
   GstSubtitleOverlay *self = GST_SUBTITLE_OVERLAY (gst_pad_get_parent (pad));
+  GstPadLinkReturn ret;
   GstCaps *caps;
 
   GST_DEBUG_OBJECT (pad, "Linking pad to peer %" GST_PTR_FORMAT, peer);
@@ -2016,9 +1958,10 @@ gst_subtitle_overlay_subtitle_sink_link (GstPad * pad, GstPad * peer)
     gst_caps_unref (caps);
   }
 
-  gst_object_unref (self);
+  ret = gst_ghost_pad_link_default (pad, peer);
 
-  return GST_PAD_LINK_OK;
+  gst_object_unref (self);
+  return ret;
 }
 
 static void
@@ -2034,6 +1977,8 @@ gst_subtitle_overlay_subtitle_sink_unlink (GstPad * pad)
   GST_DEBUG_OBJECT (pad, "Pad unlinking");
   gst_caps_replace (&self->subcaps, NULL);
 
+  gst_ghost_pad_unlink_default (pad);
+
   GST_SUBTITLE_OVERLAY_LOCK (self);
   self->subtitle_error = FALSE;
 
@@ -2051,10 +1996,8 @@ gst_subtitle_overlay_subtitle_sink_event (GstPad * pad, GstObject * parent,
   GstSubtitleOverlay *self = GST_SUBTITLE_OVERLAY (parent);
   gboolean ret;
 
-  GST_DEBUG_OBJECT (pad, "Got event %" GST_PTR_FORMAT, event);
-
   if (GST_EVENT_TYPE (event) == GST_EVENT_CUSTOM_DOWNSTREAM_OOB &&
-      gst_event_has_name (event, "playsink-custom-subtitle-flush")) {
+      gst_event_has_name (event, "subtitleoverlay-flush-subtitle")) {
     GST_DEBUG_OBJECT (pad, "Custom subtitle flush event");
     GST_SUBTITLE_OVERLAY_LOCK (self);
     self->subtitle_flush = TRUE;
@@ -2104,71 +2047,11 @@ gst_subtitle_overlay_subtitle_sink_event (GstPad * pad, GstObject * parent,
       break;
   }
 
-  ret = gst_pad_event_default (pad, parent, gst_event_ref (event));
+  ret = gst_proxy_pad_event_default (pad, parent, gst_event_ref (event));
 
   if (GST_EVENT_TYPE (event) == GST_EVENT_SEGMENT) {
-    const GstSegment *eventsegment;
     GST_DEBUG_OBJECT (pad, "segment event: %" GST_PTR_FORMAT, event);
-
-    gst_event_parse_segment (event, &eventsegment);
-
-    if (eventsegment->format == GST_FORMAT_TIME) {
-      gst_event_copy_segment (event, &self->subtitle_segment);
-    } else {
-      GstPad *peer;
-      gboolean res = FALSE;
-      gint64 tstart = 0;
-      gint64 tstop = GST_CLOCK_TIME_NONE;
-      gint64 tposition = 0;
-      gint64 tduration = 0;
-      gint64 ttime = 0;
-      gint64 tbase = 0;
-      GstFormat format = eventsegment->format;
-
-      GST_DEBUG_OBJECT (pad, "Subtitle newsegment event (%s) not in TIME "
-          "format, converting", gst_format_get_name (format));
-      peer = gst_pad_get_peer (pad);
-
-      if (peer) {
-        res =
-            _pad_query_convert_to_time (peer, format, eventsegment->start,
-            &tstart);
-        res = res
-            && _pad_query_convert_to_time (peer, format, eventsegment->stop,
-            &tstop);
-        res = res
-            && _pad_query_convert_to_time (peer, format, eventsegment->position,
-            &tposition);
-        res = res
-            && _pad_query_convert_to_time (peer, format, eventsegment->base,
-            &tbase);
-        res = res
-            && _pad_query_convert_to_time (peer, format, eventsegment->time,
-            &ttime);
-        res = res
-            && _pad_query_convert_to_time (peer, format, eventsegment->duration,
-            &tduration);
-
-        gst_object_unref (peer);
-      }
-
-      if (!res) {
-        tstart = 0;
-        tstop = GST_CLOCK_TIME_NONE;
-        tposition = 0;
-        tduration = GST_CLOCK_TIME_NONE;
-        ttime = 0;
-        tbase = 0;
-      }
-
-      gst_segment_init (&self->subtitle_segment, GST_FORMAT_TIME);
-      self->subtitle_segment.start = tstart;
-      self->subtitle_segment.stop = tstop;
-      self->subtitle_segment.base = tbase;
-      self->subtitle_segment.time = ttime;
-      self->subtitle_segment.position = tposition;
-      self->subtitle_segment.duration = tduration;
-    }
+    gst_event_copy_segment (event, &self->subtitle_segment);
     GST_DEBUG_OBJECT (pad, "New subtitle segment: %" GST_SEGMENT_FORMAT,
         &self->subtitle_segment);
   }
@@ -2222,8 +2105,8 @@ gst_subtitle_overlay_init (GstSubtitleOverlay * self)
   GstPadTemplate *templ;
   GstPad *proxypad = NULL;
 
-  g_mutex_init (&self->lock);
-  g_mutex_init (&self->factories_lock);
+  self->lock = g_mutex_new ();
+  self->factories_lock = g_mutex_new ();
 
   templ = gst_static_pad_template_get (&srctemplate);
   self->srcpad = gst_ghost_pad_new_no_target_from_template ("src", templ);
