@@ -112,22 +112,10 @@ enum
 #undef GST_VIDEO_SIZE_RANGE
 #define GST_VIDEO_SIZE_RANGE "(int) [ 1, 32767]"
 
-/* FIXME: add v210 support
- * FIXME: add v216 support
- * FIXME: add NV21 support
- * FIXME: add UYVP support
- * FIXME: add A420 support
- * FIXME: add YUV9 support
- * FIXME: add YVU9 support
- * FIXME: add IYU1 support
- * FIXME: add r210 support
- */
-
-/* FIXME: if we can do NV12, NV21 shouldn't be so hard */
 #define GST_VIDEO_FORMATS "{ I420, YV12, YUY2, UYVY, AYUV, RGBx, " \
     "BGRx, xRGB, xBGR, RGBA, BGRA, ARGB, ABGR, RGB, " \
     "BGR, Y41B, Y42B, YVYU, Y444, GRAY8, GRAY16_BE, GRAY16_LE, " \
-    "v308, RGB16, RGB15, ARGB64, AYUV64, NV12 } "
+    "v308, Y800, Y16, RGB16, RGB15, ARGB64, AYUV64, NV12 } "
 
 
 static GstStaticCaps gst_video_scale_format_caps =
@@ -143,7 +131,7 @@ gst_video_scale_method_get_type (void)
     {GST_VIDEO_SCALE_NEAREST, "Nearest Neighbour", "nearest-neighbour"},
     {GST_VIDEO_SCALE_BILINEAR, "Bilinear", "bilinear"},
     {GST_VIDEO_SCALE_4TAP, "4-tap", "4-tap"},
-    {GST_VIDEO_SCALE_LANCZOS, "Lanczos (experimental/unstable)", "lanczos"},
+    {GST_VIDEO_SCALE_LANCZOS, "Lanczos", "lanczos"},
     {0, NULL, NULL},
   };
 
@@ -410,8 +398,8 @@ get_formats_filter (GstVideoScaleMethod method)
           GST_STATIC_CAPS ("video/x-raw,"
           "format = (string) { RGBx, xRGB, BGRx, xBGR, RGBA, "
           "ARGB, BGRA, ABGR, AYUV, ARGB64, AYUV64, "
-          "RGB, BGR, v308, YUY2, YVYU, UYVY, "
-          "GRAY8, GRAY16_LE, GRAY16_BE, I420, YV12, "
+          "RGB, BGR, v308, YUY2, YVYU, UYVY, Y800, "
+          "GRAY8, GRAY16_LE, GRAY16_BE, Y16, I420, YV12, "
           "Y444, Y42B, Y41B, RGB16, RGB15 }");
       return gst_static_caps_get (&fourtap_filter);
     }
@@ -543,7 +531,7 @@ gst_video_scale_set_info (GstVideoFilter * filter, GstCaps * in,
 
   if (videoscale->tmp_buf)
     g_free (videoscale->tmp_buf);
-  videoscale->tmp_buf = g_malloc (out_info->width * sizeof (guint64) * 4);
+  videoscale->tmp_buf = g_malloc (out_info->width * 8 * 4);
 
   if (in_info->width == out_info->width && in_info->height == out_info->height) {
     gst_base_transform_set_passthrough (GST_BASE_TRANSFORM (filter), TRUE);
@@ -1083,10 +1071,12 @@ _get_black_for_format (GstVideoFormat format)
       return black[5];
     case GST_VIDEO_FORMAT_UYVY:
       return black[6];
+    case GST_VIDEO_FORMAT_Y800:
     case GST_VIDEO_FORMAT_GRAY8:
       return black[7];
     case GST_VIDEO_FORMAT_GRAY16_LE:
     case GST_VIDEO_FORMAT_GRAY16_BE:
+    case GST_VIDEO_FORMAT_Y16:
       return NULL;              /* Handled by the caller */
     case GST_VIDEO_FORMAT_I420:
     case GST_VIDEO_FORMAT_YV12:
@@ -1251,6 +1241,7 @@ gst_video_scale_transform_frame (GstVideoFilter * filter,
           goto unknown_mode;
       }
       break;
+    case GST_VIDEO_FORMAT_Y800:
     case GST_VIDEO_FORMAT_GRAY8:
       if (add_borders)
         vs_fill_borders_Y (&dest[0], black);
@@ -1270,6 +1261,7 @@ gst_video_scale_transform_frame (GstVideoFilter * filter,
       break;
     case GST_VIDEO_FORMAT_GRAY16_LE:
     case GST_VIDEO_FORMAT_GRAY16_BE:
+    case GST_VIDEO_FORMAT_Y16:
       if (add_borders)
         vs_fill_borders_Y16 (&dest[0], 0);
       switch (method) {
@@ -1412,20 +1404,17 @@ gst_video_scale_src_event (GstBaseTransform * trans, GstEvent * event)
 
   switch (GST_EVENT_TYPE (event)) {
     case GST_EVENT_NAVIGATION:
-      if (filter->in_info.width != filter->out_info.width ||
-          filter->in_info.height != filter->out_info.height) {
-        event =
-            GST_EVENT (gst_mini_object_make_writable (GST_MINI_OBJECT (event)));
+      event =
+          GST_EVENT (gst_mini_object_make_writable (GST_MINI_OBJECT (event)));
 
-        structure = (GstStructure *) gst_event_get_structure (event);
-        if (gst_structure_get_double (structure, "pointer_x", &a)) {
-          gst_structure_set (structure, "pointer_x", G_TYPE_DOUBLE,
-              a * filter->in_info.width / filter->out_info.width, NULL);
-        }
-        if (gst_structure_get_double (structure, "pointer_y", &a)) {
-          gst_structure_set (structure, "pointer_y", G_TYPE_DOUBLE,
-              a * filter->in_info.height / filter->out_info.height, NULL);
-        }
+      structure = (GstStructure *) gst_event_get_structure (event);
+      if (gst_structure_get_double (structure, "pointer_x", &a)) {
+        gst_structure_set (structure, "pointer_x", G_TYPE_DOUBLE,
+            a * filter->in_info.width / filter->out_info.width, NULL);
+      }
+      if (gst_structure_get_double (structure, "pointer_y", &a)) {
+        gst_structure_set (structure, "pointer_y", G_TYPE_DOUBLE,
+            a * filter->in_info.height / filter->out_info.height, NULL);
       }
       break;
     default:
