@@ -124,9 +124,9 @@ struct _GstVideoTestSrc {
 
   /* video state */
   GstVideoInfo info;
-  gboolean bayer;
-  gint x_invert;
-  gint y_invert;
+
+  char *format_name;
+  struct format_list_struct *format;
 
   /* private */
   gint64 timestamp_offset;              /* base offset */
@@ -161,7 +161,6 @@ struct _GstVideoTestSrc {
   guint8 *tmpline_u8;
   guint8 *tmpline;
   guint8 *tmpline2;
-  guint16 *tmpline_u16;
 };
 
 struct _GstVideoTestSrcClass {
