@@ -45,24 +45,27 @@
 #include <gst/gst.h>
 #include <gst/base/gstbasetransform.h>
 #include <gst/audio/audio.h>
-#include <gst/interfaces/mixer.h>
-#include <gst/controller/gstcontroller.h>
-#include <gst/audio/audio.h>
 #include <gst/audio/gstaudiofilter.h>
-#include <liboil/liboil.h>
 
+#ifdef HAVE_ORC
+#include <orc/orcfunctions.h>
+#else
+#define orc_memset memset
+#endif
+
+#include "gstvolumeorc.h"
 #include "gstvolume.h"
 
 /* some defines for audio processing */
 /* the volume factor is a range from 0.0 to (arbitrary) VOLUME_MAX_DOUBLE = 10.0
  * we map 1.0 to VOLUME_UNITY_INT*
  */
-#define VOLUME_UNITY_INT8            32 /* internal int for unity 2^(8-3) */
-#define VOLUME_UNITY_INT8_BIT_SHIFT  5  /* number of bits to shift for unity */
-#define VOLUME_UNITY_INT16           8192       /* internal int for unity 2^(16-3) */
-#define VOLUME_UNITY_INT16_BIT_SHIFT 13 /* number of bits to shift for unity */
-#define VOLUME_UNITY_INT24           2097152    /* internal int for unity 2^(24-3) */
-#define VOLUME_UNITY_INT24_BIT_SHIFT 21 /* number of bits to shift for unity */
+#define VOLUME_UNITY_INT8            8  /* internal int for unity 2^(8-5) */
+#define VOLUME_UNITY_INT8_BIT_SHIFT  3  /* number of bits to shift for unity */
+#define VOLUME_UNITY_INT16           2048       /* internal int for unity 2^(16-5) */
+#define VOLUME_UNITY_INT16_BIT_SHIFT 11 /* number of bits to shift for unity */
+#define VOLUME_UNITY_INT24           524288     /* internal int for unity 2^(24-5) */
+#define VOLUME_UNITY_INT24_BIT_SHIFT 19 /* number of bits to shift for unity */
 #define VOLUME_UNITY_INT32           134217728  /* internal int for unity 2^(32-5) */
 #define VOLUME_UNITY_INT32_BIT_SHIFT 27
 #define VOLUME_MAX_DOUBLE            10.0
@@ -75,9 +78,6 @@
 #define VOLUME_MAX_INT32             G_MAXINT32
 #define VOLUME_MIN_INT32             G_MININT32
 
-/* number of steps we use for the mixer interface to go from 0.0 to 1.0 */
-# define VOLUME_STEPS           100
-
 #define GST_CAT_DEFAULT gst_volume_debug
 GST_DEBUG_CATEGORY_STATIC (GST_CAT_DEFAULT);
 
@@ -98,70 +98,20 @@ enum
   PROP_VOLUME
 };
 
+#if G_BYTE_ORDER == G_LITTLE_ENDIAN
 #define ALLOWED_CAPS \
-        "audio/x-raw-float, " \
-        "rate = (int) [ 1, MAX ], " \
-        "channels = (int) [ 1, MAX ], " \
-        "endianness = (int) BYTE_ORDER, " \
-        "width = (int) {32, 64}; " \
-        "audio/x-raw-int, " \
-        "channels = (int) [ 1, MAX ], " \
-        "rate = (int) [ 1,  MAX ], " \
-        "endianness = (int) BYTE_ORDER, " \
-        "width = (int) 8, " \
-        "depth = (int) 8, " \
-        "signed = (bool) TRUE; " \
-        "audio/x-raw-int, " \
-        "channels = (int) [ 1, MAX ], " \
-        "rate = (int) [ 1,  MAX ], " \
-        "endianness = (int) BYTE_ORDER, " \
-        "width = (int) 16, " \
-        "depth = (int) 16, " \
-        "signed = (bool) TRUE; " \
-        "audio/x-raw-int, " \
-        "channels = (int) [ 1, MAX ], " \
-        "rate = (int) [ 1,  MAX ], " \
-        "endianness = (int) BYTE_ORDER, " \
-        "width = (int) 24, " \
-        "depth = (int) 24, " \
-        "signed = (bool) TRUE; " \
-        "audio/x-raw-int, " \
-        "channels = (int) [ 1, MAX ], " \
-        "rate = (int) [ 1,  MAX ], " \
-        "endianness = (int) BYTE_ORDER, " \
-        "width = (int) 32, " \
-	"depth = (int) 32, " \
-	"signed = (bool) TRUE"
+    GST_AUDIO_CAPS_MAKE ("{ F32LE, F64LE, S8, S16LE, S24LE, S32LE }") \
+    ", layout = (string) interleaved"
+#else
+#define ALLOWED_CAPS \
+    GST_AUDIO_CAPS_MAKE ("{ F32BE, F64BE, S8, S16BE, S24BE, S32BE }") \
+    ", layout = (string) { interleaved, non-interleaved }"
+#endif
 
-static void gst_volume_interface_init (GstImplementsInterfaceClass * klass);
-static void gst_volume_mixer_init (GstMixerClass * iface);
-
-#define _init_interfaces(type)                                          \
-  {                                                                     \
-    static const GInterfaceInfo voliface_info = {                       \
-      (GInterfaceInitFunc) gst_volume_interface_init,                   \
-      NULL,                                                             \
-      NULL                                                              \
-    };                                                                  \
-    static const GInterfaceInfo volmixer_info = {                       \
-      (GInterfaceInitFunc) gst_volume_mixer_init,                       \
-      NULL,                                                             \
-      NULL                                                              \
-    };                                                                  \
-    static const GInterfaceInfo svol_info = {                           \
-      NULL,                                                             \
-      NULL,                                                             \
-      NULL                                                              \
-    };                                                                  \
-                                                                        \
-    g_type_add_interface_static (type, GST_TYPE_IMPLEMENTS_INTERFACE,   \
-        &voliface_info);                                                \
-    g_type_add_interface_static (type, GST_TYPE_MIXER, &volmixer_info); \
-    g_type_add_interface_static (type, GST_TYPE_STREAM_VOLUME, &svol_info); \
-  }
-
-GST_BOILERPLATE_FULL (GstVolume, gst_volume, GstAudioFilter,
-    GST_TYPE_AUDIO_FILTER, _init_interfaces);
+#define gst_volume_parent_class parent_class
+G_DEFINE_TYPE_WITH_CODE (GstVolume, gst_volume,
+    GST_TYPE_AUDIO_FILTER,
+    G_IMPLEMENT_INTERFACE (GST_TYPE_STREAM_VOLUME, NULL));
 
 static void volume_set_property (GObject * object, guint prop_id,
     const GValue * value, GParamSpec * pspec);
@@ -174,7 +124,7 @@ static GstFlowReturn volume_transform_ip (GstBaseTransform * base,
     GstBuffer * outbuf);
 static gboolean volume_stop (GstBaseTransform * base);
 static gboolean volume_setup (GstAudioFilter * filter,
-    GstRingBufferSpec * format);
+    const GstAudioInfo * info);
 
 static void volume_process_double (GstVolume * self, gpointer bytes,
     guint n_bytes);
@@ -213,70 +163,62 @@ static void volume_process_controlled_int8_clamp (GstVolume * self,
 /* helper functions */
 
 static gboolean
-volume_choose_func (GstVolume * self)
+volume_choose_func (GstVolume * self, const GstAudioInfo * info)
 {
+  GstAudioFormat format;
+
   self->process = NULL;
   self->process_controlled = NULL;
 
-  if (GST_AUDIO_FILTER (self)->format.caps == NULL)
+  format = GST_AUDIO_INFO_FORMAT (info);
+
+  if (format == GST_AUDIO_FORMAT_UNKNOWN)
     return FALSE;
 
-  switch (GST_AUDIO_FILTER (self)->format.type) {
-    case GST_BUFTYPE_LINEAR:
-      switch (GST_AUDIO_FILTER (self)->format.width) {
-        case 32:
-          /* only clamp if the gain is greater than 1.0
-           */
-          if (self->current_vol_i32 > VOLUME_UNITY_INT32) {
-            self->process = volume_process_int32_clamp;
-          } else {
-            self->process = volume_process_int32;
-          }
-          self->process_controlled = volume_process_controlled_int32_clamp;
-          break;
-        case 24:
-          /* only clamp if the gain is greater than 1.0
-           */
-          if (self->current_vol_i24 > VOLUME_UNITY_INT24) {
-            self->process = volume_process_int24_clamp;
-          } else {
-            self->process = volume_process_int24;
-          }
-          self->process_controlled = volume_process_controlled_int24_clamp;
-          break;
-        case 16:
-          /* only clamp if the gain is greater than 1.0
-           */
-          if (self->current_vol_i16 > VOLUME_UNITY_INT16) {
-            self->process = volume_process_int16_clamp;
-          } else {
-            self->process = volume_process_int16;
-          }
-          self->process_controlled = volume_process_controlled_int16_clamp;
-          break;
-        case 8:
-          /* only clamp if the gain is greater than 1.0
-           */
-          if (self->current_vol_i16 > VOLUME_UNITY_INT8) {
-            self->process = volume_process_int8_clamp;
-          } else {
-            self->process = volume_process_int8;
-          }
-          self->process_controlled = volume_process_controlled_int8_clamp;
-          break;
+  switch (format) {
+    case GST_AUDIO_FORMAT_S32:
+      /* only clamp if the gain is greater than 1.0 */
+      if (self->current_vol_i32 > VOLUME_UNITY_INT32) {
+        self->process = volume_process_int32_clamp;
+      } else {
+        self->process = volume_process_int32;
       }
+      self->process_controlled = volume_process_controlled_int32_clamp;
       break;
-    case GST_BUFTYPE_FLOAT:
-      switch (GST_AUDIO_FILTER (self)->format.width) {
-        case 32:
-          self->process = volume_process_float;
-          self->process_controlled = volume_process_controlled_float;
-          break;
-        case 64:
-          self->process = volume_process_double;
-          self->process_controlled = volume_process_controlled_double;
-          break;
+    case GST_AUDIO_FORMAT_S24:
+      /* only clamp if the gain is greater than 1.0 */
+      if (self->current_vol_i24 > VOLUME_UNITY_INT24) {
+        self->process = volume_process_int24_clamp;
+      } else {
+        self->process = volume_process_int24;
       }
+      self->process_controlled = volume_process_controlled_int24_clamp;
+      break;
+    case GST_AUDIO_FORMAT_S16:
+      /* only clamp if the gain is greater than 1.0 */
+      if (self->current_vol_i16 > VOLUME_UNITY_INT16) {
+        self->process = volume_process_int16_clamp;
+      } else {
+        self->process = volume_process_int16;
+      }
+      self->process_controlled = volume_process_controlled_int16_clamp;
+      break;
+    case GST_AUDIO_FORMAT_S8:
+      /* only clamp if the gain is greater than 1.0 */
+      if (self->current_vol_i8 > VOLUME_UNITY_INT8) {
+        self->process = volume_process_int8_clamp;
+      } else {
+        self->process = volume_process_int8;
+      }
+      self->process_controlled = volume_process_controlled_int8_clamp;
+      break;
+    case GST_AUDIO_FORMAT_F32:
+      self->process = volume_process_float;
+      self->process_controlled = volume_process_controlled_float;
+      break;
+    case GST_AUDIO_FORMAT_F64:
+      self->process = volume_process_double;
+      self->process_controlled = volume_process_controlled_double;
       break;
     default:
       break;
@@ -286,11 +228,11 @@ volume_choose_func (GstVolume * self)
 }
 
 static gboolean
-volume_update_volume (GstVolume * self, gfloat volume, gboolean mute)
+volume_update_volume (GstVolume * self, const GstAudioInfo * info,
+    gfloat volume, gboolean mute)
 {
   gboolean passthrough;
   gboolean res;
-  GstController *controller;
 
   GST_DEBUG_OBJECT (self, "configure mute %d, volume %f", mute, volume);
 
@@ -320,94 +262,17 @@ volume_update_volume (GstVolume * self, gfloat volume, gboolean mute)
    * because the property can change from 1.0 to something
    * else in the middle of a buffer.
    */
-  controller = gst_object_get_controller (G_OBJECT (self));
-  passthrough = passthrough && (controller == NULL);
+  passthrough &= !gst_object_has_active_control_bindings (GST_OBJECT (self));
 
   GST_DEBUG_OBJECT (self, "set passthrough %d", passthrough);
 
   gst_base_transform_set_passthrough (GST_BASE_TRANSFORM (self), passthrough);
 
-  res = self->negotiated = volume_choose_func (self);
+  res = self->negotiated = volume_choose_func (self, info);
 
   return res;
 }
 
-/* Mixer interface */
-
-static gboolean
-gst_volume_interface_supported (GstImplementsInterface * iface, GType type)
-{
-  return (type == GST_TYPE_MIXER || type == GST_TYPE_STREAM_VOLUME);
-}
-
-static void
-gst_volume_interface_init (GstImplementsInterfaceClass * klass)
-{
-  klass->supported = gst_volume_interface_supported;
-}
-
-static const GList *
-gst_volume_list_tracks (GstMixer * mixer)
-{
-  GstVolume *self = GST_VOLUME (mixer);
-
-  g_return_val_if_fail (self != NULL, NULL);
-  g_return_val_if_fail (GST_IS_VOLUME (self), NULL);
-
-  return self->tracklist;
-}
-
-static void
-gst_volume_set_volume (GstMixer * mixer, GstMixerTrack * track, gint * volumes)
-{
-  GstVolume *self = GST_VOLUME (mixer);
-
-  g_return_if_fail (self != NULL);
-  g_return_if_fail (GST_IS_VOLUME (self));
-
-  GST_OBJECT_LOCK (self);
-  self->volume = (gfloat) volumes[0] / VOLUME_STEPS;
-  GST_OBJECT_UNLOCK (self);
-}
-
-static void
-gst_volume_get_volume (GstMixer * mixer, GstMixerTrack * track, gint * volumes)
-{
-  GstVolume *self = GST_VOLUME (mixer);
-
-  g_return_if_fail (self != NULL);
-  g_return_if_fail (GST_IS_VOLUME (self));
-
-  GST_OBJECT_LOCK (self);
-  volumes[0] = (gint) self->volume * VOLUME_STEPS;
-  GST_OBJECT_UNLOCK (self);
-}
-
-static void
-gst_volume_set_mute (GstMixer * mixer, GstMixerTrack * track, gboolean mute)
-{
-  GstVolume *self = GST_VOLUME (mixer);
-
-  g_return_if_fail (self != NULL);
-  g_return_if_fail (GST_IS_VOLUME (self));
-
-  GST_OBJECT_LOCK (self);
-  self->mute = mute;
-  GST_OBJECT_UNLOCK (self);
-}
-
-static void
-gst_volume_mixer_init (GstMixerClass * klass)
-{
-  GST_MIXER_TYPE (klass) = GST_MIXER_SOFTWARE;
-
-  /* default virtual functions */
-  klass->list_tracks = gst_volume_list_tracks;
-  klass->set_volume = gst_volume_set_volume;
-  klass->get_volume = gst_volume_get_volume;
-  klass->set_mute = gst_volume_set_mute;
-}
-
 /* Element class */
 
 static void
@@ -425,30 +290,17 @@ gst_volume_dispose (GObject * object)
   G_OBJECT_CLASS (parent_class)->dispose (object);
 }
 
-static void
-gst_volume_base_init (gpointer g_class)
-{
-  GstElementClass *element_class = GST_ELEMENT_CLASS (g_class);
-  GstAudioFilterClass *filter_class = GST_AUDIO_FILTER_CLASS (g_class);
-  GstCaps *caps;
-
-  gst_element_class_set_details_simple (element_class, "Volume",
-      "Filter/Effect/Audio",
-      "Set volume on audio/raw streams", "Andy Wingo <wingo@pobox.com>");
-
-  caps = gst_caps_from_string (ALLOWED_CAPS);
-  gst_audio_filter_class_add_pad_templates (filter_class, caps);
-  gst_caps_unref (caps);
-}
-
 static void
 gst_volume_class_init (GstVolumeClass * klass)
 {
   GObjectClass *gobject_class;
+  GstElementClass *element_class;
   GstBaseTransformClass *trans_class;
   GstAudioFilterClass *filter_class;
+  GstCaps *caps;
 
   gobject_class = (GObjectClass *) klass;
+  element_class = (GstElementClass *) klass;
   trans_class = (GstBaseTransformClass *) klass;
   filter_class = (GstAudioFilterClass *) (klass);
 
@@ -466,34 +318,31 @@ gst_volume_class_init (GstVolumeClass * klass)
           0.0, VOLUME_MAX_DOUBLE, DEFAULT_PROP_VOLUME,
           G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_STATIC_STRINGS));
 
+  gst_element_class_set_static_metadata (element_class, "Volume",
+      "Filter/Effect/Audio",
+      "Set volume on audio/raw streams", "Andy Wingo <wingo@pobox.com>");
+
+  caps = gst_caps_from_string (ALLOWED_CAPS);
+  gst_audio_filter_class_add_pad_templates (filter_class, caps);
+  gst_caps_unref (caps);
+
   trans_class->before_transform = GST_DEBUG_FUNCPTR (volume_before_transform);
   trans_class->transform_ip = GST_DEBUG_FUNCPTR (volume_transform_ip);
   trans_class->stop = GST_DEBUG_FUNCPTR (volume_stop);
+  trans_class->transform_ip_on_passthrough = FALSE;
+
   filter_class->setup = GST_DEBUG_FUNCPTR (volume_setup);
 }
 
 static void
-gst_volume_init (GstVolume * self, GstVolumeClass * g_class)
+gst_volume_init (GstVolume * self)
 {
-  GstMixerTrack *track = NULL;
-
   self->mute = DEFAULT_PROP_MUTE;;
   self->volume = DEFAULT_PROP_VOLUME;
 
   self->tracklist = NULL;
   self->negotiated = FALSE;
 
-  track = g_object_new (GST_TYPE_MIXER_TRACK, NULL);
-
-  if (GST_IS_MIXER_TRACK (track)) {
-    track->label = g_strdup ("volume");
-    track->num_channels = 1;
-    track->min_volume = 0;
-    track->max_volume = VOLUME_STEPS;
-    track->flags = GST_MIXER_TRACK_SOFTWARE;
-    self->tracklist = g_list_append (self->tracklist, track);
-  }
-
   gst_base_transform_set_gap_aware (GST_BASE_TRANSFORM (self), TRUE);
 }
 
@@ -503,9 +352,7 @@ volume_process_double (GstVolume * self, gpointer bytes, guint n_bytes)
   gdouble *data = (gdouble *) bytes;
   guint num_samples = n_bytes / sizeof (gdouble);
 
-  gdouble vol = self->current_volume;
-
-  oil_scalarmultiply_f64_ns (data, data, &vol, num_samples);
+  orc_scalarmultiply_f64_ns (data, self->current_volume, num_samples);
 }
 
 static void
@@ -517,10 +364,14 @@ volume_process_controlled_double (GstVolume * self, gpointer bytes,
   guint i, j;
   gdouble vol;
 
-  for (i = 0; i < num_samples; i++) {
-    vol = *volume++;
-    for (j = 0; j < channels; j++) {
-      *data++ *= vol;
+  if (channels == 1) {
+    orc_process_controlled_f64_1ch (data, volume, num_samples);
+  } else {
+    for (i = 0; i < num_samples; i++) {
+      vol = *volume++;
+      for (j = 0; j < channels; j++) {
+        *data++ *= vol;
+      }
     }
   }
 }
@@ -531,17 +382,7 @@ volume_process_float (GstVolume * self, gpointer bytes, guint n_bytes)
   gfloat *data = (gfloat *) bytes;
   guint num_samples = n_bytes / sizeof (gfloat);
 
-#if 0
-  guint i;
-
-  for (i = 0; i < num_samples; i++) {
-    *data++ *= self->real_vol_f;
-  }
-  /* time "gst-launch 2>/dev/null audiotestsrc wave=7 num-buffers=10000 ! audio/x-raw-float !
-   * volume volume=1.5 ! fakesink" goes from 0m0.850s -> 0m0.717s with liboil
-   */
-#endif
-  oil_scalarmultiply_f32_ns (data, data, &self->current_volume, num_samples);
+  orc_scalarmultiply_f32_ns (data, self->current_volume, num_samples);
 }
 
 static void
@@ -553,10 +394,16 @@ volume_process_controlled_float (GstVolume * self, gpointer bytes,
   guint i, j;
   gdouble vol;
 
-  for (i = 0; i < num_samples; i++) {
-    vol = *volume++;
-    for (j = 0; j < channels; j++) {
-      *data++ *= vol;
+  if (channels == 1) {
+    orc_process_controlled_f32_1ch (data, volume, num_samples);
+  } else if (channels == 2) {
+    orc_process_controlled_f32_2ch (data, volume, num_samples);
+  } else {
+    for (i = 0; i < num_samples; i++) {
+      vol = *volume++;
+      for (j = 0; j < channels; j++) {
+        *data++ *= vol;
+      }
     }
   }
 }
@@ -565,37 +412,23 @@ static void
 volume_process_int32 (GstVolume * self, gpointer bytes, guint n_bytes)
 {
   gint32 *data = (gint32 *) bytes;
-  guint i, num_samples;
-  gint64 val;
+  guint num_samples = n_bytes / sizeof (gint);
 
-  num_samples = n_bytes / sizeof (gint);
-  for (i = 0; i < num_samples; i++) {
-    /* we use bitshifting instead of dividing by UNITY_INT for speed */
-    val = (gint64) * data;
-    val =
-        (((gint64) self->current_vol_i32 *
-            val) >> VOLUME_UNITY_INT32_BIT_SHIFT);
-    *data++ = (gint32) val;
-  }
+  /* hard coded in volume.orc */
+  g_assert (VOLUME_UNITY_INT32_BIT_SHIFT == 27);
+  orc_process_int32 (data, self->current_vol_i32, num_samples);
 }
 
 static void
 volume_process_int32_clamp (GstVolume * self, gpointer bytes, guint n_bytes)
 {
   gint32 *data = (gint32 *) bytes;
-  guint i, num_samples;
-  gint64 val;
+  guint num_samples = n_bytes / sizeof (gint);
 
-  num_samples = n_bytes / sizeof (gint32);
+  /* hard coded in volume.orc */
+  g_assert (VOLUME_UNITY_INT32_BIT_SHIFT == 27);
 
-  for (i = 0; i < num_samples; i++) {
-    /* we use bitshifting instead of dividing by UNITY_INT for speed */
-    val = (gint64) * data;
-    val =
-        (((gint64) self->current_vol_i32 *
-            val) >> VOLUME_UNITY_INT32_BIT_SHIFT);
-    *data++ = (gint32) CLAMP (val, VOLUME_MIN_INT32, VOLUME_MAX_INT32);
-  }
+  orc_process_int32_clamp (data, self->current_vol_i32, num_samples);
 }
 
 static void
@@ -607,11 +440,15 @@ volume_process_controlled_int32_clamp (GstVolume * self, gpointer bytes,
   guint num_samples = n_bytes / (sizeof (gint32) * channels);
   gdouble vol, val;
 
-  for (i = 0; i < num_samples; i++) {
-    vol = *volume++;
-    for (j = 0; j < channels; j++) {
-      val = *data * vol;
-      *data++ = (gint32) CLAMP (val, VOLUME_MIN_INT32, VOLUME_MAX_INT32);
+  if (channels == 1) {
+    orc_process_controlled_int32_1ch (data, volume, num_samples);
+  } else {
+    for (i = 0; i < num_samples; i++) {
+      vol = *volume++;
+      for (j = 0; j < channels; j++) {
+        val = *data * vol;
+        *data++ = (gint32) CLAMP (val, VOLUME_MIN_INT32, VOLUME_MAX_INT32);
+      }
     }
   }
 }
@@ -707,38 +544,22 @@ volume_process_int16 (GstVolume * self, gpointer bytes, guint n_bytes)
   gint16 *data = (gint16 *) bytes;
   guint num_samples = n_bytes / sizeof (gint16);
 
-  guint i;
-  gint val;
+  /* hard coded in volume.orc */
+  g_assert (VOLUME_UNITY_INT16_BIT_SHIFT == 11);
 
-  for (i = 0; i < num_samples; i++) {
-    /* we use bitshifting instead of dividing by UNITY_INT for speed */
-    val = (gint) * data;
-    *data++ =
-        (gint16) ((self->current_vol_i16 *
-            val) >> VOLUME_UNITY_INT16_BIT_SHIFT);
-  }
+  orc_process_int16 (data, self->current_vol_i16, num_samples);
 }
 
 static void
 volume_process_int16_clamp (GstVolume * self, gpointer bytes, guint n_bytes)
 {
   gint16 *data = (gint16 *) bytes;
-  guint i, num_samples;
-  gint val;
+  guint num_samples = n_bytes / sizeof (gint16);
 
-  num_samples = n_bytes / sizeof (gint16);
+  /* hard coded in volume.orc */
+  g_assert (VOLUME_UNITY_INT16_BIT_SHIFT == 11);
 
-  /* FIXME: oil_scalarmultiply_s16_ns ?
-   * https://bugs.freedesktop.org/show_bug.cgi?id=7060
-   */
-  for (i = 0; i < num_samples; i++) {
-    /* we use bitshifting instead of dividing by UNITY_INT for speed */
-    val = (gint) * data;
-    *data++ =
-        (gint16) CLAMP ((self->current_vol_i16 *
-            val) >> VOLUME_UNITY_INT16_BIT_SHIFT, VOLUME_MIN_INT16,
-        VOLUME_MAX_INT16);
-  }
+  orc_process_int16_clamp (data, self->current_vol_i16, num_samples);
 }
 
 static void
@@ -750,11 +571,17 @@ volume_process_controlled_int16_clamp (GstVolume * self, gpointer bytes,
   guint num_samples = n_bytes / (sizeof (gint16) * channels);
   gdouble vol, val;
 
-  for (i = 0; i < num_samples; i++) {
-    vol = *volume++;
-    for (j = 0; j < channels; j++) {
-      val = *data * vol;
-      *data++ = (gint16) CLAMP (val, VOLUME_MIN_INT16, VOLUME_MAX_INT16);
+  if (channels == 1) {
+    orc_process_controlled_int16_1ch (data, volume, num_samples);
+  } else if (channels == 2) {
+    orc_process_controlled_int16_2ch (data, volume, num_samples);
+  } else {
+    for (i = 0; i < num_samples; i++) {
+      vol = *volume++;
+      for (j = 0; j < channels; j++) {
+        val = *data * vol;
+        *data++ = (gint16) CLAMP (val, VOLUME_MIN_INT16, VOLUME_MAX_INT16);
+      }
     }
   }
 }
@@ -764,34 +591,23 @@ volume_process_int8 (GstVolume * self, gpointer bytes, guint n_bytes)
 {
   gint8 *data = (gint8 *) bytes;
   guint num_samples = n_bytes / sizeof (gint8);
-  guint i;
-  gint val;
 
-  for (i = 0; i < num_samples; i++) {
-    /* we use bitshifting instead of dividing by UNITY_INT for speed */
-    val = (gint) * data;
-    *data++ =
-        (gint8) ((self->current_vol_i8 * val) >> VOLUME_UNITY_INT8_BIT_SHIFT);
-  }
+  /* hard coded in volume.orc */
+  g_assert (VOLUME_UNITY_INT8_BIT_SHIFT == 3);
+
+  orc_process_int8 (data, self->current_vol_i8, num_samples);
 }
 
 static void
 volume_process_int8_clamp (GstVolume * self, gpointer bytes, guint n_bytes)
 {
   gint8 *data = (gint8 *) bytes;
-  guint i, num_samples;
-  gint val;
+  guint num_samples = n_bytes / sizeof (gint8);
 
-  num_samples = n_bytes / sizeof (gint8);
+  /* hard coded in volume.orc */
+  g_assert (VOLUME_UNITY_INT8_BIT_SHIFT == 3);
 
-  for (i = 0; i < num_samples; i++) {
-    /* we use bitshifting instead of dividing by UNITY_INT for speed */
-    val = (gint) * data;
-    *data++ =
-        (gint8) CLAMP ((self->current_vol_i8 *
-            val) >> VOLUME_UNITY_INT8_BIT_SHIFT, VOLUME_MIN_INT8,
-        VOLUME_MAX_INT8);
-  }
+  orc_process_int8_clamp (data, self->current_vol_i8, num_samples);
 }
 
 static void
@@ -803,11 +619,17 @@ volume_process_controlled_int8_clamp (GstVolume * self, gpointer bytes,
   guint num_samples = n_bytes / (sizeof (gint8) * channels);
   gdouble val, vol;
 
-  for (i = 0; i < num_samples; i++) {
-    vol = *volume++;
-    for (j = 0; j < channels; j++) {
-      val = *data * vol;
-      *data++ = (gint8) CLAMP (val, VOLUME_MIN_INT8, VOLUME_MAX_INT8);
+  if (channels == 1) {
+    orc_process_controlled_int8_1ch (data, volume, num_samples);
+  } else if (channels == 2) {
+    orc_process_controlled_int8_2ch (data, volume, num_samples);
+  } else {
+    for (i = 0; i < num_samples; i++) {
+      vol = *volume++;
+      for (j = 0; j < channels; j++) {
+        val = *data * vol;
+        *data++ = (gint8) CLAMP (val, VOLUME_MIN_INT8, VOLUME_MAX_INT8);
+      }
     }
   }
 }
@@ -816,7 +638,7 @@ volume_process_controlled_int8_clamp (GstVolume * self, gpointer bytes,
 
 /* get notified of caps and plug in the correct process function */
 static gboolean
-volume_setup (GstAudioFilter * filter, GstRingBufferSpec * format)
+volume_setup (GstAudioFilter * filter, const GstAudioInfo * info)
 {
   gboolean res;
   GstVolume *self = GST_VOLUME (filter);
@@ -828,7 +650,7 @@ volume_setup (GstAudioFilter * filter, GstRingBufferSpec * format)
   mute = self->mute;
   GST_OBJECT_UNLOCK (self);
 
-  res = volume_update_volume (self, volume, mute);
+  res = volume_update_volume (self, info, volume, mute);
   if (!res) {
     GST_ELEMENT_ERROR (self, CORE, NEGOTIATION,
         ("Invalid incoming format"), (NULL));
@@ -871,7 +693,7 @@ volume_before_transform (GstBaseTransform * base, GstBuffer * buffer)
       GST_TIME_ARGS (timestamp));
 
   if (GST_CLOCK_TIME_IS_VALID (timestamp))
-    gst_object_sync_values (G_OBJECT (self), timestamp);
+    gst_object_sync_values (GST_OBJECT (self), timestamp);
 
   /* get latest values */
   GST_OBJECT_LOCK (self);
@@ -882,7 +704,7 @@ volume_before_transform (GstBaseTransform * base, GstBuffer * buffer)
   if ((volume != self->current_volume) || (mute != self->current_mute)) {
     /* the volume or mute was updated, update our internal state before
      * we continue processing. */
-    volume_update_volume (self, volume, mute);
+    volume_update_volume (self, GST_AUDIO_FILTER_INFO (self), volume, mute);
   }
 }
 
@@ -893,35 +715,35 @@ volume_before_transform (GstBaseTransform * base, GstBuffer * buffer)
 static GstFlowReturn
 volume_transform_ip (GstBaseTransform * base, GstBuffer * outbuf)
 {
+  GstAudioFilter *filter = GST_AUDIO_FILTER_CAST (base);
   GstVolume *self = GST_VOLUME (base);
-  guint8 *data;
-  guint size;
-  GstControlSource *mute_csource, *volume_csource;
+  GstMapInfo map;
+  GstControlBinding *mute_cb, *volume_cb;
 
   if (G_UNLIKELY (!self->negotiated))
     goto not_negotiated;
 
-  /* don't process data in passthrough-mode */
-  if (gst_base_transform_is_passthrough (base) ||
-      GST_BUFFER_FLAG_IS_SET (outbuf, GST_BUFFER_FLAG_GAP))
+  /* don't process data with GAP */
+  if (GST_BUFFER_FLAG_IS_SET (outbuf, GST_BUFFER_FLAG_GAP))
     return GST_FLOW_OK;
 
-  data = GST_BUFFER_DATA (outbuf);
-  size = GST_BUFFER_SIZE (outbuf);
+  gst_buffer_map (outbuf, &map, GST_MAP_READWRITE);
 
-  mute_csource = gst_object_get_control_source (G_OBJECT (self), "mute");
-  volume_csource = gst_object_get_control_source (G_OBJECT (self), "volume");
-  if (mute_csource || (volume_csource && !self->current_mute)) {
-    gint rate = GST_AUDIO_FILTER_CAST (self)->format.rate;
-    gint width = GST_AUDIO_FILTER_CAST (self)->format.width / 8;
-    gint channels = GST_AUDIO_FILTER_CAST (self)->format.channels;
-    guint nsamples = size / (width * channels);
+  mute_cb = gst_object_get_control_binding (GST_OBJECT (self), "mute");
+  volume_cb = gst_object_get_control_binding (GST_OBJECT (self), "volume");
+
+  if (mute_cb || (volume_cb && !self->current_mute)) {
+    gint rate = GST_AUDIO_INFO_RATE (&filter->info);
+    gint width = GST_AUDIO_FORMAT_INFO_WIDTH (filter->info.finfo) / 8;
+    gint channels = GST_AUDIO_INFO_CHANNELS (&filter->info);
+    guint nsamples = map.size / (width * channels);
     GstClockTime interval = gst_util_uint64_scale_int (1, GST_SECOND, rate);
     GstClockTime ts = GST_BUFFER_TIMESTAMP (outbuf);
+    gboolean use_mutes = FALSE;
 
     ts = gst_segment_to_stream_time (&base->segment, GST_FORMAT_TIME, ts);
 
-    if (self->mutes_count < nsamples && mute_csource) {
+    if (self->mutes_count < nsamples && mute_cb) {
       self->mutes = g_realloc (self->mutes, sizeof (gboolean) * nsamples);
       self->mutes_count = nsamples;
     }
@@ -931,57 +753,51 @@ volume_transform_ip (GstBaseTransform * base, GstBuffer * outbuf)
       self->volumes_count = nsamples;
     }
 
-    if (mute_csource) {
-      GstValueArray va = { "mute", nsamples, interval, (gpointer) self->mutes };
-
-      if (!gst_control_source_get_value_array (mute_csource, ts, &va))
+    if (mute_cb) {
+      if (!gst_control_binding_get_value_array (mute_cb, ts, interval,
+              nsamples, (gpointer) self->mutes))
         goto controller_failure;
 
-      gst_object_unref (mute_csource);
-      mute_csource = NULL;
+      gst_object_replace ((GstObject **) & mute_cb, NULL);
+      use_mutes = TRUE;
     } else {
       g_free (self->mutes);
       self->mutes = NULL;
       self->mutes_count = 0;
     }
 
-    if (volume_csource) {
-      GstValueArray va =
-          { "volume", nsamples, interval, (gpointer) self->volumes };
-
-      if (!gst_control_source_get_value_array (volume_csource, ts, &va))
+    if (volume_cb) {
+      if (!gst_control_binding_get_value_array (volume_cb, ts, interval,
+              nsamples, (gpointer) self->volumes))
         goto controller_failure;
 
-      gst_object_unref (volume_csource);
-      volume_csource = NULL;
+      gst_object_replace ((GstObject **) & volume_cb, NULL);
     } else {
-      guint i;
-
-      for (i = 0; i < nsamples; i++)
-        self->volumes[i] = self->current_volume;
+      orc_memset_f64 (self->volumes, self->current_volume, nsamples);
     }
 
-    if (mute_csource) {
-      guint i;
-
-      for (i = 0; i < nsamples; i++)
-        self->volumes[i] *= (1.0 - self->mutes[i]);
+    if (use_mutes) {
+      orc_prepare_volumes (self->volumes, self->mutes, nsamples);
     }
 
-    self->process_controlled (self, data, self->volumes, channels, size);
+    self->process_controlled (self, map.data, self->volumes, channels,
+        map.size);
 
-    return GST_FLOW_OK;
-  } else if (volume_csource) {
-    gst_object_unref (volume_csource);
+    goto done;
+  } else if (volume_cb) {
+    gst_object_unref (volume_cb);
   }
 
   if (self->current_volume == 0.0 || self->current_mute) {
-    memset (data, 0, size);
+    orc_memset (map.data, 0, map.size);
     GST_BUFFER_FLAG_SET (outbuf, GST_BUFFER_FLAG_GAP);
   } else if (self->current_volume != 1.0) {
-    self->process (self, data, size);
+    self->process (self, map.data, map.size);
   }
 
+done:
+  gst_buffer_unmap (outbuf, &map);
+
   return GST_FLOW_OK;
 
   /* ERRORS */
@@ -993,13 +809,14 @@ not_negotiated:
   }
 controller_failure:
   {
-    if (mute_csource)
-      gst_object_unref (mute_csource);
-    if (volume_csource)
-      gst_object_unref (volume_csource);
+    if (mute_cb)
+      gst_object_unref (mute_cb);
+    if (volume_cb)
+      gst_object_unref (volume_cb);
 
     GST_ELEMENT_ERROR (self, CORE, FAILED,
         ("Failed to get values from controller"), (NULL));
+    gst_buffer_unmap (outbuf, &map);
     return GST_FLOW_ERROR;
   }
 }
@@ -1053,23 +870,14 @@ volume_get_property (GObject * object, guint prop_id, GValue * value,
 static gboolean
 plugin_init (GstPlugin * plugin)
 {
-  oil_init ();
-
-  /* initialize gst controller library */
-  gst_controller_init (NULL, NULL);
-
   GST_DEBUG_CATEGORY_INIT (GST_CAT_DEFAULT, "volume", 0, "Volume gain");
 
-  /* ref class from a thread-safe context to work around missing bit of
-   * thread-safety in GObject */
-  g_type_class_ref (GST_TYPE_MIXER_TRACK);
-
   return gst_element_register (plugin, "volume", GST_RANK_NONE,
       GST_TYPE_VOLUME);
 }
 
 GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
     GST_VERSION_MINOR,
-    "volume",
+    volume,
     "plugin for controlling audio volume",
     plugin_init, VERSION, GST_LICENSE, GST_PACKAGE_NAME, GST_PACKAGE_ORIGIN);
