@@ -109,6 +109,10 @@
 
 /* for developers: there are two useful tools : xvinfo and xvattr */
 
+/* FIXME 0.11: suppress warnings for deprecated API such as GValueArray
+ * with newer GLib versions (>= 2.31.0) */
+#define GLIB_DISABLE_DEPRECATION_WARNINGS
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -126,6 +130,8 @@
 /* Debugging category */
 #include <gst/gstinfo.h>
 
+#include "gst/glib-compat-private.h"
+
 /* for XkbKeycodeToKeysym */
 #include <X11/XKBlib.h>
 
@@ -274,10 +280,10 @@ gst_xvimagesink_xvimage_put (GstXvImageSink * xvimagesink, GstBuffer * xvimage)
 
   /* We take the flow_lock. If expose is in there we don't want to run
      concurrently from the data flow thread */
-  g_mutex_lock (&xvimagesink->flow_lock);
+  g_mutex_lock (xvimagesink->flow_lock);
 
   if (G_UNLIKELY (xvimagesink->xwindow == NULL)) {
-    g_mutex_unlock (&xvimagesink->flow_lock);
+    g_mutex_unlock (xvimagesink->flow_lock);
     return FALSE;
   }
 
@@ -303,7 +309,7 @@ gst_xvimagesink_xvimage_put (GstXvImageSink * xvimagesink, GstBuffer * xvimage)
       draw_border = TRUE;
       xvimage = xvimagesink->cur_image;
     } else {
-      g_mutex_unlock (&xvimagesink->flow_lock);
+      g_mutex_unlock (xvimagesink->flow_lock);
       return TRUE;
     }
   }
@@ -327,24 +333,17 @@ gst_xvimagesink_xvimage_put (GstXvImageSink * xvimagesink, GstBuffer * xvimage)
   }
 
   if (xvimagesink->keep_aspect) {
-    GstVideoRectangle s;
-
-    /* We take the size of the source material as it was negotiated and
-     * corrected for DAR. This size can be different from the cropped size in
-     * which case the image will be scaled to fit the negotiated size. */
-    s.w = GST_VIDEO_SINK_WIDTH (xvimagesink);
-    s.h = GST_VIDEO_SINK_HEIGHT (xvimagesink);
     dst.w = xvimagesink->render_rect.w;
     dst.h = xvimagesink->render_rect.h;
 
-    gst_video_sink_center_rect (s, dst, &result, TRUE);
+    gst_video_sink_center_rect (src, dst, &result, TRUE);
     result.x += xvimagesink->render_rect.x;
     result.y += xvimagesink->render_rect.y;
   } else {
     memcpy (&result, &xvimagesink->render_rect, sizeof (GstVideoRectangle));
   }
 
-  g_mutex_lock (&xvimagesink->x_lock);
+  g_mutex_lock (xvimagesink->x_lock);
 
   if (draw_border && xvimagesink->draw_borders) {
     gst_xvimagesink_xwindow_draw_borders (xvimagesink, xvimagesink->xwindow,
@@ -376,9 +375,9 @@ gst_xvimagesink_xvimage_put (GstXvImageSink * xvimagesink, GstBuffer * xvimage)
 
   XSync (xvimagesink->xcontext->disp, FALSE);
 
-  g_mutex_unlock (&xvimagesink->x_lock);
+  g_mutex_unlock (xvimagesink->x_lock);
 
-  g_mutex_unlock (&xvimagesink->flow_lock);
+  g_mutex_unlock (xvimagesink->flow_lock);
 
   return TRUE;
 }
@@ -393,12 +392,12 @@ gst_xvimagesink_xwindow_decorate (GstXvImageSink * xvimagesink,
   g_return_val_if_fail (GST_IS_XVIMAGESINK (xvimagesink), FALSE);
   g_return_val_if_fail (window != NULL, FALSE);
 
-  g_mutex_lock (&xvimagesink->x_lock);
+  g_mutex_lock (xvimagesink->x_lock);
 
   hints_atom = XInternAtom (xvimagesink->xcontext->disp, "_MOTIF_WM_HINTS",
       True);
   if (hints_atom == None) {
-    g_mutex_unlock (&xvimagesink->x_lock);
+    g_mutex_unlock (xvimagesink->x_lock);
     return FALSE;
   }
 
@@ -413,7 +412,7 @@ gst_xvimagesink_xwindow_decorate (GstXvImageSink * xvimagesink,
 
   XSync (xvimagesink->xcontext->disp, FALSE);
 
-  g_mutex_unlock (&xvimagesink->x_lock);
+  g_mutex_unlock (xvimagesink->x_lock);
 
   g_free (hints);
 
@@ -482,7 +481,7 @@ gst_xvimagesink_xwindow_new (GstXvImageSink * xvimagesink,
   xwindow->height = height;
   xwindow->internal = TRUE;
 
-  g_mutex_lock (&xvimagesink->x_lock);
+  g_mutex_lock (xvimagesink->x_lock);
 
   xwindow->win = XCreateSimpleWindow (xvimagesink->xcontext->disp,
       xvimagesink->xcontext->root,
@@ -519,7 +518,7 @@ gst_xvimagesink_xwindow_new (GstXvImageSink * xvimagesink,
 
   XSync (xvimagesink->xcontext->disp, FALSE);
 
-  g_mutex_unlock (&xvimagesink->x_lock);
+  g_mutex_unlock (xvimagesink->x_lock);
 
   gst_xvimagesink_xwindow_decorate (xvimagesink, xwindow);
 
@@ -537,7 +536,7 @@ gst_xvimagesink_xwindow_destroy (GstXvImageSink * xvimagesink,
   g_return_if_fail (xwindow != NULL);
   g_return_if_fail (GST_IS_XVIMAGESINK (xvimagesink));
 
-  g_mutex_lock (&xvimagesink->x_lock);
+  g_mutex_lock (xvimagesink->x_lock);
 
   /* If we did not create that window we just free the GC and let it live */
   if (xwindow->internal)
@@ -549,7 +548,7 @@ gst_xvimagesink_xwindow_destroy (GstXvImageSink * xvimagesink,
 
   XSync (xvimagesink->xcontext->disp, FALSE);
 
-  g_mutex_unlock (&xvimagesink->x_lock);
+  g_mutex_unlock (xvimagesink->x_lock);
 
   g_free (xwindow);
 }
@@ -562,9 +561,9 @@ gst_xvimagesink_xwindow_update_geometry (GstXvImageSink * xvimagesink)
   g_return_if_fail (GST_IS_XVIMAGESINK (xvimagesink));
 
   /* Update the window geometry */
-  g_mutex_lock (&xvimagesink->x_lock);
+  g_mutex_lock (xvimagesink->x_lock);
   if (G_UNLIKELY (xvimagesink->xwindow == NULL)) {
-    g_mutex_unlock (&xvimagesink->x_lock);
+    g_mutex_unlock (xvimagesink->x_lock);
     return;
   }
 
@@ -580,7 +579,7 @@ gst_xvimagesink_xwindow_update_geometry (GstXvImageSink * xvimagesink)
     xvimagesink->render_rect.h = attr.height;
   }
 
-  g_mutex_unlock (&xvimagesink->x_lock);
+  g_mutex_unlock (xvimagesink->x_lock);
 }
 
 static void
@@ -590,14 +589,14 @@ gst_xvimagesink_xwindow_clear (GstXvImageSink * xvimagesink,
   g_return_if_fail (xwindow != NULL);
   g_return_if_fail (GST_IS_XVIMAGESINK (xvimagesink));
 
-  g_mutex_lock (&xvimagesink->x_lock);
+  g_mutex_lock (xvimagesink->x_lock);
 
   XvStopVideo (xvimagesink->xcontext->disp, xvimagesink->xcontext->xv_port_id,
       xwindow->win);
 
   XSync (xvimagesink->xcontext->disp, FALSE);
 
-  g_mutex_unlock (&xvimagesink->x_lock);
+  g_mutex_unlock (xvimagesink->x_lock);
 }
 
 /* This function commits our internal colorbalance settings to our grabbed Xv
@@ -651,7 +650,7 @@ gst_xvimagesink_update_colorbalance (GstXvImageSink * xvimagesink)
       }
 
       /* Committing to Xv port */
-      g_mutex_lock (&xvimagesink->x_lock);
+      g_mutex_lock (xvimagesink->x_lock);
       prop_atom =
           XInternAtom (xvimagesink->xcontext->disp, channel->label, True);
       if (prop_atom != None) {
@@ -661,7 +660,7 @@ gst_xvimagesink_update_colorbalance (GstXvImageSink * xvimagesink)
         XvSetPortAttribute (xvimagesink->xcontext->disp,
             xvimagesink->xcontext->xv_port_id, prop_atom, xv_value);
       }
-      g_mutex_unlock (&xvimagesink->x_lock);
+      g_mutex_unlock (xvimagesink->x_lock);
 
       g_object_unref (channel);
     }
@@ -687,12 +686,12 @@ gst_xvimagesink_handle_xevents (GstXvImageSink * xvimagesink)
 
   /* We get all pointer motion events, only the last position is
      interesting. */
-  g_mutex_lock (&xvimagesink->flow_lock);
-  g_mutex_lock (&xvimagesink->x_lock);
+  g_mutex_lock (xvimagesink->flow_lock);
+  g_mutex_lock (xvimagesink->x_lock);
   while (XCheckWindowEvent (xvimagesink->xcontext->disp,
           xvimagesink->xwindow->win, PointerMotionMask, &e)) {
-    g_mutex_unlock (&xvimagesink->x_lock);
-    g_mutex_unlock (&xvimagesink->flow_lock);
+    g_mutex_unlock (xvimagesink->x_lock);
+    g_mutex_unlock (xvimagesink->flow_lock);
 
     switch (e.type) {
       case MotionNotify:
@@ -703,21 +702,21 @@ gst_xvimagesink_handle_xevents (GstXvImageSink * xvimagesink)
       default:
         break;
     }
-    g_mutex_lock (&xvimagesink->flow_lock);
-    g_mutex_lock (&xvimagesink->x_lock);
+    g_mutex_lock (xvimagesink->flow_lock);
+    g_mutex_lock (xvimagesink->x_lock);
   }
 
   if (pointer_moved) {
-    g_mutex_unlock (&xvimagesink->x_lock);
-    g_mutex_unlock (&xvimagesink->flow_lock);
+    g_mutex_unlock (xvimagesink->x_lock);
+    g_mutex_unlock (xvimagesink->flow_lock);
 
     GST_DEBUG ("xvimagesink pointer moved over window at %d,%d",
         pointer_x, pointer_y);
     gst_navigation_send_mouse_event (GST_NAVIGATION (xvimagesink),
         "mouse-move", 0, e.xbutton.x, e.xbutton.y);
 
-    g_mutex_lock (&xvimagesink->flow_lock);
-    g_mutex_lock (&xvimagesink->x_lock);
+    g_mutex_lock (xvimagesink->flow_lock);
+    g_mutex_lock (xvimagesink->x_lock);
   }
 
   /* We get all events on our window to throw them upstream */
@@ -729,8 +728,8 @@ gst_xvimagesink_handle_xevents (GstXvImageSink * xvimagesink)
     const char *key_str = NULL;
 
     /* We lock only for the X function call */
-    g_mutex_unlock (&xvimagesink->x_lock);
-    g_mutex_unlock (&xvimagesink->flow_lock);
+    g_mutex_unlock (xvimagesink->x_lock);
+    g_mutex_unlock (xvimagesink->flow_lock);
 
     switch (e.type) {
       case ButtonPress:
@@ -753,7 +752,7 @@ gst_xvimagesink_handle_xevents (GstXvImageSink * xvimagesink)
       case KeyRelease:
         /* Key pressed/released over our window. We send upstream
            events for interactivity/navigation */
-        g_mutex_lock (&xvimagesink->x_lock);
+        g_mutex_lock (xvimagesink->x_lock);
         keysym = XkbKeycodeToKeysym (xvimagesink->xcontext->disp,
             e.xkey.keycode, 0, 0);
         if (keysym != NoSymbol) {
@@ -761,7 +760,7 @@ gst_xvimagesink_handle_xevents (GstXvImageSink * xvimagesink)
         } else {
           key_str = "unknown";
         }
-        g_mutex_unlock (&xvimagesink->x_lock);
+        g_mutex_unlock (xvimagesink->x_lock);
         GST_DEBUG_OBJECT (xvimagesink,
             "key %d pressed over window at %d,%d (%s)",
             e.xkey.keycode, e.xkey.x, e.xkey.y, key_str);
@@ -772,8 +771,8 @@ gst_xvimagesink_handle_xevents (GstXvImageSink * xvimagesink)
         GST_DEBUG_OBJECT (xvimagesink, "xvimagesink unhandled X event (%d)",
             e.type);
     }
-    g_mutex_lock (&xvimagesink->flow_lock);
-    g_mutex_lock (&xvimagesink->x_lock);
+    g_mutex_lock (xvimagesink->flow_lock);
+    g_mutex_lock (xvimagesink->x_lock);
   }
 
   /* Handle Expose */
@@ -784,9 +783,9 @@ gst_xvimagesink_handle_xevents (GstXvImageSink * xvimagesink)
         exposed = TRUE;
         break;
       case ConfigureNotify:
-        g_mutex_unlock (&xvimagesink->x_lock);
+        g_mutex_unlock (xvimagesink->x_lock);
         gst_xvimagesink_xwindow_update_geometry (xvimagesink);
-        g_mutex_lock (&xvimagesink->x_lock);
+        g_mutex_lock (xvimagesink->x_lock);
         configured = TRUE;
         break;
       default:
@@ -795,13 +794,13 @@ gst_xvimagesink_handle_xevents (GstXvImageSink * xvimagesink)
   }
 
   if (xvimagesink->handle_expose && (exposed || configured)) {
-    g_mutex_unlock (&xvimagesink->x_lock);
-    g_mutex_unlock (&xvimagesink->flow_lock);
+    g_mutex_unlock (xvimagesink->x_lock);
+    g_mutex_unlock (xvimagesink->flow_lock);
 
     gst_xvimagesink_expose (GST_VIDEO_OVERLAY (xvimagesink));
 
-    g_mutex_lock (&xvimagesink->flow_lock);
-    g_mutex_lock (&xvimagesink->x_lock);
+    g_mutex_lock (xvimagesink->flow_lock);
+    g_mutex_lock (xvimagesink->x_lock);
   }
 
   /* Handle Display events */
@@ -819,10 +818,10 @@ gst_xvimagesink_handle_xevents (GstXvImageSink * xvimagesink)
           GST_ELEMENT_ERROR (xvimagesink, RESOURCE, NOT_FOUND,
               ("Output window was closed"), (NULL));
 
-          g_mutex_unlock (&xvimagesink->x_lock);
+          g_mutex_unlock (xvimagesink->x_lock);
           gst_xvimagesink_xwindow_destroy (xvimagesink, xvimagesink->xwindow);
           xvimagesink->xwindow = NULL;
-          g_mutex_lock (&xvimagesink->x_lock);
+          g_mutex_lock (xvimagesink->x_lock);
         }
         break;
       }
@@ -831,8 +830,8 @@ gst_xvimagesink_handle_xevents (GstXvImageSink * xvimagesink)
     }
   }
 
-  g_mutex_unlock (&xvimagesink->x_lock);
-  g_mutex_unlock (&xvimagesink->flow_lock);
+  g_mutex_unlock (xvimagesink->x_lock);
+  g_mutex_unlock (xvimagesink->flow_lock);
 }
 
 static void
@@ -1279,12 +1278,12 @@ gst_xvimagesink_xcontext_get (GstXvImageSink * xvimagesink)
   xcontext = g_new0 (GstXContext, 1);
   xcontext->im_format = 0;
 
-  g_mutex_lock (&xvimagesink->x_lock);
+  g_mutex_lock (xvimagesink->x_lock);
 
   xcontext->disp = XOpenDisplay (xvimagesink->display_name);
 
   if (!xcontext->disp) {
-    g_mutex_unlock (&xvimagesink->x_lock);
+    g_mutex_unlock (xvimagesink->x_lock);
     g_free (xcontext);
     GST_ELEMENT_ERROR (xvimagesink, RESOURCE, WRITE,
         ("Could not initialise Xv output"), ("Could not open display"));
@@ -1313,7 +1312,7 @@ gst_xvimagesink_xcontext_get (GstXvImageSink * xvimagesink)
 
   if (!px_formats) {
     XCloseDisplay (xcontext->disp);
-    g_mutex_unlock (&xvimagesink->x_lock);
+    g_mutex_unlock (xvimagesink->x_lock);
     g_free (xcontext->par);
     g_free (xcontext);
     GST_ELEMENT_ERROR (xvimagesink, RESOURCE, SETTINGS,
@@ -1364,7 +1363,7 @@ gst_xvimagesink_xcontext_get (GstXvImageSink * xvimagesink)
 
   if (!xcontext->caps) {
     XCloseDisplay (xcontext->disp);
-    g_mutex_unlock (&xvimagesink->x_lock);
+    g_mutex_unlock (xvimagesink->x_lock);
     g_free (xcontext->par);
     g_free (xcontext);
     /* GST_ELEMENT_ERROR is thrown by gst_xvimagesink_get_xv_support */
@@ -1428,7 +1427,7 @@ gst_xvimagesink_xcontext_get (GstXvImageSink * xvimagesink)
   if (xv_attr)
     XFree (xv_attr);
 
-  g_mutex_unlock (&xvimagesink->x_lock);
+  g_mutex_unlock (xvimagesink->x_lock);
 
   return xcontext;
 }
@@ -1494,7 +1493,7 @@ gst_xvimagesink_xcontext_clear (GstXvImageSink * xvimagesink)
 
   g_free (xcontext->par);
 
-  g_mutex_lock (&xvimagesink->x_lock);
+  g_mutex_lock (xvimagesink->x_lock);
 
   GST_DEBUG_OBJECT (xvimagesink, "Closing display and freeing X Context");
 
@@ -1502,7 +1501,7 @@ gst_xvimagesink_xcontext_clear (GstXvImageSink * xvimagesink)
 
   XCloseDisplay (xcontext->disp);
 
-  g_mutex_unlock (&xvimagesink->x_lock);
+  g_mutex_unlock (xvimagesink->x_lock);
 
   g_free (xcontext);
 }
@@ -1549,7 +1548,7 @@ gst_xvimagesink_setcaps (GstBaseSink * bsink, GstCaps * caps)
   gint display_par_n, display_par_d;    /* display's PAR */
   guint num, den;
   gint size;
-  static GstAllocationParams params = { 0, 15, 0, 0, };
+  static GstAllocationParams params = { 0, 0, 0, 15, };
 
   xvimagesink = GST_XVIMAGESINK (bsink);
 
@@ -1563,6 +1562,8 @@ gst_xvimagesink_setcaps (GstBaseSink * bsink, GstCaps * caps)
   if (!gst_video_info_from_caps (&info, caps))
     goto invalid_format;
 
+  structure = gst_caps_get_structure (caps, 0);
+
   xvimagesink->fps_n = info.fps_n;
   xvimagesink->fps_d = info.fps_d;
 
@@ -1626,12 +1627,12 @@ gst_xvimagesink_setcaps (GstBaseSink * bsink, GstCaps * caps)
       GST_VIDEO_SINK_WIDTH (xvimagesink), GST_VIDEO_SINK_HEIGHT (xvimagesink));
 
   /* Notify application to set xwindow id now */
-  g_mutex_lock (&xvimagesink->flow_lock);
+  g_mutex_lock (xvimagesink->flow_lock);
   if (!xvimagesink->xwindow) {
-    g_mutex_unlock (&xvimagesink->flow_lock);
+    g_mutex_unlock (xvimagesink->flow_lock);
     gst_video_overlay_prepare_window_handle (GST_VIDEO_OVERLAY (xvimagesink));
   } else {
-    g_mutex_unlock (&xvimagesink->flow_lock);
+    g_mutex_unlock (xvimagesink->flow_lock);
   }
 
   /* Creating our window and our image with the display size in pixels */
@@ -1639,7 +1640,7 @@ gst_xvimagesink_setcaps (GstBaseSink * bsink, GstCaps * caps)
       GST_VIDEO_SINK_HEIGHT (xvimagesink) <= 0)
     goto no_display_size;
 
-  g_mutex_lock (&xvimagesink->flow_lock);
+  g_mutex_lock (xvimagesink->flow_lock);
   if (!xvimagesink->xwindow) {
     xvimagesink->xwindow = gst_xvimagesink_xwindow_new (xvimagesink,
         GST_VIDEO_SINK_WIDTH (xvimagesink),
@@ -1666,7 +1667,7 @@ gst_xvimagesink_setcaps (GstBaseSink * bsink, GstCaps * caps)
    * has configured the pool. If downstream does not want our pool we will
    * activate it when we render into it */
   xvimagesink->pool = newpool;
-  g_mutex_unlock (&xvimagesink->flow_lock);
+  g_mutex_unlock (xvimagesink->flow_lock);
 
   /* unref the old sink */
   if (oldpool) {
@@ -1704,7 +1705,7 @@ no_display_size:
 config_failed:
   {
     GST_ERROR_OBJECT (xvimagesink, "failed to set config.");
-    g_mutex_unlock (&xvimagesink->flow_lock);
+    g_mutex_unlock (xvimagesink->flow_lock);
     return FALSE;
   }
 }
@@ -1766,10 +1767,10 @@ gst_xvimagesink_change_state (GstElement * element, GstStateChange transition)
       xvimagesink->fps_d = 1;
       GST_VIDEO_SINK_WIDTH (xvimagesink) = 0;
       GST_VIDEO_SINK_HEIGHT (xvimagesink) = 0;
-      g_mutex_lock (&xvimagesink->flow_lock);
+      g_mutex_lock (xvimagesink->flow_lock);
       if (xvimagesink->pool)
         gst_buffer_pool_set_active (xvimagesink->pool, FALSE);
-      g_mutex_unlock (&xvimagesink->flow_lock);
+      g_mutex_unlock (xvimagesink->flow_lock);
       break;
     case GST_STATE_CHANGE_READY_TO_NULL:
       gst_xvimagesink_reset (xvimagesink);
@@ -1825,7 +1826,6 @@ gst_xvimagesink_show_frame (GstVideoSink * vsink, GstBuffer * buf)
     res = GST_FLOW_OK;
   } else {
     GstVideoFrame src, dest;
-    GstBufferPoolAcquireParams params = { 0, };
 
     /* Else we have to copy the data into our private image, */
     /* if we have one... */
@@ -1838,11 +1838,8 @@ gst_xvimagesink_show_frame (GstVideoSink * vsink, GstBuffer * buf)
     if (!gst_buffer_pool_set_active (xvimagesink->pool, TRUE))
       goto activate_failed;
 
-    /* take a buffer from our pool, if there is no buffer in the pool something
-     * is seriously wrong, waiting for the pool here might deadlock when we try
-     * to go to PAUSED because we never flush the pool then. */
-    params.flags = GST_BUFFER_POOL_ACQUIRE_FLAG_DONTWAIT;
-    res = gst_buffer_pool_acquire_buffer (xvimagesink->pool, &to_put, &params);
+    /* take a buffer from our pool */
+    res = gst_buffer_pool_acquire_buffer (xvimagesink->pool, &to_put, NULL);
     if (res != GST_FLOW_OK)
       goto no_buffer;
 
@@ -1884,12 +1881,12 @@ no_buffer:
   {
     /* No image available. That's very bad ! */
     GST_WARNING_OBJECT (xvimagesink, "could not create image");
-    return GST_FLOW_OK;
+    return res;
   }
 invalid_buffer:
   {
     /* No Window available to put our image into */
-    GST_WARNING_OBJECT (xvimagesink, "could not map image");
+    GST_WARNING_OBJECT (xvimagesink, "could map image");
     res = GST_FLOW_OK;
     goto done;
   }
@@ -1951,10 +1948,10 @@ gst_xvimagesink_propose_allocation (GstBaseSink * bsink, GstQuery * query)
   if (caps == NULL)
     goto no_caps;
 
-  g_mutex_lock (&xvimagesink->flow_lock);
+  g_mutex_lock (xvimagesink->flow_lock);
   if ((pool = xvimagesink->pool))
     gst_object_ref (pool);
-  g_mutex_unlock (&xvimagesink->flow_lock);
+  g_mutex_unlock (xvimagesink->flow_lock);
 
   if (pool != NULL) {
     GstCaps *pcaps;
@@ -1975,12 +1972,12 @@ gst_xvimagesink_propose_allocation (GstBaseSink * bsink, GstQuery * query)
   if (pool == NULL && need_pool) {
     GstVideoInfo info;
 
-    if (!gst_video_info_from_caps (&info, caps))
-      goto invalid_caps;
-
     GST_DEBUG_OBJECT (xvimagesink, "create new pool");
     pool = gst_xvimage_buffer_pool_new (xvimagesink);
 
+    if (!gst_video_info_from_caps (&info, caps))
+      goto invalid_caps;
+
     /* the normal size of a frame */
     size = info.size;
 
@@ -1989,15 +1986,14 @@ gst_xvimagesink_propose_allocation (GstBaseSink * bsink, GstQuery * query)
     if (!gst_buffer_pool_set_config (pool, config))
       goto config_failed;
   }
-  if (pool) {
-    /* we need at least 2 buffer because we hold on to the last one */
-    gst_query_add_allocation_pool (query, pool, size, 2, 0);
-    gst_object_unref (pool);
-  }
+  /* we need at least 2 buffer because we hold on to the last one */
+  gst_query_add_allocation_pool (query, pool, size, 2, 0);
 
   /* we also support various metadata */
-  gst_query_add_allocation_meta (query, GST_VIDEO_META_API_TYPE, NULL);
-  gst_query_add_allocation_meta (query, GST_VIDEO_CROP_META_API_TYPE, NULL);
+  gst_query_add_allocation_meta (query, GST_VIDEO_META_API_TYPE);
+  gst_query_add_allocation_meta (query, GST_VIDEO_CROP_META_API_TYPE);
+
+  gst_object_unref (pool);
 
   return TRUE;
 
@@ -2015,7 +2011,6 @@ invalid_caps:
 config_failed:
   {
     GST_DEBUG_OBJECT (bsink, "failed setting config");
-    gst_object_unref (pool);
     return FALSE;
   }
 }
@@ -2036,10 +2031,10 @@ gst_xvimagesink_navigation_send_event (GstNavigation * navigation,
     event = gst_event_new_navigation (structure);
 
     /* We take the flow_lock while we look at the window */
-    g_mutex_lock (&xvimagesink->flow_lock);
+    g_mutex_lock (xvimagesink->flow_lock);
 
     if (!xvimagesink->xwindow) {
-      g_mutex_unlock (&xvimagesink->flow_lock);
+      g_mutex_unlock (xvimagesink->flow_lock);
       return;
     }
 
@@ -2058,7 +2053,7 @@ gst_xvimagesink_navigation_send_event (GstNavigation * navigation,
       memcpy (&result, &xvimagesink->render_rect, sizeof (GstVideoRectangle));
     }
 
-    g_mutex_unlock (&xvimagesink->flow_lock);
+    g_mutex_unlock (xvimagesink->flow_lock);
 
     /* We calculate scaling using the original video frames geometry to include
        pixel aspect ratio scaling. */
@@ -2099,18 +2094,18 @@ gst_xvimagesink_set_window_handle (GstVideoOverlay * overlay, guintptr id)
 
   g_return_if_fail (GST_IS_XVIMAGESINK (xvimagesink));
 
-  g_mutex_lock (&xvimagesink->flow_lock);
+  g_mutex_lock (xvimagesink->flow_lock);
 
   /* If we already use that window return */
   if (xvimagesink->xwindow && (xwindow_id == xvimagesink->xwindow->win)) {
-    g_mutex_unlock (&xvimagesink->flow_lock);
+    g_mutex_unlock (xvimagesink->flow_lock);
     return;
   }
 
   /* If the element has not initialized the X11 context try to do so */
   if (!xvimagesink->xcontext &&
       !(xvimagesink->xcontext = gst_xvimagesink_xcontext_get (xvimagesink))) {
-    g_mutex_unlock (&xvimagesink->flow_lock);
+    g_mutex_unlock (xvimagesink->flow_lock);
     /* we have thrown a GST_ELEMENT_ERROR now */
     return;
   }
@@ -2141,7 +2136,7 @@ gst_xvimagesink_set_window_handle (GstVideoOverlay * overlay, guintptr id)
     xwindow->win = xwindow_id;
 
     /* Set the event we want to receive and create a GC */
-    g_mutex_lock (&xvimagesink->x_lock);
+    g_mutex_lock (xvimagesink->x_lock);
 
     XGetWindowAttributes (xvimagesink->xcontext->disp, xwindow->win, &attr);
 
@@ -2161,13 +2156,13 @@ gst_xvimagesink_set_window_handle (GstVideoOverlay * overlay, guintptr id)
 
     xwindow->gc = XCreateGC (xvimagesink->xcontext->disp,
         xwindow->win, 0, NULL);
-    g_mutex_unlock (&xvimagesink->x_lock);
+    g_mutex_unlock (xvimagesink->x_lock);
   }
 
   if (xwindow)
     xvimagesink->xwindow = xwindow;
 
-  g_mutex_unlock (&xvimagesink->flow_lock);
+  g_mutex_unlock (xvimagesink->flow_lock);
 }
 
 static void
@@ -2188,14 +2183,14 @@ gst_xvimagesink_set_event_handling (GstVideoOverlay * overlay,
 
   xvimagesink->handle_events = handle_events;
 
-  g_mutex_lock (&xvimagesink->flow_lock);
+  g_mutex_lock (xvimagesink->flow_lock);
 
   if (G_UNLIKELY (!xvimagesink->xwindow)) {
-    g_mutex_unlock (&xvimagesink->flow_lock);
+    g_mutex_unlock (xvimagesink->flow_lock);
     return;
   }
 
-  g_mutex_lock (&xvimagesink->x_lock);
+  g_mutex_lock (xvimagesink->x_lock);
 
   if (handle_events) {
     if (xvimagesink->xwindow->internal) {
@@ -2211,9 +2206,9 @@ gst_xvimagesink_set_event_handling (GstVideoOverlay * overlay,
     XSelectInput (xvimagesink->xcontext->disp, xvimagesink->xwindow->win, 0);
   }
 
-  g_mutex_unlock (&xvimagesink->x_lock);
+  g_mutex_unlock (xvimagesink->x_lock);
 
-  g_mutex_unlock (&xvimagesink->flow_lock);
+  g_mutex_unlock (xvimagesink->flow_lock);
 }
 
 static void
@@ -2698,7 +2693,7 @@ gst_xvimagesink_reset (GstXvImageSink * xvimagesink)
     xvimagesink->cur_image = NULL;
   }
 
-  g_mutex_lock (&xvimagesink->flow_lock);
+  g_mutex_lock (xvimagesink->flow_lock);
 
   if (xvimagesink->pool) {
     gst_object_unref (xvimagesink->pool);
@@ -2710,7 +2705,7 @@ gst_xvimagesink_reset (GstXvImageSink * xvimagesink)
     gst_xvimagesink_xwindow_destroy (xvimagesink, xvimagesink->xwindow);
     xvimagesink->xwindow = NULL;
   }
-  g_mutex_unlock (&xvimagesink->flow_lock);
+  g_mutex_unlock (xvimagesink->flow_lock);
 
   xvimagesink->render_rect.x = xvimagesink->render_rect.y =
       xvimagesink->render_rect.w = xvimagesink->render_rect.h = 0;
@@ -2740,8 +2735,15 @@ gst_xvimagesink_finalize (GObject * object)
     g_free (xvimagesink->par);
     xvimagesink->par = NULL;
   }
-  g_mutex_clear (&xvimagesink->x_lock);
-  g_mutex_clear (&xvimagesink->flow_lock);
+  if (xvimagesink->x_lock) {
+    g_mutex_free (xvimagesink->x_lock);
+    xvimagesink->x_lock = NULL;
+  }
+  if (xvimagesink->flow_lock) {
+    g_mutex_free (xvimagesink->flow_lock);
+    xvimagesink->flow_lock = NULL;
+  }
+
   g_free (xvimagesink->media_title);
 
   G_OBJECT_CLASS (parent_class)->finalize (object);
@@ -2765,15 +2767,15 @@ gst_xvimagesink_init (GstXvImageSink * xvimagesink)
   xvimagesink->video_width = 0;
   xvimagesink->video_height = 0;
 
-  g_mutex_init (&xvimagesink->x_lock);
-  g_mutex_init (&xvimagesink->flow_lock);
+  xvimagesink->x_lock = g_mutex_new ();
+  xvimagesink->flow_lock = g_mutex_new ();
 
   xvimagesink->pool = NULL;
 
   xvimagesink->synchronous = FALSE;
   xvimagesink->double_buffer = TRUE;
   xvimagesink->running = FALSE;
-  xvimagesink->keep_aspect = TRUE;
+  xvimagesink->keep_aspect = FALSE;
   xvimagesink->handle_events = TRUE;
   xvimagesink->par = NULL;
   xvimagesink->handle_expose = TRUE;
@@ -2833,7 +2835,7 @@ gst_xvimagesink_class_init (GstXvImageSinkClass * klass)
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   g_object_class_install_property (gobject_class, PROP_FORCE_ASPECT_RATIO,
       g_param_spec_boolean ("force-aspect-ratio", "Force aspect ratio",
-          "When enabled, scaling will respect original aspect ratio", TRUE,
+          "When enabled, scaling will respect original aspect ratio", FALSE,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   g_object_class_install_property (gobject_class, PROP_HANDLE_EVENTS,
       g_param_spec_boolean ("handle-events", "Handle XEvents",
