@@ -32,50 +32,9 @@
 
 #include <gst/check/gstcheck.h>
 #include <gst/check/gstconsistencychecker.h>
-#include <gst/base/gstbasesrc.h>
 
 static GMainLoop *main_loop;
 
-/* make sure downstream gets a CAPS event before buffers are sent */
-GST_START_TEST (test_caps)
-{
-  GstElement *pipeline, *src, *adder, *sink;
-  GstStateChangeReturn state_res;
-  GstCaps *caps;
-  GstPad *pad;
-
-  /* build pipeline */
-  pipeline = gst_pipeline_new ("pipeline");
-
-  src = gst_element_factory_make ("audiotestsrc", "src1");
-  g_object_set (src, "wave", 4, NULL);  /* silence */
-  adder = gst_element_factory_make ("adder", "adder");
-  sink = gst_element_factory_make ("fakesink", "sink");
-  gst_bin_add_many (GST_BIN (pipeline), src, adder, sink, NULL);
-
-  fail_unless (gst_element_link_many (src, adder, sink, NULL));
-
-  /* prepare playing */
-  state_res = gst_element_set_state (pipeline, GST_STATE_PAUSED);
-  fail_unless_equals_int (state_res, GST_STATE_CHANGE_ASYNC);
-
-  /* wait for preroll */
-  state_res = gst_element_get_state (pipeline, NULL, NULL, GST_CLOCK_TIME_NONE);
-  fail_unless_equals_int (state_res, GST_STATE_CHANGE_SUCCESS);
-
-  /* check caps on fakesink */
-  pad = gst_element_get_static_pad (sink, "sink");
-  caps = gst_pad_get_current_caps (pad);
-  fail_unless (caps != NULL);
-  gst_caps_unref (caps);
-  gst_object_unref (pad);
-
-  gst_element_set_state (pipeline, GST_STATE_NULL);
-  gst_object_unref (pipeline);
-}
-
-GST_END_TEST;
-
 static void
 message_received (GstBus * bus, GstMessage * message, GstPipeline * bin)
 {
@@ -141,7 +100,6 @@ GST_START_TEST (test_event)
   GstElement *bin, *src1, *src2, *adder, *sink;
   GstBus *bus;
   GstEvent *seek_event;
-  GstStateChangeReturn state_res;
   gboolean res;
   GstPad *srcpad, *sinkpad;
   GstStreamConsistency *chk_1, *chk_2, *chk_3;
@@ -205,35 +163,34 @@ GST_START_TEST (test_event)
   GST_INFO ("starting test");
 
   /* prepare playing */
-  state_res = gst_element_set_state (bin, GST_STATE_PAUSED);
-  ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+  res = gst_element_set_state (bin, GST_STATE_PAUSED);
+  fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
   /* wait for completion */
-  state_res = gst_element_get_state (bin, NULL, NULL, GST_CLOCK_TIME_NONE);
-  ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+  res = gst_element_get_state (bin, NULL, NULL, GST_CLOCK_TIME_NONE);
+  fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
   res = gst_element_send_event (bin, seek_event);
   fail_unless (res == TRUE, NULL);
 
   /* run pipeline */
-  state_res = gst_element_set_state (bin, GST_STATE_PLAYING);
-  ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+  res = gst_element_set_state (bin, GST_STATE_PLAYING);
+  fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
-  GST_INFO ("running main loop");
   g_main_loop_run (main_loop);
 
-  state_res = gst_element_set_state (bin, GST_STATE_NULL);
-  ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+  res = gst_element_set_state (bin, GST_STATE_NULL);
+  fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
-  ck_assert_int_eq (position, 2 * GST_SECOND);
+  fail_unless (position == 2 * GST_SECOND, NULL);
 
   /* cleanup */
   g_main_loop_unref (main_loop);
   gst_consistency_checker_free (chk_1);
   gst_consistency_checker_free (chk_2);
   gst_consistency_checker_free (chk_3);
-  gst_object_unref (bus);
-  gst_object_unref (bin);
+  gst_object_unref (G_OBJECT (bus));
+  gst_object_unref (G_OBJECT (bin));
 }
 
 GST_END_TEST;
@@ -246,7 +203,6 @@ test_play_twice_message_received (GstBus * bus, GstMessage * message,
     GstPipeline * bin)
 {
   gboolean res;
-  GstStateChangeReturn state_res;
 
   GST_INFO ("bus message from \"%" GST_PTR_FORMAT "\": %" GST_PTR_FORMAT,
       GST_MESSAGE_SRC (message), message);
@@ -255,26 +211,25 @@ test_play_twice_message_received (GstBus * bus, GstMessage * message,
     case GST_MESSAGE_SEGMENT_DONE:
       play_count++;
       if (play_count == 1) {
-        state_res = gst_element_set_state (GST_ELEMENT (bin), GST_STATE_READY);
-        ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+        res = gst_element_set_state (GST_ELEMENT (bin), GST_STATE_READY);
+        fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
         /* prepare playing again */
-        state_res = gst_element_set_state (GST_ELEMENT (bin), GST_STATE_PAUSED);
-        ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+        res = gst_element_set_state (GST_ELEMENT (bin), GST_STATE_PAUSED);
+        fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
         /* wait for completion */
-        state_res =
+        res =
             gst_element_get_state (GST_ELEMENT (bin), NULL, NULL,
             GST_CLOCK_TIME_NONE);
-        ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+        fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
         res = gst_element_send_event (GST_ELEMENT (bin),
             gst_event_ref (play_seek_event));
         fail_unless (res == TRUE, NULL);
 
-        state_res =
-            gst_element_set_state (GST_ELEMENT (bin), GST_STATE_PLAYING);
-        ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+        res = gst_element_set_state (GST_ELEMENT (bin), GST_STATE_PLAYING);
+        fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
       } else {
         g_main_loop_quit (main_loop);
       }
@@ -291,7 +246,6 @@ GST_START_TEST (test_play_twice)
   GstElement *bin, *src1, *src2, *adder, *sink;
   GstBus *bus;
   gboolean res;
-  GstStateChangeReturn state_res;
   GstPad *srcpad;
   GstStreamConsistency *consist;
 
@@ -338,14 +292,14 @@ GST_START_TEST (test_play_twice)
   GST_INFO ("starting test");
 
   /* prepare playing */
-  state_res = gst_element_set_state (bin, GST_STATE_PAUSED);
-  ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+  res = gst_element_set_state (bin, GST_STATE_PAUSED);
+  fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
   /* wait for completion */
-  state_res =
+  res =
       gst_element_get_state (GST_ELEMENT (bin), NULL, NULL,
       GST_CLOCK_TIME_NONE);
-  ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+  fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
   res = gst_element_send_event (bin, gst_event_ref (play_seek_event));
   fail_unless (res == TRUE, NULL);
@@ -353,22 +307,22 @@ GST_START_TEST (test_play_twice)
   GST_INFO ("seeked");
 
   /* run pipeline */
-  state_res = gst_element_set_state (bin, GST_STATE_PLAYING);
-  ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+  res = gst_element_set_state (bin, GST_STATE_PLAYING);
+  fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
   g_main_loop_run (main_loop);
 
-  state_res = gst_element_set_state (bin, GST_STATE_NULL);
-  ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+  res = gst_element_set_state (bin, GST_STATE_NULL);
+  fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
-  ck_assert_int_eq (play_count, 2);
+  fail_unless (play_count == 2, NULL);
 
   /* cleanup */
   g_main_loop_unref (main_loop);
   gst_consistency_checker_free (consist);
   gst_event_ref (play_seek_event);
-  gst_object_unref (bus);
-  gst_object_unref (bin);
+  gst_object_unref (G_OBJECT (bus));
+  gst_object_unref (G_OBJECT (bin));
 }
 
 GST_END_TEST;
@@ -378,7 +332,6 @@ GST_START_TEST (test_play_twice_then_add_and_play_again)
   GstElement *bin, *src1, *src2, *src3, *adder, *sink;
   GstBus *bus;
   gboolean res;
-  GstStateChangeReturn state_res;
   gint i;
   GstPad *srcpad;
   GstStreamConsistency *consist;
@@ -428,14 +381,14 @@ GST_START_TEST (test_play_twice_then_add_and_play_again)
     GST_INFO ("starting test-loop %d", i);
 
     /* prepare playing */
-    state_res = gst_element_set_state (bin, GST_STATE_PAUSED);
-    ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+    res = gst_element_set_state (bin, GST_STATE_PAUSED);
+    fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
     /* wait for completion */
-    state_res =
+    res =
         gst_element_get_state (GST_ELEMENT (bin), NULL, NULL,
         GST_CLOCK_TIME_NONE);
-    ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+    fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
     res = gst_element_send_event (bin, gst_event_ref (play_seek_event));
     fail_unless (res == TRUE, NULL);
@@ -443,15 +396,15 @@ GST_START_TEST (test_play_twice_then_add_and_play_again)
     GST_INFO ("seeked");
 
     /* run pipeline */
-    state_res = gst_element_set_state (bin, GST_STATE_PLAYING);
-    ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+    res = gst_element_set_state (bin, GST_STATE_PLAYING);
+    fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
     g_main_loop_run (main_loop);
 
-    state_res = gst_element_set_state (bin, GST_STATE_READY);
-    ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+    res = gst_element_set_state (bin, GST_STATE_READY);
+    fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
-    ck_assert_int_eq (play_count, 2);
+    fail_unless (play_count == 2, NULL);
 
     /* plug another source */
     if (i == 0) {
@@ -466,15 +419,15 @@ GST_START_TEST (test_play_twice_then_add_and_play_again)
     gst_consistency_checker_reset (consist);
   }
 
-  state_res = gst_element_set_state (bin, GST_STATE_NULL);
-  ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+  res = gst_element_set_state (bin, GST_STATE_NULL);
+  fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
   /* cleanup */
   g_main_loop_unref (main_loop);
   gst_event_ref (play_seek_event);
   gst_consistency_checker_free (consist);
-  gst_object_unref (bus);
-  gst_object_unref (bin);
+  gst_object_unref (G_OBJECT (bus));
+  gst_object_unref (G_OBJECT (bin));
 }
 
 GST_END_TEST;
@@ -504,7 +457,6 @@ GST_START_TEST (test_live_seeking)
   GstElement *bin, *src1, *src2, *ac1, *ac2, *adder, *sink;
   GstBus *bus;
   gboolean res;
-  GstStateChangeReturn state_res;
   GstPad *srcpad;
   gint i;
   GstStreamConsistency *consist;
@@ -529,11 +481,11 @@ GST_START_TEST (test_live_seeking)
     goto cleanup;
   }
   /* Test that the audio source can get to paused, else skip */
-  state_res = gst_element_set_state (src1, GST_STATE_PAUSED);
+  res = gst_element_set_state (src1, GST_STATE_PAUSED);
   (void) gst_element_set_state (src1, GST_STATE_NULL);
   gst_object_unref (src1);
 
-  if (state_res == GST_STATE_CHANGE_FAILURE)
+  if (res == GST_STATE_CHANGE_FAILURE)
     goto cleanup;
   src1 = gst_element_factory_make ("alsasrc", "src1");
 
@@ -583,14 +535,14 @@ GST_START_TEST (test_live_seeking)
     GST_INFO ("starting test-loop %d", i);
 
     /* prepare playing */
-    state_res = gst_element_set_state (bin, GST_STATE_PAUSED);
-    ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+    res = gst_element_set_state (bin, GST_STATE_PAUSED);
+    fail_unless (res != GST_STATE_CHANGE_FAILURE);
 
     /* wait for completion */
-    state_res =
+    res =
         gst_element_get_state (GST_ELEMENT (bin), NULL, NULL,
         GST_CLOCK_TIME_NONE);
-    ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+    fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
     res = gst_element_send_event (bin, gst_event_ref (play_seek_event));
 #if 1
@@ -603,15 +555,15 @@ GST_START_TEST (test_live_seeking)
     GST_INFO ("seeked");
 
     /* run pipeline */
-    state_res = gst_element_set_state (bin, GST_STATE_PLAYING);
-    ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+    res = gst_element_set_state (bin, GST_STATE_PLAYING);
+    fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
     GST_INFO ("playing");
 
     g_main_loop_run (main_loop);
 
-    state_res = gst_element_set_state (bin, GST_STATE_NULL);
-    ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+    res = gst_element_set_state (bin, GST_STATE_NULL);
+    fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
     gst_consistency_checker_reset (consist);
   }
@@ -623,8 +575,8 @@ cleanup:
     g_main_loop_unref (main_loop);
   if (play_seek_event)
     gst_event_unref (play_seek_event);
-  gst_object_unref (bus);
-  gst_object_unref (bin);
+  gst_object_unref (G_OBJECT (bus));
+  gst_object_unref (G_OBJECT (bin));
 }
 
 GST_END_TEST;
@@ -636,7 +588,6 @@ GST_START_TEST (test_add_pad)
   GstBus *bus;
   GstPad *srcpad;
   gboolean res;
-  GstStateChangeReturn state_res;
 
   GST_INFO ("preparing test");
 
@@ -674,14 +625,14 @@ GST_START_TEST (test_add_pad)
   GST_INFO ("starting test");
 
   /* prepare playing */
-  state_res = gst_element_set_state (bin, GST_STATE_PAUSED);
-  ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+  res = gst_element_set_state (bin, GST_STATE_PAUSED);
+  fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
   /* wait for completion */
-  state_res =
+  res =
       gst_element_get_state (GST_ELEMENT (bin), NULL, NULL,
       GST_CLOCK_TIME_NONE);
-  ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+  fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
   /* add other element */
   gst_bin_add_many (GST_BIN (bin), src2, NULL);
@@ -691,22 +642,21 @@ GST_START_TEST (test_add_pad)
   fail_unless (res == TRUE, NULL);
 
   /* set to PAUSED as well */
-  state_res = gst_element_set_state (src2, GST_STATE_PAUSED);
-  ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+  res = gst_element_set_state (src2, GST_STATE_PAUSED);
 
   /* now play all */
-  state_res = gst_element_set_state (bin, GST_STATE_PLAYING);
-  ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+  res = gst_element_set_state (bin, GST_STATE_PLAYING);
+  fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
   g_main_loop_run (main_loop);
 
-  state_res = gst_element_set_state (bin, GST_STATE_NULL);
-  ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+  res = gst_element_set_state (bin, GST_STATE_NULL);
+  fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
   /* cleanup */
   g_main_loop_unref (main_loop);
-  gst_object_unref (bus);
-  gst_object_unref (bin);
+  gst_object_unref (G_OBJECT (bus));
+  gst_object_unref (G_OBJECT (bin));
 }
 
 GST_END_TEST;
@@ -718,7 +668,6 @@ GST_START_TEST (test_remove_pad)
   GstBus *bus;
   GstPad *pad, *srcpad;
   gboolean res;
-  GstStateChangeReturn state_res;
 
   GST_INFO ("preparing test");
 
@@ -757,12 +706,12 @@ GST_START_TEST (test_remove_pad)
 
   /* prepare playing, this will not preroll as adder is waiting
    * on the unconnected sinkpad. */
-  state_res = gst_element_set_state (bin, GST_STATE_PAUSED);
-  ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+  res = gst_element_set_state (bin, GST_STATE_PAUSED);
+  fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
   /* wait for completion for one second, will return ASYNC */
-  state_res = gst_element_get_state (GST_ELEMENT (bin), NULL, NULL, GST_SECOND);
-  ck_assert_int_eq (state_res, GST_STATE_CHANGE_ASYNC);
+  res = gst_element_get_state (GST_ELEMENT (bin), NULL, NULL, GST_SECOND);
+  fail_unless (res == GST_STATE_CHANGE_ASYNC, NULL);
 
   /* get rid of the pad now, adder should stop waiting on it and
    * continue the preroll */
@@ -770,19 +719,19 @@ GST_START_TEST (test_remove_pad)
   gst_object_unref (pad);
 
   /* wait for completion, should work now */
-  state_res =
+  res =
       gst_element_get_state (GST_ELEMENT (bin), NULL, NULL,
       GST_CLOCK_TIME_NONE);
-  ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+  fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
   /* now play all */
-  state_res = gst_element_set_state (bin, GST_STATE_PLAYING);
-  ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+  res = gst_element_set_state (bin, GST_STATE_PLAYING);
+  fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
   g_main_loop_run (main_loop);
 
-  state_res = gst_element_set_state (bin, GST_STATE_NULL);
-  ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+  res = gst_element_set_state (bin, GST_STATE_NULL);
+  fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
   /* cleanup */
   g_main_loop_unref (main_loop);
@@ -810,7 +759,6 @@ GST_START_TEST (test_clip)
   GstBus *bus;
   GstPad *sinkpad;
   gboolean res;
-  GstStateChangeReturn state_res;
   GstFlowReturn ret;
   GstEvent *event;
   GstBuffer *buffer;
@@ -838,8 +786,8 @@ GST_START_TEST (test_clip)
   fail_unless (res == TRUE, NULL);
 
   /* set to playing */
-  state_res = gst_element_set_state (bin, GST_STATE_PLAYING);
-  ck_assert_int_ne (state_res, GST_STATE_CHANGE_FAILURE);
+  res = gst_element_set_state (bin, GST_STATE_PLAYING);
+  fail_unless (res != GST_STATE_CHANGE_FAILURE, NULL);
 
   /* create an unconnected sinkpad in adder, should also automatically activate
    * the pad */
@@ -872,7 +820,7 @@ GST_START_TEST (test_clip)
   GST_BUFFER_DURATION (buffer) = 250 * GST_MSECOND;
   GST_DEBUG ("pushing buffer %p", buffer);
   ret = gst_pad_chain (sinkpad, buffer);
-  ck_assert_int_eq (ret, GST_FLOW_OK);
+  fail_unless (ret == GST_FLOW_OK);
   fail_unless (handoff_buffer == NULL);
 
   /* should be partially clipped */
@@ -881,7 +829,7 @@ GST_START_TEST (test_clip)
   GST_BUFFER_DURATION (buffer) = 250 * GST_MSECOND;
   GST_DEBUG ("pushing buffer %p", buffer);
   ret = gst_pad_chain (sinkpad, buffer);
-  ck_assert_int_eq (ret, GST_FLOW_OK);
+  fail_unless (ret == GST_FLOW_OK);
   fail_unless (handoff_buffer != NULL);
   gst_buffer_replace (&handoff_buffer, NULL);
 
@@ -891,7 +839,7 @@ GST_START_TEST (test_clip)
   GST_BUFFER_DURATION (buffer) = 250 * GST_MSECOND;
   GST_DEBUG ("pushing buffer %p", buffer);
   ret = gst_pad_chain (sinkpad, buffer);
-  ck_assert_int_eq (ret, GST_FLOW_OK);
+  fail_unless (ret == GST_FLOW_OK);
   fail_unless (handoff_buffer != NULL);
   gst_buffer_replace (&handoff_buffer, NULL);
 
@@ -901,125 +849,14 @@ GST_START_TEST (test_clip)
   GST_BUFFER_DURATION (buffer) = 250 * GST_MSECOND;
   GST_DEBUG ("pushing buffer %p", buffer);
   ret = gst_pad_chain (sinkpad, buffer);
-  ck_assert_int_eq (ret, GST_FLOW_OK);
+  fail_unless (ret == GST_FLOW_OK);
   fail_unless (handoff_buffer == NULL);
+
+
 }
 
 GST_END_TEST;
 
-GST_START_TEST (test_duration_is_max)
-{
-  GstElement *bin, *src[3], *adder, *sink;
-  GstStateChangeReturn state_res;
-  GstFormat format = GST_FORMAT_TIME;
-  gboolean res;
-  gint64 duration;
-
-  GST_INFO ("preparing test");
-
-  /* build pipeline */
-  bin = gst_pipeline_new ("pipeline");
-
-  /* 3 sources, an adder and a fakesink */
-  src[0] = gst_element_factory_make ("audiotestsrc", NULL);
-  src[1] = gst_element_factory_make ("audiotestsrc", NULL);
-  src[2] = gst_element_factory_make ("audiotestsrc", NULL);
-  adder = gst_element_factory_make ("adder", "adder");
-  sink = gst_element_factory_make ("fakesink", "sink");
-  gst_bin_add_many (GST_BIN (bin), src[0], src[1], src[2], adder, sink, NULL);
-
-  gst_element_link (src[0], adder);
-  gst_element_link (src[1], adder);
-  gst_element_link (src[2], adder);
-  gst_element_link (adder, sink);
-
-  /* irks, duration is reset on basesrc */
-  state_res = gst_element_set_state (bin, GST_STATE_PAUSED);
-  fail_unless (state_res != GST_STATE_CHANGE_FAILURE, NULL);
-
-  /* set durations on src */
-  GST_BASE_SRC (src[0])->segment.duration = 1000;
-  GST_BASE_SRC (src[1])->segment.duration = 3000;
-  GST_BASE_SRC (src[2])->segment.duration = 2000;
-
-  /* set to playing */
-  state_res = gst_element_set_state (bin, GST_STATE_PLAYING);
-  fail_unless (state_res != GST_STATE_CHANGE_FAILURE, NULL);
-
-  /* wait for completion */
-  state_res =
-      gst_element_get_state (GST_ELEMENT (bin), NULL, NULL,
-      GST_CLOCK_TIME_NONE);
-  fail_unless (state_res != GST_STATE_CHANGE_FAILURE, NULL);
-
-  res = gst_element_query_duration (GST_ELEMENT (bin), format, &duration);
-  fail_unless (res, NULL);
-
-  ck_assert_int_eq (duration, 3000);
-
-  gst_element_set_state (bin, GST_STATE_NULL);
-  gst_object_unref (bin);
-}
-
-GST_END_TEST;
-
-GST_START_TEST (test_duration_unknown_overrides)
-{
-  GstElement *bin, *src[3], *adder, *sink;
-  GstStateChangeReturn state_res;
-  GstFormat format = GST_FORMAT_TIME;
-  gboolean res;
-  gint64 duration;
-
-  GST_INFO ("preparing test");
-
-  /* build pipeline */
-  bin = gst_pipeline_new ("pipeline");
-
-  /* 3 sources, an adder and a fakesink */
-  src[0] = gst_element_factory_make ("audiotestsrc", NULL);
-  src[1] = gst_element_factory_make ("audiotestsrc", NULL);
-  src[2] = gst_element_factory_make ("audiotestsrc", NULL);
-  adder = gst_element_factory_make ("adder", "adder");
-  sink = gst_element_factory_make ("fakesink", "sink");
-  gst_bin_add_many (GST_BIN (bin), src[0], src[1], src[2], adder, sink, NULL);
-
-  gst_element_link (src[0], adder);
-  gst_element_link (src[1], adder);
-  gst_element_link (src[2], adder);
-  gst_element_link (adder, sink);
-
-  /* irks, duration is reset on basesrc */
-  state_res = gst_element_set_state (bin, GST_STATE_PAUSED);
-  fail_unless (state_res != GST_STATE_CHANGE_FAILURE, NULL);
-
-  /* set durations on src */
-  GST_BASE_SRC (src[0])->segment.duration = GST_CLOCK_TIME_NONE;
-  GST_BASE_SRC (src[1])->segment.duration = 3000;
-  GST_BASE_SRC (src[2])->segment.duration = 2000;
-
-  /* set to playing */
-  state_res = gst_element_set_state (bin, GST_STATE_PLAYING);
-  fail_unless (state_res != GST_STATE_CHANGE_FAILURE, NULL);
-
-  /* wait for completion */
-  state_res =
-      gst_element_get_state (GST_ELEMENT (bin), NULL, NULL,
-      GST_CLOCK_TIME_NONE);
-  fail_unless (state_res != GST_STATE_CHANGE_FAILURE, NULL);
-
-  res = gst_element_query_duration (GST_ELEMENT (bin), format, &duration);
-  fail_unless (res, NULL);
-
-  ck_assert_int_eq (duration, GST_CLOCK_TIME_NONE);
-
-  gst_element_set_state (bin, GST_STATE_NULL);
-  gst_object_unref (bin);
-}
-
-GST_END_TEST;
-
-
 static Suite *
 adder_suite (void)
 {
@@ -1027,7 +864,6 @@ adder_suite (void)
   TCase *tc_chain = tcase_create ("general");
 
   suite_add_tcase (s, tc_chain);
-  tcase_add_test (tc_chain, test_caps);
   tcase_add_test (tc_chain, test_event);
   tcase_add_test (tc_chain, test_play_twice);
   tcase_add_test (tc_chain, test_play_twice_then_add_and_play_again);
@@ -1035,8 +871,6 @@ adder_suite (void)
   tcase_add_test (tc_chain, test_add_pad);
   tcase_add_test (tc_chain, test_remove_pad);
   tcase_add_test (tc_chain, test_clip);
-  tcase_add_test (tc_chain, test_duration_is_max);
-  tcase_add_test (tc_chain, test_duration_unknown_overrides);
 
   /* Use a longer timeout */
 #ifdef HAVE_VALGRIND
