@@ -209,6 +209,27 @@ GST_START_TEST (test_musicbrainz_tag_registration)
 
 GST_END_TEST;
 
+/* is there an easier way to compare two structures / tagslists? */
+static gboolean
+taglists_are_equal (const GstTagList * list_1, const GstTagList * list_2)
+{
+  GstCaps *c_list_1 = gst_caps_new_empty ();
+  GstCaps *c_list_2 = gst_caps_new_empty ();
+  gboolean ret;
+
+  gst_caps_append_structure (c_list_1,
+      gst_structure_copy ((GstStructure *) list_1));
+  gst_caps_append_structure (c_list_2,
+      gst_structure_copy ((GstStructure *) list_2));
+
+  ret = gst_caps_is_equal (c_list_2, c_list_1);
+
+  gst_caps_unref (c_list_1);
+  gst_caps_unref (c_list_2);
+
+  return ret;
+}
+
 GST_START_TEST (test_vorbis_tags)
 {
   GstTagList *list;
@@ -276,16 +297,15 @@ GST_START_TEST (test_vorbis_tags)
   ASSERT_TAG_LIST_HAS_UINT (list, GST_TAG_ALBUM_VOLUME_COUNT, 2);
 
   {
-    GstDateTime *dt = NULL;
+    GDate *date = NULL;
 
-    fail_unless (gst_tag_list_get_date_time (list, GST_TAG_DATE_TIME, &dt));
-    fail_unless (dt != NULL);
-    fail_unless (gst_date_time_get_day (dt) == 31);
-    fail_unless (gst_date_time_get_month (dt) == 12);
-    fail_unless (gst_date_time_get_year (dt) == 1954);
-    fail_unless (!gst_date_time_has_time (dt));
+    fail_unless (gst_tag_list_get_date (list, GST_TAG_DATE, &date));
+    fail_unless (date != NULL);
+    fail_unless (g_date_get_day (date) == 31);
+    fail_unless (g_date_get_month (date) == G_DATE_DECEMBER);
+    fail_unless (g_date_get_year (date) == 1954);
 
-    gst_date_time_unref (dt);
+    g_date_free (date);
   }
 
   /* unknown vorbis comments should go into a GST_TAG_EXTENDED_COMMENT */
@@ -327,7 +347,7 @@ GST_START_TEST (test_vorbis_tags)
     vendor_id = NULL;
 
     GST_LOG ("new_list = %" GST_PTR_FORMAT, new_list);
-    fail_unless (gst_tag_list_is_equal (list, new_list));
+    fail_unless (taglists_are_equal (list, new_list));
 
     buf2 = gst_tag_list_to_vorbiscomment_buffer (new_list,
         (const guint8 *) "\003vorbis", 7, "libgstunittest");
@@ -340,7 +360,7 @@ GST_START_TEST (test_vorbis_tags)
     vendor_id = NULL;
 
     GST_LOG ("even_newer_list = %" GST_PTR_FORMAT, even_newer_list);
-    fail_unless (gst_tag_list_is_equal (new_list, even_newer_list));
+    fail_unless (taglists_are_equal (new_list, even_newer_list));
 
     gst_tag_list_free (new_list);
     gst_tag_list_free (even_newer_list);
@@ -446,14 +466,14 @@ GST_START_TEST (test_vorbis_tags)
     fail_unless (vendor != NULL);
     fail_unless_equals_string (vendor, "foo");
     fail_unless (list != NULL);
-    fail_unless (gst_tag_list_n_tags (list) == 0);
+    fail_unless (gst_structure_n_fields ((GstStructure *) list) == 0);
     g_free (vendor);
     gst_tag_list_free (list);
 
     /* now again without vendor */
     list = gst_tag_list_from_vorbiscomment_buffer (buf, NULL, 0, NULL);
     fail_unless (list != NULL);
-    fail_unless (gst_tag_list_n_tags (list) == 0);
+    fail_unless (gst_structure_n_fields ((GstStructure *) list) == 0);
     gst_tag_list_free (list);
 
     gst_buffer_unref (buf);
@@ -493,7 +513,7 @@ GST_START_TEST (test_vorbis_tags)
     fail_unless (vendor != NULL);
     fail_unless_equals_string (vendor, "foo");
     fail_unless (list != NULL);
-    fail_unless (gst_tag_list_n_tags (list) == 1);
+    fail_unless (gst_structure_n_fields ((GstStructure *) list) == 1);
     ASSERT_TAG_LIST_HAS_STRING (list, GST_TAG_ARTIST, "foo bar");
     g_free (vendor);
     gst_tag_list_free (list);
@@ -502,7 +522,7 @@ GST_START_TEST (test_vorbis_tags)
     list = gst_tag_list_from_vorbiscomment_buffer (buf,
         (guint8 *) "\003vorbis", 7, NULL);
     fail_unless (list != NULL);
-    fail_unless (gst_tag_list_n_tags (list) == 1);
+    fail_unless (gst_structure_n_fields ((GstStructure *) list) == 1);
     ASSERT_TAG_LIST_HAS_STRING (list, GST_TAG_ARTIST, "foo bar");
     gst_tag_list_free (list);
 
@@ -511,55 +531,49 @@ GST_START_TEST (test_vorbis_tags)
 
   /* check date with time */
   {
-    GstDateTime *dt = NULL;
+    GDate *date = NULL;
 
     list = gst_tag_list_new_empty ();
     gst_vorbis_tag_add (list, "DATE", "2006-09-25 22:02:38");
 
-    fail_unless (gst_tag_list_get_date_time (list, GST_TAG_DATE_TIME, &dt));
-    fail_unless (dt != NULL);
-    fail_unless (gst_date_time_get_day (dt) == 25);
-    fail_unless (gst_date_time_get_month (dt) == 9);
-    fail_unless (gst_date_time_get_year (dt) == 2006);
-    fail_unless (gst_date_time_has_time (dt));
+    fail_unless (gst_tag_list_get_date_index (list, GST_TAG_DATE, 0, &date));
+    fail_unless (date != NULL);
+    fail_unless (g_date_get_day (date) == 25);
+    fail_unless (g_date_get_month (date) == G_DATE_SEPTEMBER);
+    fail_unless (g_date_get_year (date) == 2006);
 
-    gst_date_time_unref (dt);
+    g_date_free (date);
     gst_tag_list_free (list);
   }
 
   /* check date with month/day of 00-00 */
   {
-    GstDateTime *dt = NULL;
+    GDate *date = NULL;
 
     list = gst_tag_list_new_empty ();
     gst_vorbis_tag_add (list, "DATE", "1992-00-00");
 
-    fail_unless (gst_tag_list_get_date_time (list, GST_TAG_DATE_TIME, &dt));
-    fail_unless (dt != NULL);
-    fail_unless (gst_date_time_get_year (dt) == 1992);
-    fail_unless (!gst_date_time_has_month (dt));
-    fail_unless (!gst_date_time_has_day (dt));
-    fail_unless (!gst_date_time_has_time (dt));
+    fail_unless (gst_tag_list_get_date_index (list, GST_TAG_DATE, 0, &date));
+    fail_unless (date != NULL);
+    fail_unless (g_date_get_year (date) == 1992);
 
-    gst_date_time_unref (dt);
+    g_date_free (date);
     gst_tag_list_free (list);
   }
 
   /* check date with valid month, but day of 00 */
   {
-    GstDateTime *dt = NULL;
+    GDate *date = NULL;
 
     list = gst_tag_list_new_empty ();
     gst_vorbis_tag_add (list, "DATE", "1992-05-00");
 
-    fail_unless (gst_tag_list_get_date_time (list, GST_TAG_DATE_TIME, &dt));
-    fail_unless (dt != NULL);
-    fail_unless (gst_date_time_get_year (dt) == 1992);
-    fail_unless (gst_date_time_get_month (dt) == 5);
-    fail_unless (!gst_date_time_has_day (dt));
-    fail_unless (!gst_date_time_has_time (dt));
+    fail_unless (gst_tag_list_get_date_index (list, GST_TAG_DATE, 0, &date));
+    fail_unless (date != NULL);
+    fail_unless (g_date_get_year (date) == 1992);
+    fail_unless (g_date_get_month (date) == G_DATE_MAY);
 
-    gst_date_time_unref (dt);
+    g_date_free (date);
     gst_tag_list_free (list);
   }
 }
@@ -638,8 +652,8 @@ GST_START_TEST (test_id3v1_utf8_tag)
     /* genre */
     0x11
   };
-  GstDateTime *dt;
   GstTagList *tags;
+  GDate *d;
   gchar *s;
 
   /* set this, to make sure UTF-8 strings are really interpreted properly
@@ -669,15 +683,12 @@ GST_START_TEST (test_id3v1_utf8_tag)
   fail_unless_equals_string (s, "Best of (Prostě úžasný)");
   g_free (s);
 
-  dt = NULL;
-  fail_unless (gst_tag_list_get_date_time (tags, GST_TAG_DATE_TIME, &dt));
-  fail_unless (dt != NULL);
-  fail_unless_equals_int (gst_date_time_get_year (dt), 2000);
-  fail_if (gst_date_time_has_month (dt));
-  fail_if (gst_date_time_has_day (dt));
-  fail_if (gst_date_time_has_time (dt));
-  gst_date_time_unref (dt);
-  dt = NULL;
+  d = NULL;
+  fail_unless (gst_tag_list_get_date (tags, GST_TAG_DATE, &d));
+  fail_unless (d != NULL);
+  fail_unless_equals_int (g_date_get_year (d), 2000);
+  g_date_free (d);
+  d = NULL;
 
   gst_tag_list_free (tags);
 
@@ -962,7 +973,7 @@ GST_START_TEST (test_xmp_formatting)
       GST_TAG_DESCRIPTION, "test decription",
       GST_TAG_KEYWORDS, "keyword1", GST_TAG_KEYWORDS, "keyword2", NULL);
 
-  buf = gst_tag_list_to_xmp_buffer (list, FALSE, NULL);
+  buf = gst_tag_list_to_xmp_buffer (list, FALSE);
   fail_unless (buf != NULL);
 
   gst_buffer_map (buf, &map, GST_MAP_READ);
@@ -1043,7 +1054,7 @@ GST_START_TEST (test_xmp_parsing)
       if (test_data[i].result_size >= 0) {
         fail_unless (list != NULL);
 
-        result_size = gst_tag_list_n_tags (list);
+        result_size = gst_structure_n_fields ((GstStructure *) list);
         fail_unless (result_size == test_data[i].result_size);
 
         /* check the taglist content */
@@ -1075,7 +1086,7 @@ do_xmp_tag_serialization_deserialization (GstTagList * taglist,
   GstTagList *taglist2;
   GstBuffer *buf;
 
-  buf = gst_tag_list_to_xmp_buffer (taglist, TRUE, schemas);
+  buf = gst_tag_list_to_xmp_buffer_full (taglist, TRUE, schemas);
   taglist2 = gst_tag_list_from_xmp_buffer (buf);
 
   fail_unless (gst_tag_list_is_equal (taglist, taglist2));
@@ -1099,6 +1110,7 @@ do_simple_xmp_tag_serialization_deserialization (const gchar * gsttag,
 GST_START_TEST (test_xmp_tags_serialization_deserialization)
 {
   GValue value = { 0 };
+  GDate *date;
   GstDateTime *datetime;
 
   gst_tag_register_musicbrainz_tags ();
@@ -1225,10 +1237,11 @@ GST_START_TEST (test_xmp_tags_serialization_deserialization)
       (GST_TAG_CAPTURING_EXPOSURE_COMPENSATION, &value);
   g_value_unset (&value);
 
-  g_value_init (&value, GST_TYPE_DATE_TIME);
-  datetime = gst_date_time_new_ymd (2010, 3, 22);
-  g_value_take_boxed (&value, datetime);
-  do_simple_xmp_tag_serialization_deserialization (GST_TAG_DATE_TIME, &value);
+  g_value_init (&value, G_TYPE_DATE);
+  date = g_date_new_dmy (22, 3, 2010);
+  g_value_set_boxed (&value, date);
+  g_date_free (date);
+  do_simple_xmp_tag_serialization_deserialization (GST_TAG_DATE, &value);
   g_value_unset (&value);
 
   g_value_init (&value, G_TYPE_UINT);
@@ -1734,14 +1747,14 @@ GST_START_TEST (test_exif_tags_serialization_deserialization)
   do_simple_exif_tag_serialization_deserialization (GST_TAG_DATE_TIME, &value);
   g_value_unset (&value);
 
-  g_value_init (&value, GST_TYPE_SAMPLE);
+  g_value_init (&value, GST_TYPE_BUFFER);
   buf = gst_buffer_new_and_alloc (1024);
   gst_buffer_map (buf, &map, GST_MAP_WRITE);
   data = map.data;
   for (i = 0; i < 1024; i++)
     data[i] = i % 255;
   gst_buffer_unmap (buf, &map);
-  gst_value_take_sample (&value, gst_sample_new (buf, NULL, NULL, NULL));
+  gst_value_set_buffer (&value, buf);
   gst_buffer_unref (buf);
   do_simple_exif_tag_serialization_deserialization (GST_TAG_APPLICATION_DATA,
       &value);
