@@ -34,8 +34,9 @@
 #include <gst/check/gstcheck.h>
 
 #include <gst/video/video.h>
-#include <gst/video/gstvideometa.h>
+#if 0
 #include <gst/video/video-overlay-composition.h>
+#endif
 #include <string.h>
 
 /* These are from the current/old videotestsrc; we check our new public API
@@ -357,7 +358,7 @@ video_format_is_packed (GstVideoFormat fmt)
     case GST_VIDEO_FORMAT_ABGR:
     case GST_VIDEO_FORMAT_RGB:
     case GST_VIDEO_FORMAT_BGR:
-    case GST_VIDEO_FORMAT_RGB8P:
+    case GST_VIDEO_FORMAT_RGB8_PALETTED:
       return TRUE;
     default:
       g_return_val_if_reached (FALSE);
@@ -395,8 +396,7 @@ GST_START_TEST (test_video_formats_all)
     fail_if (gst_video_format_from_string (fmt_str) ==
         GST_VIDEO_FORMAT_UNKNOWN);
   }
-  /* Take into account GST_VIDEO_FORMAT_ENCODED */
-  fail_unless_equals_int (num, num_formats - 1);
+  fail_unless_equals_int (num, num_formats);
 
   gst_caps_unref (caps);
 }
@@ -539,7 +539,6 @@ GST_START_TEST (test_video_formats_rgb)
   GstCaps *caps;
   GstStructure *structure;
 
-  gst_video_info_init (&vinfo);
   gst_video_info_set_format (&vinfo, GST_VIDEO_FORMAT_RGB, 800, 600);
   vinfo.par_n = 1;
   vinfo.par_d = 1;
@@ -631,8 +630,7 @@ GST_START_TEST (test_parse_caps_rgb)
     gst_caps_set_simple (caps, "width", G_TYPE_INT, 2 * (i + 1), "height",
         G_TYPE_INT, i + 1, "framerate", GST_TYPE_FRACTION, 15, 1,
         "pixel-aspect-ratio", GST_TYPE_FRACTION, 1, 1,
-        "interlace-mode", G_TYPE_STRING, "progressive",
-        "colorimetry", G_TYPE_STRING, "1:1:0:0", NULL);
+        "interlace-mode", G_TYPE_STRING, "progressive", NULL);
     g_assert (gst_caps_is_fixed (caps));
 
     GST_DEBUG ("testing caps: %" GST_PTR_FORMAT, caps);
@@ -840,7 +838,6 @@ GST_START_TEST (test_convert_frame_async)
 
   gst_sample_unref (cf_data.sample);
   gst_caps_unref (to_caps);
-  gst_sample_unref (from_sample);
 
   g_main_loop_unref (loop);
 }
@@ -866,24 +863,21 @@ GST_START_TEST (test_video_size_from_caps)
 
 GST_END_TEST;
 
+#if 0
+/* FIXME 0.11: port overlay composition to buffer meta */
 GST_START_TEST (test_overlay_composition)
 {
   GstVideoOverlayComposition *comp1, *comp2;
   GstVideoOverlayRectangle *rect1, *rect2;
-  GstVideoOverlayCompositionMeta *ometa;
   GstBuffer *pix1, *pix2, *buf;
-  GstVideoMeta *vmeta;
   guint seq1, seq2;
   guint w, h, stride;
   gint x, y;
-  guint8 val;
 
   pix1 = gst_buffer_new_and_alloc (200 * sizeof (guint32) * 50);
-  gst_buffer_memset (pix1, 0, 0, gst_buffer_get_size (pix1));
+  memset (GST_BUFFER_DATA (pix1), 0, GST_BUFFER_SIZE (pix1));
 
-  gst_buffer_add_video_meta (pix1, GST_VIDEO_FRAME_FLAG_NONE,
-      GST_VIDEO_OVERLAY_COMPOSITION_FORMAT_RGB, 200, 50);
-  rect1 = gst_video_overlay_rectangle_new_argb (pix1,
+  rect1 = gst_video_overlay_rectangle_new_argb (pix1, 200, 50, 200 * 4,
       600, 50, 300, 50, GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
 
   gst_buffer_unref (pix1);
@@ -943,14 +937,13 @@ GST_START_TEST (test_overlay_composition)
   fail_unless_equals_int (h, 51);
 
   /* get scaled pixbuf and touch last byte */
-  pix1 = gst_video_overlay_rectangle_get_pixels_argb (rect1,
+  pix1 = gst_video_overlay_rectangle_get_pixels_argb (rect1, &stride,
       GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
-  stride = 4 * w;
-  fail_unless (gst_buffer_get_size (pix1) > ((h - 1) * stride + (w * 4) - 1),
-      "size %u vs. last pixel offset %u", gst_buffer_get_size (pix1),
+  fail_unless (GST_BUFFER_SIZE (pix1) > ((h - 1) * stride + (w * 4) - 1),
+      "size %u vs. last pixel offset %u", GST_BUFFER_SIZE (pix1),
       ((h - 1) * stride + (w * 4) - 1));
-  gst_buffer_extract (pix1, ((h - 1) * stride + (w * 4) - 1), &val, 1);
-  fail_unless_equals_int (val, 0);
+  fail_unless_equals_int (*(GST_BUFFER_DATA (pix1) + ((h - 1) * stride +
+              (w * 4) - 1)), 0);
 
   gst_video_overlay_rectangle_get_render_rectangle (rect2, &x, &y, &w, &h);
   fail_unless_equals_int (x, 50);
@@ -959,71 +952,59 @@ GST_START_TEST (test_overlay_composition)
   fail_unless_equals_int (h, 50);
 
   /* get scaled pixbuf and touch last byte */
-  pix2 = gst_video_overlay_rectangle_get_pixels_argb (rect2,
+  pix2 = gst_video_overlay_rectangle_get_pixels_argb (rect2, &stride,
       GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
-  stride = 4 * w;
-  fail_unless (gst_buffer_get_size (pix2) > ((h - 1) * stride + (w * 4) - 1),
-      "size %u vs. last pixel offset %u", gst_buffer_get_size (pix1),
+  fail_unless (GST_BUFFER_SIZE (pix2) > ((h - 1) * stride + (w * 4) - 1),
+      "size %u vs. last pixel offset %u", GST_BUFFER_SIZE (pix1),
       ((h - 1) * stride + (w * 4) - 1));
-  gst_buffer_extract (pix2, ((h - 1) * stride + (w * 4) - 1), &val, 1);
-  fail_unless_equals_int (val, 0);
+  fail_unless_equals_int (*(GST_BUFFER_DATA (pix2) + ((h - 1) * stride +
+              (w * 4) - 1)), 0);
 
   /* get scaled pixbuf again, should be the same buffer as before (caching) */
-  pix1 = gst_video_overlay_rectangle_get_pixels_argb (rect2,
+  pix1 = gst_video_overlay_rectangle_get_pixels_argb (rect2, &stride,
       GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
   fail_unless (pix1 == pix2);
 
   /* now compare the original unscaled ones */
-  pix1 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1,
-      GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
-  pix2 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect2,
-      GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
-
-  vmeta = gst_buffer_get_video_meta (pix2);
-  fail_unless (vmeta != NULL);
-  w = vmeta->width;
-  h = vmeta->height;
+  pix1 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1, &w, &h,
+      &stride, GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
+  pix2 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect2, &w, &h,
+      &stride, GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
 
   /* the original pixel buffers should be identical */
   fail_unless (pix1 == pix2);
   fail_unless_equals_int (w, 200);
   fail_unless_equals_int (h, 50);
-  stride = 4 * w;
 
   /* touch last byte */
-  fail_unless (gst_buffer_get_size (pix1) > ((h - 1) * stride + (w * 4) - 1),
-      "size %u vs. last pixel offset %u", gst_buffer_get_size (pix1),
+  fail_unless (GST_BUFFER_SIZE (pix1) > ((h - 1) * stride + (w * 4) - 1),
+      "size %u vs. last pixel offset %u", GST_BUFFER_SIZE (pix1),
       ((h - 1) * stride + (w * 4) - 1));
-  gst_buffer_extract (pix1, ((h - 1) * stride + (w * 4) - 1), &val, 1);
-  fail_unless_equals_int (val, 0);
+  fail_unless_equals_int (*(GST_BUFFER_DATA (pix1) + ((h - 1) * stride +
+              (w * 4) - 1)), 0);
 
   /* test attaching and retrieving of compositions to/from buffers */
   buf = gst_buffer_new ();
-  fail_unless (gst_buffer_get_video_overlay_composition_meta (buf) == NULL);
+  fail_unless (gst_video_buffer_get_overlay_composition (buf) == NULL);
 
   gst_buffer_ref (buf);
   /* buffer now has refcount of 2, so its metadata is not writable.
    * only check this if we are not running in valgrind, as it leaks */
 #ifdef HAVE_VALGRIND
   if (!RUNNING_ON_VALGRIND) {
-    ASSERT_CRITICAL (gst_buffer_add_video_overlay_composition_meta (buf,
-            comp1));
+    ASSERT_CRITICAL (gst_video_buffer_set_overlay_composition (buf, comp1));
   }
 #endif
   gst_buffer_unref (buf);
-  gst_buffer_add_video_overlay_composition_meta (buf, comp1);
-  ometa = gst_buffer_get_video_overlay_composition_meta (buf);
-  fail_unless (ometa != NULL);
-  fail_unless (ometa->overlay == comp1);
-  fail_unless (gst_buffer_remove_video_overlay_composition_meta (buf, ometa));
-  gst_buffer_add_video_overlay_composition_meta (buf, comp2);
-  ometa = gst_buffer_get_video_overlay_composition_meta (buf);
-  fail_unless (ometa->overlay == comp2);
-  fail_unless (gst_buffer_remove_video_overlay_composition_meta (buf, ometa));
-  fail_unless (gst_buffer_get_video_overlay_composition_meta (buf) == NULL);
+  gst_video_buffer_set_overlay_composition (buf, comp1);
+  fail_unless (gst_video_buffer_get_overlay_composition (buf) == comp1);
+  gst_video_buffer_set_overlay_composition (buf, comp2);
+  fail_unless (gst_video_buffer_get_overlay_composition (buf) == comp2);
+  gst_video_buffer_set_overlay_composition (buf, NULL);
+  fail_unless (gst_video_buffer_get_overlay_composition (buf) == NULL);
 
   /* make sure the buffer cleans up its composition ref when unreffed */
-  gst_buffer_add_video_overlay_composition_meta (buf, comp2);
+  gst_video_buffer_set_overlay_composition (buf, comp2);
   gst_buffer_unref (buf);
 
   gst_video_overlay_composition_unref (comp2);
@@ -1035,62 +1016,49 @@ GST_END_TEST;
 GST_START_TEST (test_overlay_composition_premultiplied_alpha)
 {
   GstVideoOverlayRectangle *rect1;
-  GstVideoMeta *vmeta;
   GstBuffer *pix1, *pix2, *pix3, *pix4, *pix5;
   GstBuffer *pix6, *pix7, *pix8, *pix9, *pix10;
   guint8 *data5, *data7;
-  guint w, h, w2, h2;
-  GstMapInfo map;
+  guint w, h, stride, w2, h2, stride2;
 
   pix1 = gst_buffer_new_and_alloc (200 * sizeof (guint32) * 50);
-  gst_buffer_memset (pix1, 0, 0x80, gst_buffer_get_size (pix1));
+  memset (GST_BUFFER_DATA (pix1), 0x80, GST_BUFFER_SIZE (pix1));
 
-  gst_buffer_add_video_meta (pix1, GST_VIDEO_FRAME_FLAG_NONE,
-      GST_VIDEO_OVERLAY_COMPOSITION_FORMAT_RGB, 200, 50);
-  rect1 = gst_video_overlay_rectangle_new_argb (pix1,
+  rect1 = gst_video_overlay_rectangle_new_argb (pix1, 200, 50, 200 * 4,
       600, 50, 300, 50, GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
   gst_buffer_unref (pix1);
 
   /* same flags, unscaled, should be the same buffer */
-  pix2 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1,
-      GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
+  pix2 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1, &w, &h,
+      &stride, GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
   fail_unless (pix1 == pix2);
 
   /* same flags, but scaled */
-  pix3 = gst_video_overlay_rectangle_get_pixels_argb (rect1,
+  pix3 = gst_video_overlay_rectangle_get_pixels_argb (rect1, &stride,
       GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
   fail_if (pix3 == pix1 || pix3 == pix2);
 
   /* same again, should hopefully get the same (cached) buffer as before */
-  pix4 = gst_video_overlay_rectangle_get_pixels_argb (rect1,
+  pix4 = gst_video_overlay_rectangle_get_pixels_argb (rect1, &stride,
       GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
   fail_unless (pix4 == pix3);
 
   /* just to update the vars */
-  pix2 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1,
-      GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
-
-  vmeta = gst_buffer_get_video_meta (pix2);
-  fail_unless (vmeta != NULL);
-  w = vmeta->width;
-  h = vmeta->height;
+  pix2 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1, &w, &h,
+      &stride, GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
 
   /* now, let's try to get premultiplied alpha from the unpremultiplied input */
-  pix5 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1,
-      GST_VIDEO_OVERLAY_FORMAT_FLAG_PREMULTIPLIED_ALPHA);
+  pix5 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1, &w2, &h2,
+      &stride2, GST_VIDEO_OVERLAY_FORMAT_FLAG_PREMULTIPLIED_ALPHA);
   fail_if (pix5 == pix1 || pix5 == pix2 || pix5 == pix3);
-  vmeta = gst_buffer_get_video_meta (pix5);
-  fail_unless (vmeta != NULL);
-  w2 = vmeta->width;
-  h2 = vmeta->height;
+  fail_unless_equals_int (stride, stride2);
   fail_unless_equals_int (w, w2);
   fail_unless_equals_int (h, h2);
-  fail_unless_equals_int (gst_buffer_get_size (pix2),
-      gst_buffer_get_size (pix5));
-  gst_buffer_map (pix5, &map, GST_MAP_READ);
-  fail_if (gst_buffer_memcmp (pix2, 0, map.data, map.size) == 0);
+  fail_unless_equals_int (GST_BUFFER_SIZE (pix2), GST_BUFFER_SIZE (pix5));
+  data5 = GST_BUFFER_DATA (pix5);
+  fail_if (memcmp (data5, GST_BUFFER_DATA (pix2), GST_BUFFER_SIZE (pix5)) == 0);
+
   /* make sure it actually did what we expected it to do (input=0x80808080) */
-  data5 = map.data;
 #if G_BYTE_ORDER == G_LITTLE_ENDIAN
   /* B - G - R - A */
   fail_unless_equals_int (data5[0], 0x40);
@@ -1104,26 +1072,25 @@ GST_START_TEST (test_overlay_composition_premultiplied_alpha)
   fail_unless_equals_int (data5[2], 0x40);
   fail_unless_equals_int (data5[3], 0x80);
 #endif
-  gst_buffer_unmap (pix5, &map);
 
   /* same again, now we should be getting back the same buffer as before,
    * as it should have been cached */
-  pix6 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1,
-      GST_VIDEO_OVERLAY_FORMAT_FLAG_PREMULTIPLIED_ALPHA);
+  pix6 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1, &w2, &h2,
+      &stride2, GST_VIDEO_OVERLAY_FORMAT_FLAG_PREMULTIPLIED_ALPHA);
   fail_unless (pix6 == pix5);
 
   /* just to update the stride var */
-  pix3 = gst_video_overlay_rectangle_get_pixels_argb (rect1,
+  pix3 = gst_video_overlay_rectangle_get_pixels_argb (rect1, &stride,
       GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
   fail_unless (pix3 == pix4);
 
   /* now try to get scaled premultiplied alpha from unpremultiplied input */
-  pix7 = gst_video_overlay_rectangle_get_pixels_argb (rect1,
+  pix7 = gst_video_overlay_rectangle_get_pixels_argb (rect1, &stride2,
       GST_VIDEO_OVERLAY_FORMAT_FLAG_PREMULTIPLIED_ALPHA);
   fail_if (pix7 == pix1 || pix7 == pix2 || pix7 == pix3 || pix7 == pix5);
+  fail_unless_equals_int (stride, stride2);
 
-  gst_buffer_map (pix7, &map, GST_MAP_READ);
-  data7 = map.data;
+  data7 = GST_BUFFER_DATA (pix7);
   /* make sure it actually did what we expected it to do (input=0x80808080)
    * hoping that the scaling didn't mess up our values */
 #if G_BYTE_ORDER == G_LITTLE_ENDIAN
@@ -1139,78 +1106,65 @@ GST_START_TEST (test_overlay_composition_premultiplied_alpha)
   fail_unless_equals_int (data7[2], 0x40);
   fail_unless_equals_int (data7[3], 0x80);
 #endif
-  gst_buffer_unmap (pix7, &map);
 
   /* and the same again, it should be cached now */
-  pix8 = gst_video_overlay_rectangle_get_pixels_argb (rect1,
+  pix8 = gst_video_overlay_rectangle_get_pixels_argb (rect1, &stride2,
       GST_VIDEO_OVERLAY_FORMAT_FLAG_PREMULTIPLIED_ALPHA);
   fail_unless (pix8 == pix7);
 
   /* make sure other cached stuff is still there */
-  pix9 = gst_video_overlay_rectangle_get_pixels_argb (rect1,
+  pix9 = gst_video_overlay_rectangle_get_pixels_argb (rect1, &stride,
       GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
   fail_unless (pix9 == pix3);
-  pix10 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1,
-      GST_VIDEO_OVERLAY_FORMAT_FLAG_PREMULTIPLIED_ALPHA);
+  pix10 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1, &w2, &h2,
+      &stride2, GST_VIDEO_OVERLAY_FORMAT_FLAG_PREMULTIPLIED_ALPHA);
   fail_unless (pix10 == pix5);
 
   gst_video_overlay_rectangle_unref (rect1);
 }
 
 GST_END_TEST;
+#endif
 
+#if 0
 GST_START_TEST (test_overlay_composition_global_alpha)
 {
   GstVideoOverlayRectangle *rect1;
   GstBuffer *pix1, *pix2, *pix3, *pix4, *pix5;
-  GstVideoMeta *vmeta;
   guint8 *data2, *data4, *data5;
-  guint w, h, w4, h4;
+  guint w, h, stride, stride3, w4, h4, stride4, stride5;
   guint seq1, seq2;
   gfloat ga1, ga2;
   GstVideoOverlayFormatFlags flags1;
-  GstMapInfo map;
 
   pix1 = gst_buffer_new_and_alloc (200 * sizeof (guint32) * 50);
-  gst_buffer_memset (pix1, 0, 0x80, gst_buffer_get_size (pix1));
+  memset (GST_BUFFER_DATA (pix1), 0x80, GST_BUFFER_SIZE (pix1));
 
-  gst_buffer_add_video_meta (pix1, GST_VIDEO_FRAME_FLAG_NONE,
-      GST_VIDEO_OVERLAY_COMPOSITION_FORMAT_RGB, 200, 50);
-  rect1 = gst_video_overlay_rectangle_new_argb (pix1,
+  rect1 = gst_video_overlay_rectangle_new_argb (pix1, 200, 50, 200 * 4,
       600, 50, 300, 50, GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
   gst_buffer_unref (pix1);
 
   /* same flags, unscaled, should be the same buffer */
-  pix2 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1,
-      GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
+  pix2 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1, &w, &h,
+      &stride, GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
   fail_unless (pix1 == pix2);
 
-  vmeta = gst_buffer_get_video_meta (pix2);
-  fail_unless (vmeta != NULL);
-  w = vmeta->width;
-  h = vmeta->height;
-
   /* same flags, but scaled */
-  pix3 = gst_video_overlay_rectangle_get_pixels_argb (rect1,
+  pix3 = gst_video_overlay_rectangle_get_pixels_argb (rect1, &stride3,
       GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
   fail_if (pix3 == pix1 || pix3 == pix2);
 
   /* get unscaled premultiplied data, new cached rectangle should be created */
-  pix4 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1,
-      GST_VIDEO_OVERLAY_FORMAT_FLAG_PREMULTIPLIED_ALPHA);
+  pix4 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1, &w4, &h4,
+      &stride4, GST_VIDEO_OVERLAY_FORMAT_FLAG_PREMULTIPLIED_ALPHA);
   fail_if (pix4 == pix2 || pix4 == pix3);
-  vmeta = gst_buffer_get_video_meta (pix4);
-  fail_unless (vmeta != NULL);
-  w4 = vmeta->width;
-  h4 = vmeta->height;
+  fail_unless_equals_int (stride, stride4);
   fail_unless_equals_int (w, w4);
   fail_unless_equals_int (h, h4);
-  fail_unless_equals_int (gst_buffer_get_size (pix2),
-      gst_buffer_get_size (pix4));
-  gst_buffer_map (pix4, &map, GST_MAP_READ);
-  fail_if (gst_buffer_memcmp (pix1, 0, map.data, map.size) == 0);
+  fail_unless_equals_int (GST_BUFFER_SIZE (pix2), GST_BUFFER_SIZE (pix4));
+  data4 = GST_BUFFER_DATA (pix4);
+  fail_if (memcmp (data4, GST_BUFFER_DATA (pix1), GST_BUFFER_SIZE (pix1)) == 0);
   /* make sure it actually did what we expected it to do (input=0x80808080) */
-  data4 = map.data;
 #if G_BYTE_ORDER == G_LITTLE_ENDIAN
   /* B - G - R - A */
   fail_unless_equals_int (data4[0], 0x40);
@@ -1224,20 +1178,18 @@ GST_START_TEST (test_overlay_composition_global_alpha)
   fail_unless_equals_int (data4[2], 0x40);
   fail_unless_equals_int (data4[3], 0x40);
 #endif
-  gst_buffer_unmap (pix4, &map);
 
   /* now premultiplied and scaled, again a new cached rectangle should be cached */
-  pix5 = gst_video_overlay_rectangle_get_pixels_argb (rect1,
+  pix5 = gst_video_overlay_rectangle_get_pixels_argb (rect1, &stride5,
       GST_VIDEO_OVERLAY_FORMAT_FLAG_PREMULTIPLIED_ALPHA);
   fail_if (pix5 == pix2 || pix5 == pix3 || pix5 == pix4);
   /* stride and size should be equal to the first scaled rect */
-  fail_unless_equals_int (gst_buffer_get_size (pix5),
-      gst_buffer_get_size (pix3));
+  fail_unless_equals_int (stride5, stride3);
+  fail_unless_equals_int (GST_BUFFER_SIZE (pix3), GST_BUFFER_SIZE (pix3));
+  data5 = GST_BUFFER_DATA (pix5);
   /* data should be different (premutliplied) though */
-  gst_buffer_map (pix5, &map, GST_MAP_READ);
-  fail_if (gst_buffer_memcmp (pix3, 0, map.data, map.size) == 0);
+  fail_if (memcmp (data5, GST_BUFFER_DATA (pix3), GST_BUFFER_SIZE (pix3)) == 0);
   /* make sure it actually did what we expected it to do (input=0x80808080) */
-  data5 = map.data;
 #if G_BYTE_ORDER == G_LITTLE_ENDIAN
   /* B - G - R - A */
   fail_unless_equals_int (data5[0], 0x40);
@@ -1251,7 +1203,6 @@ GST_START_TEST (test_overlay_composition_global_alpha)
   fail_unless_equals_int (data5[2], 0x40);
   fail_unless_equals_int (data5[3], 0x40);
 #endif
-  gst_buffer_unmap (pix5, &map);
 
   /* global_alpha should initially be 1.0 */
   ga1 = gst_video_overlay_rectangle_get_global_alpha (rect1);
@@ -1272,13 +1223,14 @@ GST_START_TEST (test_overlay_composition_global_alpha)
   fail_unless_equals_int (flags1, GST_VIDEO_OVERLAY_FORMAT_FLAG_GLOBAL_ALPHA);
 
   /* request unscaled pixel-data, global-alpha not applied */
-  pix2 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1,
-      GST_VIDEO_OVERLAY_FORMAT_FLAG_GLOBAL_ALPHA);
+  pix2 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1, &w, &h,
+      &stride, GST_VIDEO_OVERLAY_FORMAT_FLAG_GLOBAL_ALPHA);
   /* this should just return the same buffer */
   fail_unless (pix2 == pix1);
+  data2 = GST_BUFFER_DATA (pix2);
+  fail_unless (memcmp (data2, GST_BUFFER_DATA (pix1),
+          GST_BUFFER_SIZE (pix1)) == 0);
   /* make sure we got the initial data (input=0x80808080) */
-  gst_buffer_map (pix2, &map, GST_MAP_READ);
-  data2 = map.data;
 #if G_BYTE_ORDER == G_LITTLE_ENDIAN
   /* B - G - R - A */
   fail_unless_equals_int (data2[0], 0x80);
@@ -1292,15 +1244,15 @@ GST_START_TEST (test_overlay_composition_global_alpha)
   fail_unless_equals_int (data2[2], 0x80);
   fail_unless_equals_int (data2[3], 0x80);
 #endif
-  gst_buffer_unmap (pix2, &map);
 
   /* unscaled pixel-data, global-alpha applied */
-  pix2 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1,
-      GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
+  pix2 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1, &w, &h,
+      &stride, GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
   /* this should be the same buffer with on-the-fly modified alpha-channel */
   fail_unless (pix2 == pix1);
-  gst_buffer_map (pix2, &map, GST_MAP_READ);
-  data2 = map.data;
+  data2 = GST_BUFFER_DATA (pix2);
+  fail_unless (memcmp (data2, GST_BUFFER_DATA (pix1),
+          GST_BUFFER_SIZE (pix1)) == 0);
   /* make sure we got the initial data with adjusted alpha-channel */
 #if G_BYTE_ORDER == G_LITTLE_ENDIAN
   /* B - G - R - A */
@@ -1315,19 +1267,19 @@ GST_START_TEST (test_overlay_composition_global_alpha)
   fail_unless_equals_int (data2[2], 0x80);
   fail_unless_equals_int (data2[3], 0x80);
 #endif
-  gst_buffer_unmap (pix2, &map);
 
   /* adjust global_alpha once more */
   gst_video_overlay_rectangle_set_global_alpha (rect1, 0.25);
   ga2 = gst_video_overlay_rectangle_get_global_alpha (rect1);
   fail_unless_equals_float (ga2, 0.25);
   /* and again request unscaled pixel-data, global-alpha applied */
-  pix2 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1,
-      GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
+  pix2 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1, &w, &h,
+      &stride, GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
   fail_unless (pix2 == pix1);
+  data2 = GST_BUFFER_DATA (pix2);
+  fail_unless (memcmp (data2, GST_BUFFER_DATA (pix1),
+          GST_BUFFER_SIZE (pix1)) == 0);
   /* make sure we got the initial data with adjusted alpha-channel */
-  gst_buffer_map (pix2, &map, GST_MAP_READ);
-  data2 = map.data;
 #if G_BYTE_ORDER == G_LITTLE_ENDIAN
   /* B - G - R - A */
   fail_unless_equals_int (data2[0], 0x80);
@@ -1341,16 +1293,16 @@ GST_START_TEST (test_overlay_composition_global_alpha)
   fail_unless_equals_int (data2[2], 0x80);
   fail_unless_equals_int (data2[3], 0x80);
 #endif
-  gst_buffer_unmap (pix2, &map);
 
   /* again: unscaled pixel-data, global-alpha not applied,
    * this should revert alpha-channel to initial values */
-  pix2 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1,
-      GST_VIDEO_OVERLAY_FORMAT_FLAG_GLOBAL_ALPHA);
+  pix2 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1, &w, &h,
+      &stride, GST_VIDEO_OVERLAY_FORMAT_FLAG_GLOBAL_ALPHA);
   fail_unless (pix2 == pix1);
+  data2 = GST_BUFFER_DATA (pix2);
+  fail_unless (memcmp (data2, GST_BUFFER_DATA (pix1),
+          GST_BUFFER_SIZE (pix1)) == 0);
   /* make sure we got the initial data (input=0x80808080) */
-  gst_buffer_map (pix2, &map, GST_MAP_READ);
-  data2 = map.data;
 #if G_BYTE_ORDER == G_LITTLE_ENDIAN
   /* B - G - R - A */
   fail_unless_equals_int (data2[0], 0x80);
@@ -1364,17 +1316,17 @@ GST_START_TEST (test_overlay_composition_global_alpha)
   fail_unless_equals_int (data2[2], 0x80);
   fail_unless_equals_int (data2[3], 0x80);
 #endif
-  gst_buffer_unmap (pix2, &map);
 
   /* now scaled, global-alpha not applied */
-  pix2 = gst_video_overlay_rectangle_get_pixels_argb (rect1,
+  pix2 = gst_video_overlay_rectangle_get_pixels_argb (rect1, &stride,
       GST_VIDEO_OVERLAY_FORMAT_FLAG_GLOBAL_ALPHA);
   /* this should just return the rect/buffer, that was cached for these
    * scaling dimensions */
   fail_unless (pix2 == pix3);
+  data2 = GST_BUFFER_DATA (pix2);
+  fail_unless (memcmp (data2, GST_BUFFER_DATA (pix3),
+          GST_BUFFER_SIZE (pix3)) == 0);
   /* make sure we got the initial data (input=0x80808080) */
-  gst_buffer_map (pix2, &map, GST_MAP_READ);
-  data2 = map.data;
 #if G_BYTE_ORDER == G_LITTLE_ENDIAN
   /* B - G - R - A */
   fail_unless_equals_int (data2[0], 0x80);
@@ -1388,17 +1340,17 @@ GST_START_TEST (test_overlay_composition_global_alpha)
   fail_unless_equals_int (data2[2], 0x80);
   fail_unless_equals_int (data2[3], 0x80);
 #endif
-  gst_buffer_unmap (pix2, &map);
 
   /* scaled, global-alpha (0.25) applied */
-  pix2 = gst_video_overlay_rectangle_get_pixels_argb (rect1,
+  pix2 = gst_video_overlay_rectangle_get_pixels_argb (rect1, &stride,
       GST_VIDEO_OVERLAY_FORMAT_FLAG_NONE);
   /* this should just return the rect/buffer, that was cached for these
    * scaling dimensions with modified alpha channel */
   fail_unless (pix2 == pix3);
+  data2 = GST_BUFFER_DATA (pix2);
+  fail_unless (memcmp (data2, GST_BUFFER_DATA (pix3),
+          GST_BUFFER_SIZE (pix3)) == 0);
   /* make sure we got the data we expect for global-alpha=0.25 */
-  gst_buffer_map (pix2, &map, GST_MAP_READ);
-  data2 = map.data;
 #if G_BYTE_ORDER == G_LITTLE_ENDIAN
   /* B - G - R - A */
   fail_unless_equals_int (data2[0], 0x80);
@@ -1412,19 +1364,19 @@ GST_START_TEST (test_overlay_composition_global_alpha)
   fail_unless_equals_int (data2[2], 0x80);
   fail_unless_equals_int (data2[3], 0x80);
 #endif
-  gst_buffer_unmap (pix2, &map);
 
   /* now unscaled premultiplied data, global-alpha not applied,
    * is this really a valid use case?*/
-  pix2 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1,
-      GST_VIDEO_OVERLAY_FORMAT_FLAG_PREMULTIPLIED_ALPHA |
+  pix2 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1, &w, &h,
+      &stride, GST_VIDEO_OVERLAY_FORMAT_FLAG_PREMULTIPLIED_ALPHA |
       GST_VIDEO_OVERLAY_FORMAT_FLAG_GLOBAL_ALPHA);
   /* this should just return the rect/buffer, that was cached for the
    * premultiplied data */
   fail_unless (pix2 == pix4);
+  data2 = GST_BUFFER_DATA (pix2);
+  fail_unless (memcmp (data2, GST_BUFFER_DATA (pix4),
+          GST_BUFFER_SIZE (pix4)) == 0);
   /* make sure we got what we expected */
-  gst_buffer_map (pix2, &map, GST_MAP_READ);
-  data2 = map.data;
 #if G_BYTE_ORDER == G_LITTLE_ENDIAN
   /* B - G - R - A */
   fail_unless_equals_int (data2[0], 0x40);
@@ -1438,21 +1390,21 @@ GST_START_TEST (test_overlay_composition_global_alpha)
   fail_unless_equals_int (data2[2], 0x40);
   fail_unless_equals_int (data2[3], 0x40);
 #endif
-  gst_buffer_unmap (pix2, &map);
 
   /* unscaled premultiplied data, global-alpha (0.25) applied */
-  pix2 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1,
-      GST_VIDEO_OVERLAY_FORMAT_FLAG_PREMULTIPLIED_ALPHA);
+  pix2 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1, &w, &h,
+      &stride, GST_VIDEO_OVERLAY_FORMAT_FLAG_PREMULTIPLIED_ALPHA);
   /* this should just return the rect/buffer, that was cached for the
    * premultiplied data */
   fail_unless (pix2 == pix4);
+  data2 = GST_BUFFER_DATA (pix2);
+  fail_unless (memcmp (data2, GST_BUFFER_DATA (pix4),
+          GST_BUFFER_SIZE (pix4)) == 0);
   /* make sure we got what we expected:
    * (0x40 / (0x80/0xFF) * (0x20/0xFF) = 0x10
    * NOTE: unless we are using round() for the premultiplied case
    * in gst_video_overlay_rectangle_apply_global_alpha() we get rounding
    * error, i.e. 0x0F here */
-  gst_buffer_map (pix2, &map, GST_MAP_READ);
-  data2 = map.data;
 #if G_BYTE_ORDER == G_LITTLE_ENDIAN
   /* B - G - R - A */
   fail_unless_equals_int (data2[0], 0x0F);
@@ -1466,23 +1418,23 @@ GST_START_TEST (test_overlay_composition_global_alpha)
   fail_unless_equals_int (data2[2], 0x0F);
   fail_unless_equals_int (data2[3], 0x0F);
 #endif
-  gst_buffer_unmap (pix2, &map);
 
   /* set global_alpha once more */
   gst_video_overlay_rectangle_set_global_alpha (rect1, 0.75);
   /* and verify that also premultiplied data is adjusted
    * correspondingly (though with increasing rounding errors) */
-  pix2 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1,
-      GST_VIDEO_OVERLAY_FORMAT_FLAG_PREMULTIPLIED_ALPHA);
+  pix2 = gst_video_overlay_rectangle_get_pixels_unscaled_argb (rect1, &w, &h,
+      &stride, GST_VIDEO_OVERLAY_FORMAT_FLAG_PREMULTIPLIED_ALPHA);
   /* this should just return the rect/buffer, that was cached for the
    * premultiplied data */
   fail_unless (pix2 == pix4);
+  data2 = GST_BUFFER_DATA (pix2);
+  fail_unless (memcmp (data2, GST_BUFFER_DATA (pix4),
+          GST_BUFFER_SIZE (pix4)) == 0);
   /* make sure we got what we expected:
    * (0x0F / (0x20/0xFF) * (0x60/0xFF) = 0x2D
    * NOTE: using floats everywhere we would get 0x30
    * here we will actually end up with 0x2C */
-  gst_buffer_map (pix2, &map, GST_MAP_READ);
-  data2 = map.data;
 #if G_BYTE_ORDER == G_LITTLE_ENDIAN
   /* B - G - R - A */
   fail_unless_equals_int (data2[0], 0x2C);
@@ -1496,19 +1448,20 @@ GST_START_TEST (test_overlay_composition_global_alpha)
   fail_unless_equals_int (data2[2], 0x2C);
   fail_unless_equals_int (data2[3], 0x2C);
 #endif
-  gst_buffer_unmap (pix2, &map);
 
   /* now scaled and premultiplied data, global-alpha not applied,
    * is this really a valid use case?*/
-  pix2 = gst_video_overlay_rectangle_get_pixels_argb (rect1,
+  pix2 = gst_video_overlay_rectangle_get_pixels_argb (rect1, &stride,
       GST_VIDEO_OVERLAY_FORMAT_FLAG_PREMULTIPLIED_ALPHA |
       GST_VIDEO_OVERLAY_FORMAT_FLAG_GLOBAL_ALPHA);
   /* this should just return the rect/buffer, that was cached for the
    * first premultiplied+scaled rect*/
   fail_unless (pix2 == pix5);
+  fail_unless (stride == stride5);
+  data2 = GST_BUFFER_DATA (pix2);
+  fail_unless (memcmp (data2, GST_BUFFER_DATA (pix5),
+          GST_BUFFER_SIZE (pix5)) == 0);
   /* make sure we got what we expected */
-  gst_buffer_map (pix2, &map, GST_MAP_READ);
-  data2 = map.data;
 #if G_BYTE_ORDER == G_LITTLE_ENDIAN
   /* B - G - R - A */
   fail_unless_equals_int (data2[0], 0x40);
@@ -1522,17 +1475,18 @@ GST_START_TEST (test_overlay_composition_global_alpha)
   fail_unless_equals_int (data2[2], 0x40);
   fail_unless_equals_int (data2[3], 0x40);
 #endif
-  gst_buffer_unmap (pix2, &map);
 
   /* scaled and premultiplied data, global-alpha applied */
-  pix2 = gst_video_overlay_rectangle_get_pixels_argb (rect1,
+  pix2 = gst_video_overlay_rectangle_get_pixels_argb (rect1, &stride,
       GST_VIDEO_OVERLAY_FORMAT_FLAG_PREMULTIPLIED_ALPHA);
   /* this should just return the rect/buffer, that was cached for the
    * first premultiplied+scaled rect*/
   fail_unless (pix2 == pix5);
+  fail_unless (stride == stride5);
+  data2 = GST_BUFFER_DATA (pix2);
+  fail_unless (memcmp (data2, GST_BUFFER_DATA (pix5),
+          GST_BUFFER_SIZE (pix5)) == 0);
   /* make sure we got what we expected; see above note about rounding errors! */
-  gst_buffer_map (pix2, &map, GST_MAP_READ);
-  data2 = map.data;
 #if G_BYTE_ORDER == G_LITTLE_ENDIAN
   /* B - G - R - A */
   fail_unless_equals_int (data2[0], 0x2F);
@@ -1546,13 +1500,12 @@ GST_START_TEST (test_overlay_composition_global_alpha)
   fail_unless_equals_int (data2[2], 0x2F);
   fail_unless_equals_int (data2[3], 0x2F);
 #endif
-  gst_buffer_unmap (pix2, &map);
 
   gst_video_overlay_rectangle_unref (rect1);
 }
 
 GST_END_TEST;
-
+#endif
 static Suite *
 video_suite (void)
 {
@@ -1569,9 +1522,12 @@ video_suite (void)
   tcase_add_test (tc_chain, test_convert_frame);
   tcase_add_test (tc_chain, test_convert_frame_async);
   tcase_add_test (tc_chain, test_video_size_from_caps);
+#if 0
+  /* FIXME 0.11: port overlay compositions */
   tcase_add_test (tc_chain, test_overlay_composition);
   tcase_add_test (tc_chain, test_overlay_composition_premultiplied_alpha);
   tcase_add_test (tc_chain, test_overlay_composition_global_alpha);
+#endif
 
   return s;
 }
