@@ -1814,7 +1814,7 @@ update_streams (GstPipeline * pipeline)
     for (i = 0; i < n_video; i++) {
       g_signal_emit_by_name (pipeline, "get-video-tags", i, &tags);
       if (tags) {
-        str = gst_tag_list_to_string (tags);
+        str = gst_structure_to_string ((GstStructure *) tags);
         g_print ("video %d: %s\n", i, str);
         g_free (str);
       }
@@ -1831,7 +1831,7 @@ update_streams (GstPipeline * pipeline)
     for (i = 0; i < n_audio; i++) {
       g_signal_emit_by_name (pipeline, "get-audio-tags", i, &tags);
       if (tags) {
-        str = gst_tag_list_to_string (tags);
+        str = gst_structure_to_string ((GstStructure *) tags);
         g_print ("audio %d: %s\n", i, str);
         g_free (str);
       }
@@ -1852,7 +1852,7 @@ update_streams (GstPipeline * pipeline)
       if (tags) {
         const GValue *value;
 
-        str = gst_tag_list_to_string (tags);
+        str = gst_structure_to_string ((GstStructure *) tags);
         g_print ("text %d: %s\n", i, str);
         g_free (str);
 
@@ -2140,7 +2140,7 @@ do_shuttle (GstElement * element)
   if (shuttling)
     duration = 40 * GST_MSECOND;
   else
-    duration = 0;
+    duration = -1;
 
   gst_element_send_event (element,
       gst_event_new_step (GST_FORMAT_TIME, duration, shuttle_rate, FALSE,
@@ -2443,6 +2443,11 @@ bus_sync_handler (GstBus * bus, GstMessage * message, GstPipeline * data)
 
   g_print ("got prepare-window-handle, setting XID %lu\n", embed_xid);
 
+  if (g_object_class_find_property (G_OBJECT_GET_CLASS (element),
+          "force-aspect-ratio")) {
+    g_object_set (element, "force-aspect-ratio", TRUE, NULL);
+  }
+
   /* Should have been initialised from main thread before (can't use
    * GDK_WINDOW_XID here with Gtk+ >= 2.18, because the sync handler will
    * be called from a streaming thread and GDK_WINDOW_XID maps to more than
@@ -2518,7 +2523,7 @@ connect_bus_signals (GstElement * pipeline)
 #ifdef HAVE_X
   /* handle prepare-window-handle element message synchronously */
   gst_bus_set_sync_handler (bus, (GstBusSyncHandler) bus_sync_handler,
-      pipeline, NULL);
+      pipeline);
 #endif
 
   gst_bus_add_signal_watch_full (bus, G_PRIORITY_HIGH);
