@@ -28,7 +28,6 @@
 
 static gboolean async = FALSE;
 static gboolean silent = FALSE;
-static gboolean show_toc = FALSE;
 static gboolean verbose = FALSE;
 
 typedef struct
@@ -103,7 +102,7 @@ gst_stream_audio_information_to_string (GstDiscovererStreamInfo * info,
   my_g_string_append_printf (s, depth, "Tags:\n");
   tags = gst_discoverer_stream_info_get_tags (info);
   if (tags) {
-    tmp = gst_tag_list_to_string (tags);
+    tmp = gst_structure_to_string ((GstStructure *) tags);
     my_g_string_append_printf (s, depth, "  %s\n", tmp);
     g_free (tmp);
   } else {
@@ -175,7 +174,7 @@ gst_stream_video_information_to_string (GstDiscovererStreamInfo * info,
   my_g_string_append_printf (s, depth, "Tags:\n");
   tags = gst_discoverer_stream_info_get_tags (info);
   if (tags) {
-    tmp = gst_tag_list_to_string (tags);
+    tmp = gst_structure_to_string ((GstStructure *) tags);
     my_g_string_append_printf (s, depth, "  %s\n", tmp);
     g_free (tmp);
   } else {
@@ -227,7 +226,7 @@ gst_stream_subtitle_information_to_string (GstDiscovererStreamInfo * info,
   my_g_string_append_printf (s, depth, "Tags:\n");
   tags = gst_discoverer_stream_info_get_tags (info);
   if (tags) {
-    tmp = gst_tag_list_to_string (tags);
+    tmp = gst_structure_to_string ((GstStructure *) tags);
     my_g_string_append_printf (s, depth, "  %s\n", tmp);
     g_free (tmp);
   } else {
@@ -311,63 +310,39 @@ print_topology (GstDiscovererStreamInfo * info, gint depth)
   }
 }
 
-static void
-print_tag_foreach (const GstTagList * tags, const gchar * tag,
-    gpointer user_data)
+static gboolean
+print_tag_each (GQuark field_id, const GValue * value, gpointer user_data)
 {
-  GValue val = { 0, };
-  gchar *str;
-  gint depth = GPOINTER_TO_INT (user_data);
+  gint tab = GPOINTER_TO_INT (user_data);
+  gchar *ser;
 
-  gst_tag_list_copy_value (&val, tags, tag);
+  if (G_VALUE_HOLDS_STRING (value))
+    ser = g_value_dup_string (value);
+  else if (GST_VALUE_HOLDS_SAMPLE (value)) {
+    GstSample *smpl = gst_value_get_sample (value);
+    GstBuffer *buf = gst_sample_get_buffer (smpl);
+    GstCaps *caps = gst_sample_get_caps (smpl);
+    gchar *caps_str;
 
-  if (G_VALUE_HOLDS_STRING (&val))
-    str = g_value_dup_string (&val);
-  else
-    str = gst_value_serialize (&val);
+    caps_str = caps ? gst_caps_to_string (caps) : g_strdup ("unknown");
+    ser =
+        g_strdup_printf ("<GstSample [%" G_GSIZE_FORMAT " bytes, type %s]>",
+        gst_buffer_get_size (buf), caps_str);
+    g_free (caps_str);
+  } else
+    ser = gst_value_serialize (value);
 
-  g_print ("%*s%s: %s\n", 2 * depth, " ", gst_tag_get_nick (tag), str);
-  g_free (str);
+  g_print ("%*s%s: %s\n", tab, " ",
+      gst_tag_get_nick (g_quark_to_string (field_id)), ser);
+  g_free (ser);
 
-  g_value_unset (&val);
-}
-
-#define MAX_INDENT 40
-
-static void
-print_toc_entry (gpointer data, gpointer user_data)
-{
-  GstTocEntry *entry = (GstTocEntry *) data;
-  gint depth = GPOINTER_TO_INT (user_data);
-  guint indent = MIN (GPOINTER_TO_UINT (user_data), MAX_INDENT);
-  GstTagList *tags;
-  GList *subentries;
-  gint64 start, stop;
-
-  gst_toc_entry_get_start_stop_times (entry, &start, &stop);
-  g_print ("%*s%s: start: %" GST_TIME_FORMAT " stop: %" GST_TIME_FORMAT "\n",
-      depth, " ",
-      gst_toc_entry_type_get_nick (gst_toc_entry_get_entry_type (entry)),
-      GST_TIME_ARGS (start), GST_TIME_ARGS (stop));
-  indent += 2;
-
-  /* print tags */
-  tags = gst_toc_entry_get_tags (entry);
-  if (tags) {
-    g_print ("%*sTags:\n", 2 * depth, " ");
-    gst_tag_list_foreach (tags, print_tag_foreach, GUINT_TO_POINTER (indent));
-  }
-
-  /* loop over sub-toc entries */
-  subentries = gst_toc_entry_get_sub_entries (entry);
-  g_list_foreach (subentries, print_toc_entry, GUINT_TO_POINTER (indent));
+  return TRUE;
 }
 
 static void
 print_properties (GstDiscovererInfo * info, gint tab)
 {
   const GstTagList *tags;
-  const GstToc *toc;
 
   g_print ("%*sDuration: %" GST_TIME_FORMAT "\n", tab + 1, " ",
       GST_TIME_ARGS (gst_discoverer_info_get_duration (info)));
@@ -375,14 +350,8 @@ print_properties (GstDiscovererInfo * info, gint tab)
       (gst_discoverer_info_get_seekable (info) ? "yes" : "no"));
   if ((tags = gst_discoverer_info_get_tags (info))) {
     g_print ("%*sTags: \n", tab + 1, " ");
-    gst_tag_list_foreach (tags, print_tag_foreach, GUINT_TO_POINTER (tab + 2));
-  }
-  if (show_toc && (toc = gst_discoverer_info_get_toc (info))) {
-    GList *entries;
-
-    g_print ("%*sTOC: \n", tab + 1, " ");
-    entries = gst_toc_get_entries (toc);
-    g_list_foreach (entries, print_toc_entry, GUINT_TO_POINTER (tab + 5));
+    gst_structure_foreach ((const GstStructure *) tags, print_tag_each,
+        GINT_TO_POINTER (tab + 5));
   }
 }
 
@@ -542,8 +511,6 @@ main (int argc, char **argv)
         "Specify timeout (in seconds, default 10)", "T"},
     /* {"elem", 'e', 0, G_OPTION_ARG_NONE, &elem_seek, */
     /*     "Seek on elements instead of pads", NULL}, */
-    {"toc", 'c', 0, G_OPTION_ARG_NONE, &show_toc,
-        "Output TOC (chapters and editions)", NULL},
     {"verbose", 'v', 0, G_OPTION_ARG_NONE, &verbose,
         "Verbose properties", NULL},
     {NULL}
